# Generated from jac.g4 by ANTLR 4.9.2
# encoding: utf-8
from antlr4 import *
from io import StringIO
import sys
if sys.version_info[1] > 5:
	from typing import TextIO
else:
	from typing.io import TextIO


def serializedATN():
    with StringIO() as buf:
        buf.write("\3\u608b\ua72a\u8133\ub9ed\u417c\u3be7\u7786\u5964\3i")
        buf.write("\u0460\4\2\t\2\4\3\t\3\4\4\t\4\4\5\t\5\4\6\t\6\4\7\t\7")
        buf.write("\4\b\t\b\4\t\t\t\4\n\t\n\4\13\t\13\4\f\t\f\4\r\t\r\4\16")
        buf.write("\t\16\4\17\t\17\4\20\t\20\4\21\t\21\4\22\t\22\4\23\t\23")
        buf.write("\4\24\t\24\4\25\t\25\4\26\t\26\4\27\t\27\4\30\t\30\4\31")
        buf.write("\t\31\4\32\t\32\4\33\t\33\4\34\t\34\4\35\t\35\4\36\t\36")
        buf.write("\4\37\t\37\4 \t \4!\t!\4\"\t\"\4#\t#\4$\t$\4%\t%\4&\t")
        buf.write("&\4\'\t\'\4(\t(\4)\t)\4*\t*\4+\t+\4,\t,\4-\t-\4.\t.\4")
        buf.write("/\t/\4\60\t\60\4\61\t\61\4\62\t\62\4\63\t\63\4\64\t\64")
        buf.write("\4\65\t\65\4\66\t\66\4\67\t\67\48\t8\49\t9\4:\t:\4;\t")
        buf.write(";\4<\t<\4=\t=\4>\t>\4?\t?\4@\t@\4A\tA\4B\tB\4C\tC\4D\t")
        buf.write("D\4E\tE\4F\tF\4G\tG\4H\tH\4I\tI\4J\tJ\4K\tK\4L\tL\4M\t")
        buf.write("M\4N\tN\4O\tO\4P\tP\4Q\tQ\4R\tR\4S\tS\4T\tT\4U\tU\4V\t")
        buf.write("V\4W\tW\4X\tX\4Y\tY\4Z\tZ\4[\t[\4\\\t\\\4]\t]\4^\t^\4")
        buf.write("_\t_\4`\t`\4a\ta\4b\tb\4c\tc\4d\td\4e\te\4f\tf\4g\tg\4")
        buf.write("h\th\4i\ti\3\2\5\2\u00d4\n\2\3\2\7\2\u00d7\n\2\f\2\16")
        buf.write("\2\u00da\13\2\3\2\7\2\u00dd\n\2\f\2\16\2\u00e0\13\2\3")
        buf.write("\2\3\2\3\3\3\3\3\3\3\3\5\3\u00e8\n\3\3\3\3\3\3\3\3\3\3")
        buf.write("\3\3\4\3\4\3\4\3\4\5\4\u00f3\n\4\3\5\3\5\3\5\5\5\u00f8")
        buf.write("\n\5\3\5\3\5\5\5\u00fc\n\5\3\5\3\5\3\5\5\5\u0101\n\5\3")
        buf.write("\5\3\5\5\5\u0105\n\5\3\5\3\5\3\5\5\5\u010a\n\5\3\5\3\5")
        buf.write("\5\5\u010e\n\5\3\5\3\5\3\5\5\5\u0113\n\5\3\5\3\5\5\5\u0117")
        buf.write("\n\5\5\5\u0119\n\5\3\6\3\6\3\6\3\6\3\6\3\6\3\6\5\6\u0122")
        buf.write("\n\6\3\7\3\7\3\7\5\7\u0127\n\7\3\b\3\b\3\b\3\b\5\b\u012d")
        buf.write("\n\b\3\b\3\b\3\b\3\b\3\b\3\b\3\b\5\b\u0136\n\b\3\t\3\t")
        buf.write("\3\t\5\t\u013b\n\t\3\t\3\t\3\n\3\n\7\n\u0141\n\n\f\n\16")
        buf.write("\n\u0144\13\n\3\n\5\n\u0147\n\n\3\n\3\n\7\n\u014b\n\n")
        buf.write("\f\n\16\n\u014e\13\n\3\n\5\n\u0151\n\n\3\n\3\n\3\13\3")
        buf.write("\13\3\13\3\13\3\13\3\13\5\13\u015b\n\13\3\13\3\13\3\13")
        buf.write("\5\13\u0160\n\13\3\13\3\13\5\13\u0164\n\13\3\13\3\13\5")
        buf.write("\13\u0168\n\13\3\f\3\f\3\f\3\r\3\r\3\r\3\r\3\16\3\16\3")
        buf.write("\16\3\16\3\17\3\17\3\17\3\17\3\20\3\20\7\20\u017b\n\20")
        buf.write("\f\20\16\20\u017e\13\20\3\20\3\20\3\20\3\20\5\20\u0184")
        buf.write("\n\20\3\21\3\21\5\21\u0188\n\21\3\22\3\22\5\22\u018c\n")
        buf.write("\22\3\23\3\23\3\23\3\23\3\23\3\23\3\23\3\23\3\23\3\23")
        buf.write("\3\23\3\23\5\23\u019a\n\23\3\24\3\24\3\24\3\24\3\24\3")
        buf.write("\24\3\24\3\24\3\24\3\24\5\24\u01a6\n\24\3\25\3\25\3\25")
        buf.write("\3\25\3\25\3\26\3\26\5\26\u01af\n\26\3\26\5\26\u01b2\n")
        buf.write("\26\3\26\3\26\3\26\7\26\u01b7\n\26\f\26\16\26\u01ba\13")
        buf.write("\26\3\26\3\26\3\27\3\27\3\27\3\27\5\27\u01c2\n\27\3\30")
        buf.write("\3\30\3\30\3\30\3\30\5\30\u01c9\n\30\3\30\3\30\3\30\3")
        buf.write("\30\3\30\5\30\u01d0\n\30\7\30\u01d2\n\30\f\30\16\30\u01d5")
        buf.write("\13\30\3\30\3\30\3\30\3\30\3\30\5\30\u01dc\n\30\3\30\5")
        buf.write("\30\u01df\n\30\3\31\3\31\5\31\u01e3\n\31\3\31\3\31\3\32")
        buf.write("\3\32\5\32\u01e9\n\32\3\32\3\32\3\32\5\32\u01ee\n\32\3")
        buf.write("\33\3\33\3\33\3\33\3\34\3\34\3\34\7\34\u01f7\n\34\f\34")
        buf.write("\16\34\u01fa\13\34\3\35\3\35\3\35\7\35\u01ff\n\35\f\35")
        buf.write("\16\35\u0202\13\35\3\36\3\36\7\36\u0206\n\36\f\36\16\36")
        buf.write("\u0209\13\36\3\36\3\36\3\36\5\36\u020e\n\36\3\37\3\37")
        buf.write("\3\37\3 \3 \3 \3 \3 \3 \3 \3 \3 \3 \3 \3 \3 \3 \3 \3 ")
        buf.write("\3 \3 \5 \u0225\n \3!\3!\3!\3!\7!\u022b\n!\f!\16!\u022e")
        buf.write("\13!\3!\5!\u0231\n!\3\"\3\"\3\"\5\"\u0236\n\"\3#\3#\3")
        buf.write("#\3#\5#\u023c\n#\3#\3#\3#\3#\5#\u0242\n#\3#\5#\u0245\n")
        buf.write("#\3$\3$\3$\3$\3%\3%\3%\3&\3&\3&\3&\3&\3&\3&\3&\3&\3&\3")
        buf.write("&\3&\3&\3&\5&\u025c\n&\3\'\3\'\3\'\3\'\3(\3(\3)\3)\3)")
        buf.write("\3*\3*\3*\3*\3+\3+\3+\3+\3+\3+\3+\3+\3+\3+\5+\u0275\n")
        buf.write("+\3,\3,\3,\3,\5,\u027b\n,\3-\3-\3-\3-\3.\3.\3.\3.\5.\u0285")
        buf.write("\n.\3/\3/\3/\3/\5/\u028b\n/\3\60\3\60\3\60\3\61\3\61\3")
        buf.write("\61\3\62\3\62\3\62\3\63\3\63\5\63\u0298\n\63\3\63\3\63")
        buf.write("\3\63\5\63\u029d\n\63\3\64\3\64\3\64\7\64\u02a2\n\64\f")
        buf.write("\64\16\64\u02a5\13\64\3\65\3\65\3\65\3\65\3\65\3\65\7")
        buf.write("\65\u02ad\n\65\f\65\16\65\u02b0\13\65\5\65\u02b2\n\65")
        buf.write("\3\66\3\66\3\66\3\66\3\66\3\66\3\66\3\66\5\66\u02bc\n")
        buf.write("\66\3\67\3\67\3\67\38\38\38\78\u02c4\n8\f8\168\u02c7\13")
        buf.write("8\39\39\39\79\u02cc\n9\f9\169\u02cf\139\3:\3:\3:\5:\u02d4")
        buf.write("\n:\3;\3;\3;\7;\u02d9\n;\f;\16;\u02dc\13;\3<\3<\3<\3<")
        buf.write("\3<\3<\3<\3<\3<\3<\3<\3<\3<\3<\3<\3<\3<\5<\u02ef\n<\3")
        buf.write("<\3<\3<\3<\5<\u02f5\n<\3<\3<\6<\u02f9\n<\r<\16<\u02fa")
        buf.write("\7<\u02fd\n<\f<\16<\u0300\13<\3=\3=\3=\3=\3=\3=\3=\5=")
        buf.write("\u0309\n=\3=\3=\3=\3=\5=\u030f\n=\5=\u0311\n=\3>\3>\3")
        buf.write(">\3?\3?\3?\3@\3@\3@\3@\3@\3@\5@\u031f\n@\3A\3A\3B\3B\3")
        buf.write("C\3C\3C\3C\3C\3C\3C\3C\5C\u032d\nC\3C\3C\3C\3C\3C\5C\u0334")
        buf.write("\nC\5C\u0336\nC\3D\3D\3D\3D\5D\u033c\nD\3D\3D\3D\3D\3")
        buf.write("D\5D\u0343\nD\5D\u0345\nD\3E\3E\3E\5E\u034a\nE\3E\3E\3")
        buf.write("E\3E\3E\5E\u0351\nE\3F\3F\5F\u0355\nF\3F\3F\3F\5F\u035a")
        buf.write("\nF\5F\u035c\nF\5F\u035e\nF\3G\3G\3G\3G\3H\3H\3H\3H\3")
        buf.write("I\3I\3I\3I\3J\3J\3J\5J\u036f\nJ\3K\3K\3K\3K\3K\3K\5K\u0377")
        buf.write("\nK\3K\5K\u037a\nK\3K\5K\u037d\nK\3L\3L\3L\3L\3L\3L\5")
        buf.write("L\u0385\nL\3L\5L\u0388\nL\3L\5L\u038b\nL\3M\3M\3M\3M\3")
        buf.write("M\3M\5M\u0393\nM\3M\5M\u0396\nM\3M\5M\u0399\nM\3N\3N\5")
        buf.write("N\u039d\nN\3N\3N\3O\3O\3O\3O\3O\3O\3O\3O\3O\3O\5O\u03ab")
        buf.write("\nO\3P\3P\3P\3P\7P\u03b1\nP\fP\16P\u03b4\13P\5P\u03b6")
        buf.write("\nP\3P\3P\3Q\3Q\3Q\3Q\3R\3R\5R\u03c0\nR\3R\3R\3S\3S\3")
        buf.write("S\5S\u03c7\nS\3T\5T\u03ca\nT\3T\3T\5T\u03ce\nT\3U\5U\u03d1")
        buf.write("\nU\3U\3U\3V\3V\5V\u03d7\nV\3W\3W\3W\3W\7W\u03dd\nW\f")
        buf.write("W\16W\u03e0\13W\5W\u03e2\nW\3W\3W\3X\3X\3X\3X\7X\u03ea")
        buf.write("\nX\fX\16X\u03ed\13X\5X\u03ef\nX\3X\3X\3Y\3Y\3Y\3Y\3Z")
        buf.write("\3Z\3Z\3Z\3[\3[\3\\\5\\\u03fe\n\\\3\\\3\\\5\\\u0402\n")
        buf.write("\\\3\\\3\\\3\\\3\\\3]\3]\5]\u040a\n]\7]\u040c\n]\f]\16")
        buf.write("]\u040f\13]\3^\3^\3^\3^\3^\3^\3^\3^\5^\u0419\n^\3_\3_")
        buf.write("\3_\3`\3`\5`\u0420\n`\3`\6`\u0423\n`\r`\16`\u0424\3a\3")
        buf.write("a\3a\5a\u042a\na\3a\5a\u042d\na\6a\u042f\na\ra\16a\u0430")
        buf.write("\3b\3b\5b\u0435\nb\3b\3b\5b\u0439\nb\3c\3c\3c\5c\u043e")
        buf.write("\nc\6c\u0440\nc\rc\16c\u0441\3d\3d\3e\3e\5e\u0448\ne\3")
        buf.write("f\3f\5f\u044c\nf\3g\3g\3g\3g\5g\u0452\ng\3h\3h\5h\u0456")
        buf.write("\nh\5h\u0458\nh\3h\3h\3h\3h\3i\3i\3i\2\3vj\2\4\6\b\n\f")
        buf.write("\16\20\22\24\26\30\32\34\36 \"$&(*,.\60\62\64\668:<>@")
        buf.write("BDFHJLNPRTVXZ\\^`bdfhjlnprtvxz|~\u0080\u0082\u0084\u0086")
        buf.write("\u0088\u008a\u008c\u008e\u0090\u0092\u0094\u0096\u0098")
        buf.write("\u009a\u009c\u009e\u00a0\u00a2\u00a4\u00a6\u00a8\u00aa")
        buf.write("\u00ac\u00ae\u00b0\u00b2\u00b4\u00b6\u00b8\u00ba\u00bc")
        buf.write("\u00be\u00c0\u00c2\u00c4\u00c6\u00c8\u00ca\u00cc\u00ce")
        buf.write("\u00d0\2\17\4\2\33\34\"\"\4\2@ACC\3\2\62\65\3\2\678\3")
        buf.write("\2UV\3\2WY\3\2\37!\4\2\36\36dd\5\2\13\21\26\26,,\4\2\22")
        buf.write("\22\24\24\5\2\22\22\26\26,,\4\2\6\6\n\n\b\2\22\22\26\26")
        buf.write(",,_`bbdd\2\u04b3\2\u00d3\3\2\2\2\4\u00e3\3\2\2\2\6\u00ee")
        buf.write("\3\2\2\2\b\u0118\3\2\2\2\n\u0121\3\2\2\2\f\u0126\3\2\2")
        buf.write("\2\16\u0135\3\2\2\2\20\u0137\3\2\2\2\22\u013e\3\2\2\2")
        buf.write("\24\u0154\3\2\2\2\26\u0169\3\2\2\2\30\u016c\3\2\2\2\32")
        buf.write("\u0170\3\2\2\2\34\u0174\3\2\2\2\36\u0183\3\2\2\2 \u0187")
        buf.write("\3\2\2\2\"\u018b\3\2\2\2$\u0199\3\2\2\2&\u01a5\3\2\2\2")
        buf.write("(\u01a7\3\2\2\2*\u01ac\3\2\2\2,\u01c1\3\2\2\2.\u01de\3")
        buf.write("\2\2\2\60\u01e0\3\2\2\2\62\u01e6\3\2\2\2\64\u01ef\3\2")
        buf.write("\2\2\66\u01f3\3\2\2\28\u01fb\3\2\2\2:\u020d\3\2\2\2<\u020f")
        buf.write("\3\2\2\2>\u0224\3\2\2\2@\u0226\3\2\2\2B\u0232\3\2\2\2")
        buf.write("D\u0244\3\2\2\2F\u0246\3\2\2\2H\u024a\3\2\2\2J\u025b\3")
        buf.write("\2\2\2L\u025d\3\2\2\2N\u0261\3\2\2\2P\u0263\3\2\2\2R\u0266")
        buf.write("\3\2\2\2T\u0274\3\2\2\2V\u027a\3\2\2\2X\u027c\3\2\2\2")
        buf.write("Z\u0280\3\2\2\2\\\u0286\3\2\2\2^\u028c\3\2\2\2`\u028f")
        buf.write("\3\2\2\2b\u0292\3\2\2\2d\u0295\3\2\2\2f\u029e\3\2\2\2")
        buf.write("h\u02b1\3\2\2\2j\u02bb\3\2\2\2l\u02bd\3\2\2\2n\u02c0\3")
        buf.write("\2\2\2p\u02c8\3\2\2\2r\u02d3\3\2\2\2t\u02d5\3\2\2\2v\u02f4")
        buf.write("\3\2\2\2x\u0310\3\2\2\2z\u0312\3\2\2\2|\u0315\3\2\2\2")
        buf.write("~\u031e\3\2\2\2\u0080\u0320\3\2\2\2\u0082\u0322\3\2\2")
        buf.write("\2\u0084\u0335\3\2\2\2\u0086\u0344\3\2\2\2\u0088\u0349")
        buf.write("\3\2\2\2\u008a\u035d\3\2\2\2\u008c\u035f\3\2\2\2\u008e")
        buf.write("\u0363\3\2\2\2\u0090\u0367\3\2\2\2\u0092\u036e\3\2\2\2")
        buf.write("\u0094\u037c\3\2\2\2\u0096\u038a\3\2\2\2\u0098\u0398\3")
        buf.write("\2\2\2\u009a\u039a\3\2\2\2\u009c\u03aa\3\2\2\2\u009e\u03ac")
        buf.write("\3\2\2\2\u00a0\u03b9\3\2\2\2\u00a2\u03bd\3\2\2\2\u00a4")
        buf.write("\u03c6\3\2\2\2\u00a6\u03c9\3\2\2\2\u00a8\u03d0\3\2\2\2")
        buf.write("\u00aa\u03d4\3\2\2\2\u00ac\u03d8\3\2\2\2\u00ae\u03e5\3")
        buf.write("\2\2\2\u00b0\u03f2\3\2\2\2\u00b2\u03f6\3\2\2\2\u00b4\u03fa")
        buf.write("\3\2\2\2\u00b6\u03fd\3\2\2\2\u00b8\u040d\3\2\2\2\u00ba")
        buf.write("\u0418\3\2\2\2\u00bc\u041a\3\2\2\2\u00be\u0422\3\2\2\2")
        buf.write("\u00c0\u042e\3\2\2\2\u00c2\u0434\3\2\2\2\u00c4\u043f\3")
        buf.write("\2\2\2\u00c6\u0443\3\2\2\2\u00c8\u0445\3\2\2\2\u00ca\u0449")
        buf.write("\3\2\2\2\u00cc\u044d\3\2\2\2\u00ce\u0457\3\2\2\2\u00d0")
        buf.write("\u045d\3\2\2\2\u00d2\u00d4\5\6\4\2\u00d3\u00d2\3\2\2\2")
        buf.write("\u00d3\u00d4\3\2\2\2\u00d4\u00d8\3\2\2\2\u00d5\u00d7\5")
        buf.write("\4\3\2\u00d6\u00d5\3\2\2\2\u00d7\u00da\3\2\2\2\u00d8\u00d6")
        buf.write("\3\2\2\2\u00d8\u00d9\3\2\2\2\u00d9\u00de\3\2\2\2\u00da")
        buf.write("\u00d8\3\2\2\2\u00db\u00dd\5\f\7\2\u00dc\u00db\3\2\2\2")
        buf.write("\u00dd\u00e0\3\2\2\2\u00de\u00dc\3\2\2\2\u00de\u00df\3")
        buf.write("\2\2\2\u00df\u00e1\3\2\2\2\u00e0\u00de\3\2\2\2\u00e1\u00e2")
        buf.write("\7\2\2\3\u00e2\3\3\2\2\2\u00e3\u00e4\7#\2\2\u00e4\u00e7")
        buf.write("\7*\2\2\u00e5\u00e8\5\b\5\2\u00e6\u00e8\7W\2\2\u00e7\u00e5")
        buf.write("\3\2\2\2\u00e7\u00e6\3\2\2\2\u00e8\u00e9\3\2\2\2\u00e9")
        buf.write("\u00ea\7+\2\2\u00ea\u00eb\7\32\2\2\u00eb\u00ec\7`\2\2")
        buf.write("\u00ec\u00ed\7\60\2\2\u00ed\5\3\2\2\2\u00ee\u00ef\7\3")
        buf.write("\2\2\u00ef\u00f0\7$\2\2\u00f0\u00f2\7`\2\2\u00f1\u00f3")
        buf.write("\7\60\2\2\u00f2\u00f1\3\2\2\2\u00f2\u00f3\3\2\2\2\u00f3")
        buf.write("\7\3\2\2\2\u00f4\u00f7\7-\2\2\u00f5\u00f8\7W\2\2\u00f6")
        buf.write("\u00f8\5\n\6\2\u00f7\u00f5\3\2\2\2\u00f7\u00f6\3\2\2\2")
        buf.write("\u00f8\u00fb\3\2\2\2\u00f9\u00fa\7S\2\2\u00fa\u00fc\5")
        buf.write("\b\5\2\u00fb\u00f9\3\2\2\2\u00fb\u00fc\3\2\2\2\u00fc\u0119")
        buf.write("\3\2\2\2\u00fd\u0100\7\26\2\2\u00fe\u0101\7W\2\2\u00ff")
        buf.write("\u0101\5\n\6\2\u0100\u00fe\3\2\2\2\u0100\u00ff\3\2\2\2")
        buf.write("\u0101\u0104\3\2\2\2\u0102\u0103\7S\2\2\u0103\u0105\5")
        buf.write("\b\5\2\u0104\u0102\3\2\2\2\u0104\u0105\3\2\2\2\u0105\u0119")
        buf.write("\3\2\2\2\u0106\u0109\7,\2\2\u0107\u010a\7W\2\2\u0108\u010a")
        buf.write("\5\n\6\2\u0109\u0107\3\2\2\2\u0109\u0108\3\2\2\2\u010a")
        buf.write("\u010d\3\2\2\2\u010b\u010c\7S\2\2\u010c\u010e\5\b\5\2")
        buf.write("\u010d\u010b\3\2\2\2\u010d\u010e\3\2\2\2\u010e\u0119\3")
        buf.write("\2\2\2\u010f\u0112\7\22\2\2\u0110\u0113\7W\2\2\u0111\u0113")
        buf.write("\5\n\6\2\u0112\u0110\3\2\2\2\u0112\u0111\3\2\2\2\u0113")
        buf.write("\u0116\3\2\2\2\u0114\u0115\7S\2\2\u0115\u0117\5\b\5\2")
        buf.write("\u0116\u0114\3\2\2\2\u0116\u0117\3\2\2\2\u0117\u0119\3")
        buf.write("\2\2\2\u0118\u00f4\3\2\2\2\u0118\u00fd\3\2\2\2\u0118\u0106")
        buf.write("\3\2\2\2\u0118\u010f\3\2\2\2\u0119\t\3\2\2\2\u011a\u011b")
        buf.write("\7%\2\2\u011b\u0122\7d\2\2\u011c\u011d\7%\2\2\u011d\u011e")
        buf.write("\7*\2\2\u011e\u011f\5\66\34\2\u011f\u0120\7+\2\2\u0120")
        buf.write("\u0122\3\2\2\2\u0121\u011a\3\2\2\2\u0121\u011c\3\2\2\2")
        buf.write("\u0122\13\3\2\2\2\u0123\u0127\5\16\b\2\u0124\u0127\5\20")
        buf.write("\t\2\u0125\u0127\5\24\13\2\u0126\u0123\3\2\2\2\u0126\u0124")
        buf.write("\3\2\2\2\u0126\u0125\3\2\2\2\u0127\r\3\2\2\2\u0128\u0129")
        buf.write("\7\26\2\2\u0129\u012c\7d\2\2\u012a\u012b\7$\2\2\u012b")
        buf.write("\u012d\7b\2\2\u012c\u012a\3\2\2\2\u012c\u012d\3\2\2\2")
        buf.write("\u012d\u012e\3\2\2\2\u012e\u0136\5\36\20\2\u012f\u0130")
        buf.write("\7,\2\2\u0130\u0131\7d\2\2\u0131\u0136\5\36\20\2\u0132")
        buf.write("\u0133\7\22\2\2\u0133\u0134\7d\2\2\u0134\u0136\5\"\22")
        buf.write("\2\u0135\u0128\3\2\2\2\u0135\u012f\3\2\2\2\u0135\u0132")
        buf.write("\3\2\2\2\u0136\17\3\2\2\2\u0137\u0138\7-\2\2\u0138\u013a")
        buf.write("\7d\2\2\u0139\u013b\5\26\f\2\u013a\u0139\3\2\2\2\u013a")
        buf.write("\u013b\3\2\2\2\u013b\u013c\3\2\2\2\u013c\u013d\5\22\n")
        buf.write("\2\u013d\21\3\2\2\2\u013e\u0142\7*\2\2\u013f\u0141\5 ")
        buf.write("\21\2\u0140\u013f\3\2\2\2\u0141\u0144\3\2\2\2\u0142\u0140")
        buf.write("\3\2\2\2\u0142\u0143\3\2\2\2\u0143\u0146\3\2\2\2\u0144")
        buf.write("\u0142\3\2\2\2\u0145\u0147\5\30\r\2\u0146\u0145\3\2\2")
        buf.write("\2\u0146\u0147\3\2\2\2\u0147\u014c\3\2\2\2\u0148\u014b")
        buf.write("\5> \2\u0149\u014b\5\34\17\2\u014a\u0148\3\2\2\2\u014a")
        buf.write("\u0149\3\2\2\2\u014b\u014e\3\2\2\2\u014c\u014a\3\2\2\2")
        buf.write("\u014c\u014d\3\2\2\2\u014d\u0150\3\2\2\2\u014e\u014c\3")
        buf.write("\2\2\2\u014f\u0151\5\32\16\2\u0150\u014f\3\2\2\2\u0150")
        buf.write("\u0151\3\2\2\2\u0151\u0152\3\2\2\2\u0152\u0153\7+\2\2")
        buf.write("\u0153\23\3\2\2\2\u0154\u0155\7.\2\2\u0155\u0156\7`\2")
        buf.write("\2\u0156\u015a\7\32\2\2\u0157\u015b\5\u0090I\2\u0158\u0159")
        buf.write("\7\22\2\2\u0159\u015b\5\"\22\2\u015a\u0157\3\2\2\2\u015a")
        buf.write("\u0158\3\2\2\2\u015b\u015c\3\2\2\2\u015c\u0167\7>\2\2")
        buf.write("\u015d\u015f\5\u008eH\2\u015e\u0160\5\u00acW\2\u015f\u015e")
        buf.write("\3\2\2\2\u015f\u0160\3\2\2\2\u0160\u0163\3\2\2\2\u0161")
        buf.write("\u0164\5:\36\2\u0162\u0164\7\60\2\2\u0163\u0161\3\2\2")
        buf.write("\2\u0163\u0162\3\2\2\2\u0164\u0168\3\2\2\2\u0165\u0166")
        buf.write("\7-\2\2\u0166\u0168\5\22\n\2\u0167\u015d\3\2\2\2\u0167")
        buf.write("\u0165\3\2\2\2\u0168\25\3\2\2\2\u0169\u016a\7$\2\2\u016a")
        buf.write("\u016b\5\66\34\2\u016b\27\3\2\2\2\u016c\u016d\7\32\2\2")
        buf.write("\u016d\u016e\7\33\2\2\u016e\u016f\5:\36\2\u016f\31\3\2")
        buf.write("\2\2\u0170\u0171\7\32\2\2\u0171\u0172\7\34\2\2\u0172\u0173")
        buf.write("\5:\36\2\u0173\33\3\2\2\2\u0174\u0175\7\32\2\2\u0175\u0176")
        buf.write("\7\"\2\2\u0176\u0177\5:\36\2\u0177\35\3\2\2\2\u0178\u017c")
        buf.write("\7*\2\2\u0179\u017b\5 \21\2\u017a\u0179\3\2\2\2\u017b")
        buf.write("\u017e\3\2\2\2\u017c\u017a\3\2\2\2\u017c\u017d\3\2\2\2")
        buf.write("\u017d\u017f\3\2\2\2\u017e\u017c\3\2\2\2\u017f\u0184\7")
        buf.write("+\2\2\u0180\u0181\7$\2\2\u0181\u0184\5 \21\2\u0182\u0184")
        buf.write("\7\60\2\2\u0183\u0178\3\2\2\2\u0183\u0180\3\2\2\2\u0183")
        buf.write("\u0182\3\2\2\2\u0184\37\3\2\2\2\u0185\u0188\5*\26\2\u0186")
        buf.write("\u0188\5.\30\2\u0187\u0185\3\2\2\2\u0187\u0186\3\2\2\2")
        buf.write("\u0188!\3\2\2\2\u0189\u018c\5$\23\2\u018a\u018c\5&\24")
        buf.write("\2\u018b\u0189\3\2\2\2\u018b\u018a\3\2\2\2\u018c#\3\2")
        buf.write("\2\2\u018d\u018e\7*\2\2\u018e\u018f\5(\25\2\u018f\u0190")
        buf.write("\7\31\2\2\u0190\u0191\5:\36\2\u0191\u0192\7+\2\2\u0192")
        buf.write("\u019a\3\2\2\2\u0193\u0194\7$\2\2\u0194\u0195\5(\25\2")
        buf.write("\u0195\u0196\7\31\2\2\u0196\u0197\5:\36\2\u0197\u0198")
        buf.write("\7\60\2\2\u0198\u019a\3\2\2\2\u0199\u018d\3\2\2\2\u0199")
        buf.write("\u0193\3\2\2\2\u019a%\3\2\2\2\u019b\u019c\7*\2\2\u019c")
        buf.write("\u019d\5(\25\2\u019d\u019e\5\u00b6\\\2\u019e\u019f\7+")
        buf.write("\2\2\u019f\u01a6\3\2\2\2\u01a0\u01a1\7$\2\2\u01a1\u01a2")
        buf.write("\5(\25\2\u01a2\u01a3\5\u00b6\\\2\u01a3\u01a4\7\60\2\2")
        buf.write("\u01a4\u01a6\3\2\2\2\u01a5\u019b\3\2\2\2\u01a5\u01a0\3")
        buf.write("\2\2\2\u01a6\'\3\2\2\2\u01a7\u01a8\7Q\2\2\u01a8\u01a9")
        buf.write("\7P\2\2\u01a9\u01aa\7d\2\2\u01aa\u01ab\7\60\2\2\u01ab")
        buf.write(")\3\2\2\2\u01ac\u01ae\7Q\2\2\u01ad\u01af\7R\2\2\u01ae")
        buf.write("\u01ad\3\2\2\2\u01ae\u01af\3\2\2\2\u01af\u01b1\3\2\2\2")
        buf.write("\u01b0\u01b2\7P\2\2\u01b1\u01b0\3\2\2\2\u01b1\u01b2\3")
        buf.write("\2\2\2\u01b2\u01b3\3\2\2\2\u01b3\u01b8\5,\27\2\u01b4\u01b5")
        buf.write("\7S\2\2\u01b5\u01b7\5,\27\2\u01b6\u01b4\3\2\2\2\u01b7")
        buf.write("\u01ba\3\2\2\2\u01b8\u01b6\3\2\2\2\u01b8\u01b9\3\2\2\2")
        buf.write("\u01b9\u01bb\3\2\2\2\u01ba\u01b8\3\2\2\2\u01bb\u01bc\7")
        buf.write("\60\2\2\u01bc+\3\2\2\2\u01bd\u01c2\7d\2\2\u01be\u01bf")
        buf.write("\7d\2\2\u01bf\u01c0\7\61\2\2\u01c0\u01c2\5\\/\2\u01c1")
        buf.write("\u01bd\3\2\2\2\u01c1\u01be\3\2\2\2\u01c2-\3\2\2\2\u01c3")
        buf.write("\u01c4\7T\2\2\u01c4\u01c8\5\64\33\2\u01c5\u01c6\5\62\32")
        buf.write("\2\u01c6\u01c7\5\60\31\2\u01c7\u01c9\3\2\2\2\u01c8\u01c5")
        buf.write("\3\2\2\2\u01c8\u01c9\3\2\2\2\u01c9\u01d3\3\2\2\2\u01ca")
        buf.write("\u01cb\7S\2\2\u01cb\u01cf\5\64\33\2\u01cc\u01cd\5\62\32")
        buf.write("\2\u01cd\u01ce\5\60\31\2\u01ce\u01d0\3\2\2\2\u01cf\u01cc")
        buf.write("\3\2\2\2\u01cf\u01d0\3\2\2\2\u01d0\u01d2\3\2\2\2\u01d1")
        buf.write("\u01ca\3\2\2\2\u01d2\u01d5\3\2\2\2\u01d3\u01d1\3\2\2\2")
        buf.write("\u01d3\u01d4\3\2\2\2\u01d4\u01d6\3\2\2\2\u01d5\u01d3\3")
        buf.write("\2\2\2\u01d6\u01d7\7\60\2\2\u01d7\u01df\3\2\2\2\u01d8")
        buf.write("\u01d9\7T\2\2\u01d9\u01db\7d\2\2\u01da\u01dc\5\60\31\2")
        buf.write("\u01db\u01da\3\2\2\2\u01db\u01dc\3\2\2\2\u01dc\u01dd\3")
        buf.write("\2\2\2\u01dd\u01df\5:\36\2\u01de\u01c3\3\2\2\2\u01de\u01d8")
        buf.write("\3\2\2\2\u01df/\3\2\2\2\u01e0\u01e2\7\32\2\2\u01e1\u01e3")
        buf.write("\5\66\34\2\u01e2\u01e1\3\2\2\2\u01e2\u01e3\3\2\2\2\u01e3")
        buf.write("\u01e4\3\2\2\2\u01e4\u01e5\t\2\2\2\u01e5\61\3\2\2\2\u01e6")
        buf.write("\u01e8\7%\2\2\u01e7\u01e9\58\35\2\u01e8\u01e7\3\2\2\2")
        buf.write("\u01e8\u01e9\3\2\2\2\u01e9\u01ed\3\2\2\2\u01ea\u01ee\7")
        buf.write("%\2\2\u01eb\u01ec\7)\2\2\u01ec\u01ee\5\\/\2\u01ed\u01ea")
        buf.write("\3\2\2\2\u01ed\u01eb\3\2\2\2\u01ee\63\3\2\2\2\u01ef\u01f0")
        buf.write("\7d\2\2\u01f0\u01f1\7G\2\2\u01f1\u01f2\7d\2\2\u01f2\65")
        buf.write("\3\2\2\2\u01f3\u01f8\7d\2\2\u01f4\u01f5\7S\2\2\u01f5\u01f7")
        buf.write("\7d\2\2\u01f6\u01f4\3\2\2\2\u01f7\u01fa\3\2\2\2\u01f8")
        buf.write("\u01f6\3\2\2\2\u01f8\u01f9\3\2\2\2\u01f9\67\3\2\2\2\u01fa")
        buf.write("\u01f8\3\2\2\2\u01fb\u0200\5\\/\2\u01fc\u01fd\7S\2\2\u01fd")
        buf.write("\u01ff\5\\/\2\u01fe\u01fc\3\2\2\2\u01ff\u0202\3\2\2\2")
        buf.write("\u0200\u01fe\3\2\2\2\u0200\u0201\3\2\2\2\u02019\3\2\2")
        buf.write("\2\u0202\u0200\3\2\2\2\u0203\u0207\7*\2\2\u0204\u0206")
        buf.write("\5> \2\u0205\u0204\3\2\2\2\u0206\u0209\3\2\2\2\u0207\u0205")
        buf.write("\3\2\2\2\u0207\u0208\3\2\2\2\u0208\u020a\3\2\2\2\u0209")
        buf.write("\u0207\3\2\2\2\u020a\u020e\7+\2\2\u020b\u020c\7$\2\2\u020c")
        buf.write("\u020e\5> \2\u020d\u0203\3\2\2\2\u020d\u020b\3\2\2\2\u020e")
        buf.write(";\3\2\2\2\u020f\u0210\5\66\34\2\u0210\u0211\5:\36\2\u0211")
        buf.write("=\3\2\2\2\u0212\u0225\5:\36\2\u0213\u0225\5<\37\2\u0214")
        buf.write("\u0215\5\\/\2\u0215\u0216\7\60\2\2\u0216\u0225\3\2\2\2")
        buf.write("\u0217\u0225\5@!\2\u0218\u0225\5B\"\2\u0219\u0225\5J&")
        buf.write("\2\u021a\u0225\5L\'\2\u021b\u021c\5P)\2\u021c\u021d\7")
        buf.write("\60\2\2\u021d\u0225\3\2\2\2\u021e\u021f\5N(\2\u021f\u0220")
        buf.write("\7\60\2\2\u0220\u0225\3\2\2\2\u0221\u0225\5R*\2\u0222")
        buf.write("\u0225\5T+\2\u0223\u0225\5V,\2\u0224\u0212\3\2\2\2\u0224")
        buf.write("\u0213\3\2\2\2\u0224\u0214\3\2\2\2\u0224\u0217\3\2\2\2")
        buf.write("\u0224\u0218\3\2\2\2\u0224\u0219\3\2\2\2\u0224\u021a\3")
        buf.write("\2\2\2\u0224\u021b\3\2\2\2\u0224\u021e\3\2\2\2\u0224\u0221")
        buf.write("\3\2\2\2\u0224\u0222\3\2\2\2\u0224\u0223\3\2\2\2\u0225")
        buf.write("?\3\2\2\2\u0226\u0227\79\2\2\u0227\u0228\5\\/\2\u0228")
        buf.write("\u022c\5:\36\2\u0229\u022b\5F$\2\u022a\u0229\3\2\2\2\u022b")
        buf.write("\u022e\3\2\2\2\u022c\u022a\3\2\2\2\u022c\u022d\3\2\2\2")
        buf.write("\u022d\u0230\3\2\2\2\u022e\u022c\3\2\2\2\u022f\u0231\5")
        buf.write("H%\2\u0230\u022f\3\2\2\2\u0230\u0231\3\2\2\2\u0231A\3")
        buf.write("\2\2\2\u0232\u0233\7F\2\2\u0233\u0235\5:\36\2\u0234\u0236")
        buf.write("\5D#\2\u0235\u0234\3\2\2\2\u0235\u0236\3\2\2\2\u0236C")
        buf.write("\3\2\2\2\u0237\u023b\7;\2\2\u0238\u0239\7[\2\2\u0239\u023a")
        buf.write("\7d\2\2\u023a\u023c\7\\\2\2\u023b\u0238\3\2\2\2\u023b")
        buf.write("\u023c\3\2\2\2\u023c\u023d\3\2\2\2\u023d\u0245\5:\36\2")
        buf.write("\u023e\u0241\7;\2\2\u023f\u0240\7\32\2\2\u0240\u0242\7")
        buf.write("d\2\2\u0241\u023f\3\2\2\2\u0241\u0242\3\2\2\2\u0242\u0243")
        buf.write("\3\2\2\2\u0243\u0245\5:\36\2\u0244\u0237\3\2\2\2\u0244")
        buf.write("\u023e\3\2\2\2\u0245E\3\2\2\2\u0246\u0247\7:\2\2\u0247")
        buf.write("\u0248\5\\/\2\u0248\u0249\5:\36\2\u0249G\3\2\2\2\u024a")
        buf.write("\u024b\7;\2\2\u024b\u024c\5:\36\2\u024cI\3\2\2\2\u024d")
        buf.write("\u024e\7<\2\2\u024e\u024f\5\\/\2\u024f\u0250\7=\2\2\u0250")
        buf.write("\u0251\5\\/\2\u0251\u0252\7>\2\2\u0252\u0253\5\\/\2\u0253")
        buf.write("\u0254\5:\36\2\u0254\u025c\3\2\2\2\u0255\u0256\7<\2\2")
        buf.write("\u0256\u0257\7d\2\2\u0257\u0258\7O\2\2\u0258\u0259\5\\")
        buf.write("/\2\u0259\u025a\5:\36\2\u025a\u025c\3\2\2\2\u025b\u024d")
        buf.write("\3\2\2\2\u025b\u0255\3\2\2\2\u025cK\3\2\2\2\u025d\u025e")
        buf.write("\7?\2\2\u025e\u025f\5\\/\2\u025f\u0260\5:\36\2\u0260M")
        buf.write("\3\2\2\2\u0261\u0262\t\3\2\2\u0262O\3\2\2\2\u0263\u0264")
        buf.write("\7/\2\2\u0264\u0265\5\\/\2\u0265Q\3\2\2\2\u0266\u0267")
        buf.write("\7E\2\2\u0267\u0268\5\\/\2\u0268\u0269\7\60\2\2\u0269")
        buf.write("S\3\2\2\2\u026a\u026b\7D\2\2\u026b\u026c\5\\/\2\u026c")
        buf.write("\u026d\7\60\2\2\u026d\u0275\3\2\2\2\u026e\u026f\7D\2\2")
        buf.write("\u026f\u0270\7G\2\2\u0270\u0271\7d\2\2\u0271\u0272\7\61")
        buf.write("\2\2\u0272\u0273\7b\2\2\u0273\u0275\7\60\2\2\u0274\u026a")
        buf.write("\3\2\2\2\u0274\u026e\3\2\2\2\u0275U\3\2\2\2\u0276\u027b")
        buf.write("\5X-\2\u0277\u027b\5Z.\2\u0278\u0279\7B\2\2\u0279\u027b")
        buf.write("\7\60\2\2\u027a\u0276\3\2\2\2\u027a\u0277\3\2\2\2\u027a")
        buf.write("\u0278\3\2\2\2\u027bW\3\2\2\2\u027c\u027d\7\27\2\2\u027d")
        buf.write("\u027e\5\\/\2\u027e\u027f\7\60\2\2\u027fY\3\2\2\2\u0280")
        buf.write("\u0281\7\30\2\2\u0281\u0284\5\\/\2\u0282\u0285\7\60\2")
        buf.write("\2\u0283\u0285\5H%\2\u0284\u0282\3\2\2\2\u0284\u0283\3")
        buf.write("\2\2\2\u0285[\3\2\2\2\u0286\u028a\5d\63\2\u0287\u028b")
        buf.write("\5^\60\2\u0288\u028b\5`\61\2\u0289\u028b\5b\62\2\u028a")
        buf.write("\u0287\3\2\2\2\u028a\u0288\3\2\2\2\u028a\u0289\3\2\2\2")
        buf.write("\u028a\u028b\3\2\2\2\u028b]\3\2\2\2\u028c\u028d\7\61\2")
        buf.write("\2\u028d\u028e\5\\/\2\u028e_\3\2\2\2\u028f\u0290\7\66")
        buf.write("\2\2\u0290\u0291\5\\/\2\u0291a\3\2\2\2\u0292\u0293\t\4")
        buf.write("\2\2\u0293\u0294\5\\/\2\u0294c\3\2\2\2\u0295\u029c\5f")
        buf.write("\64\2\u0296\u0298\7H\2\2\u0297\u0296\3\2\2\2\u0297\u0298")
        buf.write("\3\2\2\2\u0298\u0299\3\2\2\2\u0299\u029a\5\u0092J\2\u029a")
        buf.write("\u029b\5\\/\2\u029b\u029d\3\2\2\2\u029c\u0297\3\2\2\2")
        buf.write("\u029c\u029d\3\2\2\2\u029de\3\2\2\2\u029e\u02a3\5h\65")
        buf.write("\2\u029f\u02a0\t\5\2\2\u02a0\u02a2\5h\65\2\u02a1\u029f")
        buf.write("\3\2\2\2\u02a2\u02a5\3\2\2\2\u02a3\u02a1\3\2\2\2\u02a3")
        buf.write("\u02a4\3\2\2\2\u02a4g\3\2\2\2\u02a5\u02a3\3\2\2\2\u02a6")
        buf.write("\u02a7\7H\2\2\u02a7\u02b2\5h\65\2\u02a8\u02ae\5n8\2\u02a9")
        buf.write("\u02aa\5j\66\2\u02aa\u02ab\5n8\2\u02ab\u02ad\3\2\2\2\u02ac")
        buf.write("\u02a9\3\2\2\2\u02ad\u02b0\3\2\2\2\u02ae\u02ac\3\2\2\2")
        buf.write("\u02ae\u02af\3\2\2\2\u02af\u02b2\3\2\2\2\u02b0\u02ae\3")
        buf.write("\2\2\2\u02b1\u02a6\3\2\2\2\u02b1\u02a8\3\2\2\2\u02b2i")
        buf.write("\3\2\2\2\u02b3\u02bc\7I\2\2\u02b4\u02bc\7J\2\2\u02b5\u02bc")
        buf.write("\7K\2\2\u02b6\u02bc\7L\2\2\u02b7\u02bc\7M\2\2\u02b8\u02bc")
        buf.write("\7N\2\2\u02b9\u02bc\7O\2\2\u02ba\u02bc\5l\67\2\u02bb\u02b3")
        buf.write("\3\2\2\2\u02bb\u02b4\3\2\2\2\u02bb\u02b5\3\2\2\2\u02bb")
        buf.write("\u02b6\3\2\2\2\u02bb\u02b7\3\2\2\2\u02bb\u02b8\3\2\2\2")
        buf.write("\u02bb\u02b9\3\2\2\2\u02bb\u02ba\3\2\2\2\u02bck\3\2\2")
        buf.write("\2\u02bd\u02be\7H\2\2\u02be\u02bf\7O\2\2\u02bfm\3\2\2")
        buf.write("\2\u02c0\u02c5\5p9\2\u02c1\u02c2\t\6\2\2\u02c2\u02c4\5")
        buf.write("p9\2\u02c3\u02c1\3\2\2\2\u02c4\u02c7\3\2\2\2\u02c5\u02c3")
        buf.write("\3\2\2\2\u02c5\u02c6\3\2\2\2\u02c6o\3\2\2\2\u02c7\u02c5")
        buf.write("\3\2\2\2\u02c8\u02cd\5r:\2\u02c9\u02ca\t\7\2\2\u02ca\u02cc")
        buf.write("\5r:\2\u02cb\u02c9\3\2\2\2\u02cc\u02cf\3\2\2\2\u02cd\u02cb")
        buf.write("\3\2\2\2\u02cd\u02ce\3\2\2\2\u02ceq\3\2\2\2\u02cf\u02cd")
        buf.write("\3\2\2\2\u02d0\u02d1\t\6\2\2\u02d1\u02d4\5r:\2\u02d2\u02d4")
        buf.write("\5t;\2\u02d3\u02d0\3\2\2\2\u02d3\u02d2\3\2\2\2\u02d4s")
        buf.write("\3\2\2\2\u02d5\u02da\5v<\2\u02d6\u02d7\7Z\2\2\u02d7\u02d9")
        buf.write("\5r:\2\u02d8\u02d6\3\2\2\2\u02d9\u02dc\3\2\2\2\u02da\u02d8")
        buf.write("\3\2\2\2\u02da\u02db\3\2\2\2\u02dbu\3\2\2\2\u02dc\u02da")
        buf.write("\3\2\2\2\u02dd\u02de\b<\1\2\u02de\u02f5\7b\2\2\u02df\u02f5")
        buf.write("\7_\2\2\u02e0\u02f5\7`\2\2\u02e1\u02f5\7a\2\2\u02e2\u02f5")
        buf.write("\7c\2\2\u02e3\u02f5\7d\2\2\u02e4\u02f5\5\u008aF\2\u02e5")
        buf.write("\u02f5\5\u009aN\2\u02e6\u02f5\5\u009eP\2\u02e7\u02e8\7")
        buf.write("[\2\2\u02e8\u02e9\5\\/\2\u02e9\u02ea\7\\\2\2\u02ea\u02f5")
        buf.write("\3\2\2\2\u02eb\u02ec\7%\2\2\u02ec\u02ee\7d\2\2\u02ed\u02ef")
        buf.write("\5\u00acW\2\u02ee\u02ed\3\2\2\2\u02ee\u02ef\3\2\2\2\u02ef")
        buf.write("\u02f5\3\2\2\2\u02f0\u02f5\5\u00a2R\2\u02f1\u02f5\5z>")
        buf.write("\2\u02f2\u02f5\5|?\2\u02f3\u02f5\5\u00b4[\2\u02f4\u02dd")
        buf.write("\3\2\2\2\u02f4\u02df\3\2\2\2\u02f4\u02e0\3\2\2\2\u02f4")
        buf.write("\u02e1\3\2\2\2\u02f4\u02e2\3\2\2\2\u02f4\u02e3\3\2\2\2")
        buf.write("\u02f4\u02e4\3\2\2\2\u02f4\u02e5\3\2\2\2\u02f4\u02e6\3")
        buf.write("\2\2\2\u02f4\u02e7\3\2\2\2\u02f4\u02eb\3\2\2\2\u02f4\u02f0")
        buf.write("\3\2\2\2\u02f4\u02f1\3\2\2\2\u02f4\u02f2\3\2\2\2\u02f4")
        buf.write("\u02f3\3\2\2\2\u02f5\u02fe\3\2\2\2\u02f6\u02f8\f\7\2\2")
        buf.write("\u02f7\u02f9\5x=\2\u02f8\u02f7\3\2\2\2\u02f9\u02fa\3\2")
        buf.write("\2\2\u02fa\u02f8\3\2\2\2\u02fa\u02fb\3\2\2\2\u02fb\u02fd")
        buf.write("\3\2\2\2\u02fc\u02f6\3\2\2\2\u02fd\u0300\3\2\2\2\u02fe")
        buf.write("\u02fc\3\2\2\2\u02fe\u02ff\3\2\2\2\u02ffw\3\2\2\2\u0300")
        buf.write("\u02fe\3\2\2\2\u0301\u0302\7G\2\2\u0302\u0311\5~@\2\u0303")
        buf.write("\u0304\7G\2\2\u0304\u0311\7d\2\2\u0305\u0311\5\u009cO")
        buf.write("\2\u0306\u0308\7[\2\2\u0307\u0309\58\35\2\u0308\u0307")
        buf.write("\3\2\2\2\u0308\u0309\3\2\2\2\u0309\u030a\3\2\2\2\u030a")
        buf.write("\u0311\7\\\2\2\u030b\u030c\7%\2\2\u030c\u030e\7d\2\2\u030d")
        buf.write("\u030f\5\u00acW\2\u030e\u030d\3\2\2\2\u030e\u030f\3\2")
        buf.write("\2\2\u030f\u0311\3\2\2\2\u0310\u0301\3\2\2\2\u0310\u0303")
        buf.write("\3\2\2\2\u0310\u0305\3\2\2\2\u0310\u0306\3\2\2\2\u0310")
        buf.write("\u030b\3\2\2\2\u0311y\3\2\2\2\u0312\u0313\7\4\2\2\u0313")
        buf.write("\u0314\5\\/\2\u0314{\3\2\2\2\u0315\u0316\7W\2\2\u0316")
        buf.write("\u0317\5\\/\2\u0317}\3\2\2\2\u0318\u031f\3\2\2\2\u0319")
        buf.write("\u031f\5\u0088E\2\u031a\u031f\5\u0084C\2\u031b\u031f\5")
        buf.write("\u0086D\2\u031c\u031f\5\u0082B\2\u031d\u031f\5\u0080A")
        buf.write("\2\u031e\u0318\3\2\2\2\u031e\u0319\3\2\2\2\u031e\u031a")
        buf.write("\3\2\2\2\u031e\u031b\3\2\2\2\u031e\u031c\3\2\2\2\u031e")
        buf.write("\u031d\3\2\2\2\u031f\177\3\2\2\2\u0320\u0321\5\u00b4[")
        buf.write("\2\u0321\u0081\3\2\2\2\u0322\u0323\t\b\2\2\u0323\u0083")
        buf.write("\3\2\2\2\u0324\u0336\7\36\2\2\u0325\u0326\7*\2\2\u0326")
        buf.write("\u0327\5\66\34\2\u0327\u0328\7+\2\2\u0328\u0336\3\2\2")
        buf.write("\2\u0329\u032a\7\17\2\2\u032a\u032d\7%\2\2\u032b\u032d")
        buf.write("\7(\2\2\u032c\u0329\3\2\2\2\u032c\u032b\3\2\2\2\u032d")
        buf.write("\u032e\3\2\2\2\u032e\u0333\t\t\2\2\u032f\u0330\7[\2\2")
        buf.write("\u0330\u0331\58\35\2\u0331\u0332\7\\\2\2\u0332\u0334\3")
        buf.write("\2\2\2\u0333\u032f\3\2\2\2\u0333\u0334\3\2\2\2\u0334\u0336")
        buf.write("\3\2\2\2\u0335\u0324\3\2\2\2\u0335\u0325\3\2\2\2\u0335")
        buf.write("\u032c\3\2\2\2\u0336\u0085\3\2\2\2\u0337\u0345\7\35\2")
        buf.write("\2\u0338\u0339\7\16\2\2\u0339\u033c\7%\2\2\u033a\u033c")
        buf.write("\7\'\2\2\u033b\u0338\3\2\2\2\u033b\u033a\3\2\2\2\u033c")
        buf.write("\u033d\3\2\2\2\u033d\u0342\7d\2\2\u033e\u033f\7[\2\2\u033f")
        buf.write("\u0340\58\35\2\u0340\u0341\7\\\2\2\u0341\u0343\3\2\2\2")
        buf.write("\u0342\u033e\3\2\2\2\u0342\u0343\3\2\2\2\u0343\u0345\3")
        buf.write("\2\2\2\u0344\u0337\3\2\2\2\u0344\u033b\3\2\2\2\u0345\u0087")
        buf.write("\3\2\2\2\u0346\u0347\7\13\2\2\u0347\u034a\7%\2\2\u0348")
        buf.write("\u034a\7&\2\2\u0349\u0346\3\2\2\2\u0349\u0348\3\2\2\2")
        buf.write("\u034a\u034b\3\2\2\2\u034b\u0350\7d\2\2\u034c\u034d\7")
        buf.write("[\2\2\u034d\u034e\58\35\2\u034e\u034f\7\\\2\2\u034f\u0351")
        buf.write("\3\2\2\2\u0350\u034c\3\2\2\2\u0350\u0351\3\2\2\2\u0351")
        buf.write("\u0089\3\2\2\2\u0352\u0354\5\u008cG\2\u0353\u0355\5\u00ae")
        buf.write("X\2\u0354\u0353\3\2\2\2\u0354\u0355\3\2\2\2\u0355\u035e")
        buf.write("\3\2\2\2\u0356\u035b\5\u0092J\2\u0357\u0359\5\u008cG\2")
        buf.write("\u0358\u035a\5\u00aeX\2\u0359\u0358\3\2\2\2\u0359\u035a")
        buf.write("\3\2\2\2\u035a\u035c\3\2\2\2\u035b\u0357\3\2\2\2\u035b")
        buf.write("\u035c\3\2\2\2\u035c\u035e\3\2\2\2\u035d\u0352\3\2\2\2")
        buf.write("\u035d\u0356\3\2\2\2\u035e\u008b\3\2\2\2\u035f\u0360\7")
        buf.write("\26\2\2\u0360\u0361\7%\2\2\u0361\u0362\7d\2\2\u0362\u008d")
        buf.write("\3\2\2\2\u0363\u0364\7-\2\2\u0364\u0365\7%\2\2\u0365\u0366")
        buf.write("\7d\2\2\u0366\u008f\3\2\2\2\u0367\u0368\7\22\2\2\u0368")
        buf.write("\u0369\7%\2\2\u0369\u036a\7d\2\2\u036a\u0091\3\2\2\2\u036b")
        buf.write("\u036f\5\u0094K\2\u036c\u036f\5\u0096L\2\u036d\u036f\5")
        buf.write("\u0098M\2\u036e\u036b\3\2\2\2\u036e\u036c\3\2\2\2\u036e")
        buf.write("\u036d\3\2\2\2\u036f\u0093\3\2\2\2\u0370\u037d\7\5\2\2")
        buf.write("\u0371\u0379\7V\2\2\u0372\u0373\7]\2\2\u0373\u0376\7d")
        buf.write("\2\2\u0374\u0377\5\u00acW\2\u0375\u0377\5\u00aeX\2\u0376")
        buf.write("\u0374\3\2\2\2\u0376\u0375\3\2\2\2\u0376\u0377\3\2\2\2")
        buf.write("\u0377\u0378\3\2\2\2\u0378\u037a\7^\2\2\u0379\u0372\3")
        buf.write("\2\2\2\u0379\u037a\3\2\2\2\u037a\u037b\3\2\2\2\u037b\u037d")
        buf.write("\7\6\2\2\u037c\u0370\3\2\2\2\u037c\u0371\3\2\2\2\u037d")
        buf.write("\u0095\3\2\2\2\u037e\u038b\7\7\2\2\u037f\u0387\7\b\2\2")
        buf.write("\u0380\u0381\7]\2\2\u0381\u0384\7d\2\2\u0382\u0385\5\u00ac")
        buf.write("W\2\u0383\u0385\5\u00aeX\2\u0384\u0382\3\2\2\2\u0384\u0383")
        buf.write("\3\2\2\2\u0384\u0385\3\2\2\2\u0385\u0386\3\2\2\2\u0386")
        buf.write("\u0388\7^\2\2\u0387\u0380\3\2\2\2\u0387\u0388\3\2\2\2")
        buf.write("\u0388\u0389\3\2\2\2\u0389\u038b\7V\2\2\u038a\u037e\3")
        buf.write("\2\2\2\u038a\u037f\3\2\2\2\u038b\u0097\3\2\2\2\u038c\u0399")
        buf.write("\7\t\2\2\u038d\u0395\7\b\2\2\u038e\u038f\7]\2\2\u038f")
        buf.write("\u0392\7d\2\2\u0390\u0393\5\u00acW\2\u0391\u0393\5\u00ae")
        buf.write("X\2\u0392\u0390\3\2\2\2\u0392\u0391\3\2\2\2\u0392\u0393")
        buf.write("\3\2\2\2\u0393\u0394\3\2\2\2\u0394\u0396\7^\2\2\u0395")
        buf.write("\u038e\3\2\2\2\u0395\u0396\3\2\2\2\u0396\u0397\3\2\2\2")
        buf.write("\u0397\u0399\7\6\2\2\u0398\u038c\3\2\2\2\u0398\u038d\3")
        buf.write("\2\2\2\u0399\u0099\3\2\2\2\u039a\u039c\7]\2\2\u039b\u039d")
        buf.write("\58\35\2\u039c\u039b\3\2\2\2\u039c\u039d\3\2\2\2\u039d")
        buf.write("\u039e\3\2\2\2\u039e\u039f\7^\2\2\u039f\u009b\3\2\2\2")
        buf.write("\u03a0\u03a1\7]\2\2\u03a1\u03a2\5\\/\2\u03a2\u03a3\7^")
        buf.write("\2\2\u03a3\u03ab\3\2\2\2\u03a4\u03a5\7]\2\2\u03a5\u03a6")
        buf.write("\5\\/\2\u03a6\u03a7\7$\2\2\u03a7\u03a8\5\\/\2\u03a8\u03a9")
        buf.write("\7^\2\2\u03a9\u03ab\3\2\2\2\u03aa\u03a0\3\2\2\2\u03aa")
        buf.write("\u03a4\3\2\2\2\u03ab\u009d\3\2\2\2\u03ac\u03b5\7*\2\2")
        buf.write("\u03ad\u03b2\5\u00a0Q\2\u03ae\u03af\7S\2\2\u03af\u03b1")
        buf.write("\5\u00a0Q\2\u03b0\u03ae\3\2\2\2\u03b1\u03b4\3\2\2\2\u03b2")
        buf.write("\u03b0\3\2\2\2\u03b2\u03b3\3\2\2\2\u03b3\u03b6\3\2\2\2")
        buf.write("\u03b4\u03b2\3\2\2\2\u03b5\u03ad\3\2\2\2\u03b5\u03b6\3")
        buf.write("\2\2\2\u03b6\u03b7\3\2\2\2\u03b7\u03b8\7+\2\2\u03b8\u009f")
        buf.write("\3\2\2\2\u03b9\u03ba\7`\2\2\u03ba\u03bb\7$\2\2\u03bb\u03bc")
        buf.write("\5\\/\2\u03bc\u00a1\3\2\2\2\u03bd\u03bf\7\31\2\2\u03be")
        buf.write("\u03c0\5\\/\2\u03bf\u03be\3\2\2\2\u03bf\u03c0\3\2\2\2")
        buf.write("\u03c0\u03c1\3\2\2\2\u03c1\u03c2\5\u00a4S\2\u03c2\u00a3")
        buf.write("\3\2\2\2\u03c3\u03c7\5\u00a6T\2\u03c4\u03c7\5\u00aaV\2")
        buf.write("\u03c5\u03c7\5\u00a8U\2\u03c6\u03c3\3\2\2\2\u03c6\u03c4")
        buf.write("\3\2\2\2\u03c6\u03c5\3\2\2\2\u03c7\u00a5\3\2\2\2\u03c8")
        buf.write("\u03ca\5\u0092J\2\u03c9\u03c8\3\2\2\2\u03c9\u03ca\3\2")
        buf.write("\2\2\u03ca\u03cb\3\2\2\2\u03cb\u03cd\5\u008cG\2\u03cc")
        buf.write("\u03ce\5\u00acW\2\u03cd\u03cc\3\2\2\2\u03cd\u03ce\3\2")
        buf.write("\2\2\u03ce\u00a7\3\2\2\2\u03cf\u03d1\5\u0092J\2\u03d0")
        buf.write("\u03cf\3\2\2\2\u03d0\u03d1\3\2\2\2\u03d1\u03d2\3\2\2\2")
        buf.write("\u03d2\u03d3\5\u0090I\2\u03d3\u00a9\3\2\2\2\u03d4\u03d6")
        buf.write("\5\u008eH\2\u03d5\u03d7\5\u00acW\2\u03d6\u03d5\3\2\2\2")
        buf.write("\u03d6\u03d7\3\2\2\2\u03d7\u00ab\3\2\2\2\u03d8\u03e1\7")
        buf.write("[\2\2\u03d9\u03de\5\u00b0Y\2\u03da\u03db\7S\2\2\u03db")
        buf.write("\u03dd\5\u00b0Y\2\u03dc\u03da\3\2\2\2\u03dd\u03e0\3\2")
        buf.write("\2\2\u03de\u03dc\3\2\2\2\u03de\u03df\3\2\2\2\u03df\u03e2")
        buf.write("\3\2\2\2\u03e0\u03de\3\2\2\2\u03e1\u03d9\3\2\2\2\u03e1")
        buf.write("\u03e2\3\2\2\2\u03e2\u03e3\3\2\2\2\u03e3\u03e4\7\\\2\2")
        buf.write("\u03e4\u00ad\3\2\2\2\u03e5\u03ee\7[\2\2\u03e6\u03eb\5")
        buf.write("\u00b2Z\2\u03e7\u03e8\7S\2\2\u03e8\u03ea\5\u00b2Z\2\u03e9")
        buf.write("\u03e7\3\2\2\2\u03ea\u03ed\3\2\2\2\u03eb\u03e9\3\2\2\2")
        buf.write("\u03eb\u03ec\3\2\2\2\u03ec\u03ef\3\2\2\2\u03ed\u03eb\3")
        buf.write("\2\2\2\u03ee\u03e6\3\2\2\2\u03ee\u03ef\3\2\2\2\u03ef\u03f0")
        buf.write("\3\2\2\2\u03f0\u03f1\7\\\2\2\u03f1\u00af\3\2\2\2\u03f2")
        buf.write("\u03f3\7d\2\2\u03f3\u03f4\7\61\2\2\u03f4\u03f5\5\\/\2")
        buf.write("\u03f5\u00b1\3\2\2\2\u03f6\u03f7\7d\2\2\u03f7\u03f8\5")
        buf.write("j\66\2\u03f8\u03f9\5\\/\2\u03f9\u00b3\3\2\2\2\u03fa\u03fb")
        buf.write("\t\n\2\2\u03fb\u00b5\3\2\2\2\u03fc\u03fe\7\23\2\2\u03fd")
        buf.write("\u03fc\3\2\2\2\u03fd\u03fe\3\2\2\2\u03fe\u03ff\3\2\2\2")
        buf.write("\u03ff\u0401\t\13\2\2\u0400\u0402\5\u00d0i\2\u0401\u0400")
        buf.write("\3\2\2\2\u0401\u0402\3\2\2\2\u0402\u0403\3\2\2\2\u0403")
        buf.write("\u0404\7*\2\2\u0404\u0405\5\u00b8]\2\u0405\u0406\7+\2")
        buf.write("\2\u0406\u00b7\3\2\2\2\u0407\u0409\5\u00ba^\2\u0408\u040a")
        buf.write("\7\60\2\2\u0409\u0408\3\2\2\2\u0409\u040a\3\2\2\2\u040a")
        buf.write("\u040c\3\2\2\2\u040b\u0407\3\2\2\2\u040c\u040f\3\2\2\2")
        buf.write("\u040d\u040b\3\2\2\2\u040d\u040e\3\2\2\2\u040e\u00b9\3")
        buf.write("\2\2\2\u040f\u040d\3\2\2\2\u0410\u0419\5\u00c8e\2\u0411")
        buf.write("\u0419\5\u00c2b\2\u0412\u0419\5\u00bc_\2\u0413\u0414\5")
        buf.write("\u00d0i\2\u0414\u0415\7\61\2\2\u0415\u0416\5\u00d0i\2")
        buf.write("\u0416\u0419\3\2\2\2\u0417\u0419\5\u00ceh\2\u0418\u0410")
        buf.write("\3\2\2\2\u0418\u0411\3\2\2\2\u0418\u0412\3\2\2\2\u0418")
        buf.write("\u0413\3\2\2\2\u0418\u0417\3\2\2\2\u0419\u00bb\3\2\2\2")
        buf.write("\u041a\u041b\t\f\2\2\u041b\u041c\5\u00be`\2\u041c\u00bd")
        buf.write("\3\2\2\2\u041d\u041f\7]\2\2\u041e\u0420\5\u00c0a\2\u041f")
        buf.write("\u041e\3\2\2\2\u041f\u0420\3\2\2\2\u0420\u0421\3\2\2\2")
        buf.write("\u0421\u0423\7^\2\2\u0422\u041d\3\2\2\2\u0423\u0424\3")
        buf.write("\2\2\2\u0424\u0422\3\2\2\2\u0424\u0425\3\2\2\2\u0425\u00bf")
        buf.write("\3\2\2\2\u0426\u0429\5\u00d0i\2\u0427\u0428\7\61\2\2\u0428")
        buf.write("\u042a\5\u00d0i\2\u0429\u0427\3\2\2\2\u0429\u042a\3\2")
        buf.write("\2\2\u042a\u042c\3\2\2\2\u042b\u042d\7S\2\2\u042c\u042b")
        buf.write("\3\2\2\2\u042c\u042d\3\2\2\2\u042d\u042f\3\2\2\2\u042e")
        buf.write("\u0426\3\2\2\2\u042f\u0430\3\2\2\2\u0430\u042e\3\2\2\2")
        buf.write("\u0430\u0431\3\2\2\2\u0431\u00c1\3\2\2\2\u0432\u0435\5")
        buf.write("\u00caf\2\u0433\u0435\5\u00ceh\2\u0434\u0432\3\2\2\2\u0434")
        buf.write("\u0433\3\2\2\2\u0435\u0436\3\2\2\2\u0436\u0438\5\u00c4")
        buf.write("c\2\u0437\u0439\5\u00be`\2\u0438\u0437\3\2\2\2\u0438\u0439")
        buf.write("\3\2\2\2\u0439\u00c3\3\2\2\2\u043a\u043d\5\u00c6d\2\u043b")
        buf.write("\u043e\5\u00caf\2\u043c\u043e\5\u00ceh\2\u043d\u043b\3")
        buf.write("\2\2\2\u043d\u043c\3\2\2\2\u043e\u0440\3\2\2\2\u043f\u043a")
        buf.write("\3\2\2\2\u0440\u0441\3\2\2\2\u0441\u043f\3\2\2\2\u0441")
        buf.write("\u0442\3\2\2\2\u0442\u00c5\3\2\2\2\u0443\u0444\t\r\2\2")
        buf.write("\u0444\u00c7\3\2\2\2\u0445\u0447\5\u00caf\2\u0446\u0448")
        buf.write("\5\u00be`\2\u0447\u0446\3\2\2\2\u0447\u0448\3\2\2\2\u0448")
        buf.write("\u00c9\3\2\2\2\u0449\u044b\5\u00d0i\2\u044a\u044c\5\u00cc")
        buf.write("g\2\u044b\u044a\3\2\2\2\u044b\u044c\3\2\2\2\u044c\u00cb")
        buf.write("\3\2\2\2\u044d\u044e\7$\2\2\u044e\u0451\5\u00d0i\2\u044f")
        buf.write("\u0450\7$\2\2\u0450\u0452\5\u00d0i\2\u0451\u044f\3\2\2")
        buf.write("\2\u0451\u0452\3\2\2\2\u0452\u00cd\3\2\2\2\u0453\u0455")
        buf.write("\7\25\2\2\u0454\u0456\5\u00d0i\2\u0455\u0454\3\2\2\2\u0455")
        buf.write("\u0456\3\2\2\2\u0456\u0458\3\2\2\2\u0457\u0453\3\2\2\2")
        buf.write("\u0457\u0458\3\2\2\2\u0458\u0459\3\2\2\2\u0459\u045a\7")
        buf.write("*\2\2\u045a\u045b\5\u00b8]\2\u045b\u045c\7+\2\2\u045c")
        buf.write("\u00cf\3\2\2\2\u045d\u045e\t\16\2\2\u045e\u00d1\3\2\2")
        buf.write("\2\u0089\u00d3\u00d8\u00de\u00e7\u00f2\u00f7\u00fb\u0100")
        buf.write("\u0104\u0109\u010d\u0112\u0116\u0118\u0121\u0126\u012c")
        buf.write("\u0135\u013a\u0142\u0146\u014a\u014c\u0150\u015a\u015f")
        buf.write("\u0163\u0167\u017c\u0183\u0187\u018b\u0199\u01a5\u01ae")
        buf.write("\u01b1\u01b8\u01c1\u01c8\u01cf\u01d3\u01db\u01de\u01e2")
        buf.write("\u01e8\u01ed\u01f8\u0200\u0207\u020d\u0224\u022c\u0230")
        buf.write("\u0235\u023b\u0241\u0244\u025b\u0274\u027a\u0284\u028a")
        buf.write("\u0297\u029c\u02a3\u02ae\u02b1\u02bb\u02c5\u02cd\u02d3")
        buf.write("\u02da\u02ee\u02f4\u02fa\u02fe\u0308\u030e\u0310\u031e")
        buf.write("\u032c\u0333\u0335\u033b\u0342\u0344\u0349\u0350\u0354")
        buf.write("\u0359\u035b\u035d\u036e\u0376\u0379\u037c\u0384\u0387")
        buf.write("\u038a\u0392\u0395\u0398\u039c\u03aa\u03b2\u03b5\u03bf")
        buf.write("\u03c6\u03c9\u03cd\u03d0\u03d6\u03de\u03e1\u03eb\u03ee")
        buf.write("\u03fd\u0401\u0409\u040d\u0418\u041f\u0424\u0429\u042c")
        buf.write("\u0430\u0434\u0438\u043d\u0441\u0447\u044b\u0451\u0455")
        buf.write("\u0457")
        return buf.getvalue()


class jacParser ( Parser ):

    grammarFileName = "jac.g4"

    atn = ATNDeserializer().deserialize(serializedATN())

    decisionsToDFA = [ DFA(ds, i) for i, ds in enumerate(atn.decisionToState) ]

    sharedContextCache = PredictionContextCache()

    literalNames = [ "<INVALID>", "'version'", "'&'", "'-->'", "'->'", "'<--'", 
                     "'<-'", "'<-->'", "'--'", "'str'", "'int'", "'float'", 
                     "'list'", "'dict'", "'bool'", "'type'", "'graph'", 
                     "'strict'", "'digraph'", "'subgraph'", "'node'", "'ignore'", 
                     "'take'", "'spawn'", "'with'", "'entry'", "'exit'", 
                     "'length'", "'keys'", "'context'", "'info'", "'details'", 
                     "'activity'", "'import'", "':'", "'::'", "'s::'", "'l::'", 
                     "'d::'", "'::>'", "'{'", "'}'", "'edge'", "'walker'", 
                     "'test'", "'assert'", "';'", "'='", "'+='", "'-='", 
                     "'*='", "'/='", "':='", "<INVALID>", "<INVALID>", "'if'", 
                     "'elif'", "'else'", "'for'", "'to'", "'by'", "'while'", 
                     "'continue'", "'break'", "'disengage'", "'skip'", "'report'", 
                     "'destroy'", "'try'", "'.'", "<INVALID>", "'=='", "'<'", 
                     "'>'", "'<='", "'>='", "'!='", "'in'", "'anchor'", 
                     "'has'", "'private'", "','", "'can'", "'+'", "'-'", 
                     "'*'", "'/'", "'%'", "'^'", "'('", "')'", "'['", "']'", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "'null'" ]

    symbolicNames = [ "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                      "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                      "<INVALID>", "TYP_STRING", "TYP_INT", "TYP_FLOAT", 
                      "TYP_LIST", "TYP_DICT", "TYP_BOOL", "KW_TYPE", "KW_GRAPH", 
                      "KW_STRICT", "KW_DIGRAPH", "KW_SUBGRAPH", "KW_NODE", 
                      "KW_IGNORE", "KW_TAKE", "KW_SPAWN", "KW_WITH", "KW_ENTRY", 
                      "KW_EXIT", "KW_LENGTH", "KW_KEYS", "KW_CONTEXT", "KW_INFO", 
                      "KW_DETAILS", "KW_ACTIVITY", "KW_IMPORT", "COLON", 
                      "DBL_COLON", "STR_DBL_COLON", "LIST_DBL_COLON", "DICT_DBL_COLON", 
                      "COLON_OUT", "LBRACE", "RBRACE", "KW_EDGE", "KW_WALKER", 
                      "KW_TEST", "KW_ASSERT", "SEMI", "EQ", "PEQ", "MEQ", 
                      "TEQ", "DEQ", "CPY_EQ", "KW_AND", "KW_OR", "KW_IF", 
                      "KW_ELIF", "KW_ELSE", "KW_FOR", "KW_TO", "KW_BY", 
                      "KW_WHILE", "KW_CONTINUE", "KW_BREAK", "KW_DISENGAGE", 
                      "KW_SKIP", "KW_REPORT", "KW_DESTROY", "KW_TRY", "DOT", 
                      "NOT", "EE", "LT", "GT", "LTE", "GTE", "NE", "KW_IN", 
                      "KW_ANCHOR", "KW_HAS", "KW_PRIVATE", "COMMA", "KW_CAN", 
                      "PLUS", "MINUS", "STAR_MUL", "DIV", "MOD", "POW", 
                      "LPAREN", "RPAREN", "LSQUARE", "RSQUARE", "FLOAT", 
                      "STRING", "BOOL", "INT", "NULL", "NAME", "COMMENT", 
                      "LINE_COMMENT", "PY_COMMENT", "WS", "ErrorChar" ]

    RULE_start = 0
    RULE_import_module = 1
    RULE_ver_label = 2
    RULE_import_items = 3
    RULE_import_names = 4
    RULE_element = 5
    RULE_architype = 6
    RULE_walker = 7
    RULE_walker_block = 8
    RULE_test = 9
    RULE_namespaces = 10
    RULE_walk_entry_block = 11
    RULE_walk_exit_block = 12
    RULE_walk_activity_block = 13
    RULE_attr_block = 14
    RULE_attr_stmt = 15
    RULE_graph_block = 16
    RULE_graph_block_spawn = 17
    RULE_graph_block_dot = 18
    RULE_has_root = 19
    RULE_has_stmt = 20
    RULE_has_assign = 21
    RULE_can_stmt = 22
    RULE_event_clause = 23
    RULE_preset_in_out = 24
    RULE_dotted_name = 25
    RULE_name_list = 26
    RULE_expr_list = 27
    RULE_code_block = 28
    RULE_node_ctx_block = 29
    RULE_statement = 30
    RULE_if_stmt = 31
    RULE_try_stmt = 32
    RULE_else_from_try = 33
    RULE_elif_stmt = 34
    RULE_else_stmt = 35
    RULE_for_stmt = 36
    RULE_while_stmt = 37
    RULE_ctrl_stmt = 38
    RULE_assert_stmt = 39
    RULE_destroy_action = 40
    RULE_report_action = 41
    RULE_walker_action = 42
    RULE_ignore_action = 43
    RULE_take_action = 44
    RULE_expression = 45
    RULE_assignment = 46
    RULE_copy_assign = 47
    RULE_inc_assign = 48
    RULE_connect = 49
    RULE_logical = 50
    RULE_compare = 51
    RULE_cmp_op = 52
    RULE_nin = 53
    RULE_arithmetic = 54
    RULE_term = 55
    RULE_factor = 56
    RULE_power = 57
    RULE_atom = 58
    RULE_atom_trailer = 59
    RULE_ref = 60
    RULE_deref = 61
    RULE_built_in = 62
    RULE_cast_built_in = 63
    RULE_obj_built_in = 64
    RULE_dict_built_in = 65
    RULE_list_built_in = 66
    RULE_string_built_in = 67
    RULE_node_edge_ref = 68
    RULE_node_ref = 69
    RULE_walker_ref = 70
    RULE_graph_ref = 71
    RULE_edge_ref = 72
    RULE_edge_to = 73
    RULE_edge_from = 74
    RULE_edge_any = 75
    RULE_list_val = 76
    RULE_index_slice = 77
    RULE_dict_val = 78
    RULE_kv_pair = 79
    RULE_spawn = 80
    RULE_spawn_object = 81
    RULE_node_spawn = 82
    RULE_graph_spawn = 83
    RULE_walker_spawn = 84
    RULE_spawn_ctx = 85
    RULE_filter_ctx = 86
    RULE_spawn_assign = 87
    RULE_filter_compare = 88
    RULE_any_type = 89
    RULE_dot_graph = 90
    RULE_dot_stmt_list = 91
    RULE_dot_stmt = 92
    RULE_dot_attr_stmt = 93
    RULE_dot_attr_list = 94
    RULE_dot_a_list = 95
    RULE_dot_edge_stmt = 96
    RULE_dot_edgeRHS = 97
    RULE_dot_edgeop = 98
    RULE_dot_node_stmt = 99
    RULE_dot_node_id = 100
    RULE_dot_port = 101
    RULE_dot_subgraph = 102
    RULE_dot_id = 103

    ruleNames =  [ "start", "import_module", "ver_label", "import_items", 
                   "import_names", "element", "architype", "walker", "walker_block", 
                   "test", "namespaces", "walk_entry_block", "walk_exit_block", 
                   "walk_activity_block", "attr_block", "attr_stmt", "graph_block", 
                   "graph_block_spawn", "graph_block_dot", "has_root", "has_stmt", 
                   "has_assign", "can_stmt", "event_clause", "preset_in_out", 
                   "dotted_name", "name_list", "expr_list", "code_block", 
                   "node_ctx_block", "statement", "if_stmt", "try_stmt", 
                   "else_from_try", "elif_stmt", "else_stmt", "for_stmt", 
                   "while_stmt", "ctrl_stmt", "assert_stmt", "destroy_action", 
                   "report_action", "walker_action", "ignore_action", "take_action", 
                   "expression", "assignment", "copy_assign", "inc_assign", 
                   "connect", "logical", "compare", "cmp_op", "nin", "arithmetic", 
                   "term", "factor", "power", "atom", "atom_trailer", "ref", 
                   "deref", "built_in", "cast_built_in", "obj_built_in", 
                   "dict_built_in", "list_built_in", "string_built_in", 
                   "node_edge_ref", "node_ref", "walker_ref", "graph_ref", 
                   "edge_ref", "edge_to", "edge_from", "edge_any", "list_val", 
                   "index_slice", "dict_val", "kv_pair", "spawn", "spawn_object", 
                   "node_spawn", "graph_spawn", "walker_spawn", "spawn_ctx", 
                   "filter_ctx", "spawn_assign", "filter_compare", "any_type", 
                   "dot_graph", "dot_stmt_list", "dot_stmt", "dot_attr_stmt", 
                   "dot_attr_list", "dot_a_list", "dot_edge_stmt", "dot_edgeRHS", 
                   "dot_edgeop", "dot_node_stmt", "dot_node_id", "dot_port", 
                   "dot_subgraph", "dot_id" ]

    EOF = Token.EOF
    T__0=1
    T__1=2
    T__2=3
    T__3=4
    T__4=5
    T__5=6
    T__6=7
    T__7=8
    TYP_STRING=9
    TYP_INT=10
    TYP_FLOAT=11
    TYP_LIST=12
    TYP_DICT=13
    TYP_BOOL=14
    KW_TYPE=15
    KW_GRAPH=16
    KW_STRICT=17
    KW_DIGRAPH=18
    KW_SUBGRAPH=19
    KW_NODE=20
    KW_IGNORE=21
    KW_TAKE=22
    KW_SPAWN=23
    KW_WITH=24
    KW_ENTRY=25
    KW_EXIT=26
    KW_LENGTH=27
    KW_KEYS=28
    KW_CONTEXT=29
    KW_INFO=30
    KW_DETAILS=31
    KW_ACTIVITY=32
    KW_IMPORT=33
    COLON=34
    DBL_COLON=35
    STR_DBL_COLON=36
    LIST_DBL_COLON=37
    DICT_DBL_COLON=38
    COLON_OUT=39
    LBRACE=40
    RBRACE=41
    KW_EDGE=42
    KW_WALKER=43
    KW_TEST=44
    KW_ASSERT=45
    SEMI=46
    EQ=47
    PEQ=48
    MEQ=49
    TEQ=50
    DEQ=51
    CPY_EQ=52
    KW_AND=53
    KW_OR=54
    KW_IF=55
    KW_ELIF=56
    KW_ELSE=57
    KW_FOR=58
    KW_TO=59
    KW_BY=60
    KW_WHILE=61
    KW_CONTINUE=62
    KW_BREAK=63
    KW_DISENGAGE=64
    KW_SKIP=65
    KW_REPORT=66
    KW_DESTROY=67
    KW_TRY=68
    DOT=69
    NOT=70
    EE=71
    LT=72
    GT=73
    LTE=74
    GTE=75
    NE=76
    KW_IN=77
    KW_ANCHOR=78
    KW_HAS=79
    KW_PRIVATE=80
    COMMA=81
    KW_CAN=82
    PLUS=83
    MINUS=84
    STAR_MUL=85
    DIV=86
    MOD=87
    POW=88
    LPAREN=89
    RPAREN=90
    LSQUARE=91
    RSQUARE=92
    FLOAT=93
    STRING=94
    BOOL=95
    INT=96
    NULL=97
    NAME=98
    COMMENT=99
    LINE_COMMENT=100
    PY_COMMENT=101
    WS=102
    ErrorChar=103

    def __init__(self, input:TokenStream, output:TextIO = sys.stdout):
        super().__init__(input, output)
        self.checkVersion("4.9.2")
        self._interp = ParserATNSimulator(self, self.atn, self.decisionsToDFA, self.sharedContextCache)
        self._predicates = None




    class StartContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def EOF(self):
            return self.getToken(jacParser.EOF, 0)

        def ver_label(self):
            return self.getTypedRuleContext(jacParser.Ver_labelContext,0)


        def import_module(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(jacParser.Import_moduleContext)
            else:
                return self.getTypedRuleContext(jacParser.Import_moduleContext,i)


        def element(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(jacParser.ElementContext)
            else:
                return self.getTypedRuleContext(jacParser.ElementContext,i)


        def getRuleIndex(self):
            return jacParser.RULE_start

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterStart" ):
                listener.enterStart(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitStart" ):
                listener.exitStart(self)




    def start(self):

        localctx = jacParser.StartContext(self, self._ctx, self.state)
        self.enterRule(localctx, 0, self.RULE_start)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 209
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==jacParser.T__0:
                self.state = 208
                self.ver_label()


            self.state = 214
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==jacParser.KW_IMPORT:
                self.state = 211
                self.import_module()
                self.state = 216
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 220
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while (((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << jacParser.KW_GRAPH) | (1 << jacParser.KW_NODE) | (1 << jacParser.KW_EDGE) | (1 << jacParser.KW_WALKER) | (1 << jacParser.KW_TEST))) != 0):
                self.state = 217
                self.element()
                self.state = 222
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 223
            self.match(jacParser.EOF)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Import_moduleContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def KW_IMPORT(self):
            return self.getToken(jacParser.KW_IMPORT, 0)

        def LBRACE(self):
            return self.getToken(jacParser.LBRACE, 0)

        def RBRACE(self):
            return self.getToken(jacParser.RBRACE, 0)

        def KW_WITH(self):
            return self.getToken(jacParser.KW_WITH, 0)

        def STRING(self):
            return self.getToken(jacParser.STRING, 0)

        def SEMI(self):
            return self.getToken(jacParser.SEMI, 0)

        def import_items(self):
            return self.getTypedRuleContext(jacParser.Import_itemsContext,0)


        def STAR_MUL(self):
            return self.getToken(jacParser.STAR_MUL, 0)

        def getRuleIndex(self):
            return jacParser.RULE_import_module

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterImport_module" ):
                listener.enterImport_module(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitImport_module" ):
                listener.exitImport_module(self)




    def import_module(self):

        localctx = jacParser.Import_moduleContext(self, self._ctx, self.state)
        self.enterRule(localctx, 2, self.RULE_import_module)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 225
            self.match(jacParser.KW_IMPORT)
            self.state = 226
            self.match(jacParser.LBRACE)
            self.state = 229
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [jacParser.KW_GRAPH, jacParser.KW_NODE, jacParser.KW_EDGE, jacParser.KW_WALKER]:
                self.state = 227
                self.import_items()
                pass
            elif token in [jacParser.STAR_MUL]:
                self.state = 228
                self.match(jacParser.STAR_MUL)
                pass
            else:
                raise NoViableAltException(self)

            self.state = 231
            self.match(jacParser.RBRACE)
            self.state = 232
            self.match(jacParser.KW_WITH)
            self.state = 233
            self.match(jacParser.STRING)
            self.state = 234
            self.match(jacParser.SEMI)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Ver_labelContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def COLON(self):
            return self.getToken(jacParser.COLON, 0)

        def STRING(self):
            return self.getToken(jacParser.STRING, 0)

        def SEMI(self):
            return self.getToken(jacParser.SEMI, 0)

        def getRuleIndex(self):
            return jacParser.RULE_ver_label

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterVer_label" ):
                listener.enterVer_label(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitVer_label" ):
                listener.exitVer_label(self)




    def ver_label(self):

        localctx = jacParser.Ver_labelContext(self, self._ctx, self.state)
        self.enterRule(localctx, 4, self.RULE_ver_label)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 236
            self.match(jacParser.T__0)
            self.state = 237
            self.match(jacParser.COLON)
            self.state = 238
            self.match(jacParser.STRING)
            self.state = 240
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==jacParser.SEMI:
                self.state = 239
                self.match(jacParser.SEMI)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Import_itemsContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def KW_WALKER(self):
            return self.getToken(jacParser.KW_WALKER, 0)

        def STAR_MUL(self):
            return self.getToken(jacParser.STAR_MUL, 0)

        def import_names(self):
            return self.getTypedRuleContext(jacParser.Import_namesContext,0)


        def COMMA(self):
            return self.getToken(jacParser.COMMA, 0)

        def import_items(self):
            return self.getTypedRuleContext(jacParser.Import_itemsContext,0)


        def KW_NODE(self):
            return self.getToken(jacParser.KW_NODE, 0)

        def KW_EDGE(self):
            return self.getToken(jacParser.KW_EDGE, 0)

        def KW_GRAPH(self):
            return self.getToken(jacParser.KW_GRAPH, 0)

        def getRuleIndex(self):
            return jacParser.RULE_import_items

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterImport_items" ):
                listener.enterImport_items(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitImport_items" ):
                listener.exitImport_items(self)




    def import_items(self):

        localctx = jacParser.Import_itemsContext(self, self._ctx, self.state)
        self.enterRule(localctx, 6, self.RULE_import_items)
        self._la = 0 # Token type
        try:
            self.state = 278
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [jacParser.KW_WALKER]:
                self.enterOuterAlt(localctx, 1)
                self.state = 242
                self.match(jacParser.KW_WALKER)
                self.state = 245
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [jacParser.STAR_MUL]:
                    self.state = 243
                    self.match(jacParser.STAR_MUL)
                    pass
                elif token in [jacParser.DBL_COLON]:
                    self.state = 244
                    self.import_names()
                    pass
                else:
                    raise NoViableAltException(self)

                self.state = 249
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==jacParser.COMMA:
                    self.state = 247
                    self.match(jacParser.COMMA)
                    self.state = 248
                    self.import_items()


                pass
            elif token in [jacParser.KW_NODE]:
                self.enterOuterAlt(localctx, 2)
                self.state = 251
                self.match(jacParser.KW_NODE)
                self.state = 254
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [jacParser.STAR_MUL]:
                    self.state = 252
                    self.match(jacParser.STAR_MUL)
                    pass
                elif token in [jacParser.DBL_COLON]:
                    self.state = 253
                    self.import_names()
                    pass
                else:
                    raise NoViableAltException(self)

                self.state = 258
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==jacParser.COMMA:
                    self.state = 256
                    self.match(jacParser.COMMA)
                    self.state = 257
                    self.import_items()


                pass
            elif token in [jacParser.KW_EDGE]:
                self.enterOuterAlt(localctx, 3)
                self.state = 260
                self.match(jacParser.KW_EDGE)
                self.state = 263
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [jacParser.STAR_MUL]:
                    self.state = 261
                    self.match(jacParser.STAR_MUL)
                    pass
                elif token in [jacParser.DBL_COLON]:
                    self.state = 262
                    self.import_names()
                    pass
                else:
                    raise NoViableAltException(self)

                self.state = 267
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==jacParser.COMMA:
                    self.state = 265
                    self.match(jacParser.COMMA)
                    self.state = 266
                    self.import_items()


                pass
            elif token in [jacParser.KW_GRAPH]:
                self.enterOuterAlt(localctx, 4)
                self.state = 269
                self.match(jacParser.KW_GRAPH)
                self.state = 272
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [jacParser.STAR_MUL]:
                    self.state = 270
                    self.match(jacParser.STAR_MUL)
                    pass
                elif token in [jacParser.DBL_COLON]:
                    self.state = 271
                    self.import_names()
                    pass
                else:
                    raise NoViableAltException(self)

                self.state = 276
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==jacParser.COMMA:
                    self.state = 274
                    self.match(jacParser.COMMA)
                    self.state = 275
                    self.import_items()


                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Import_namesContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def DBL_COLON(self):
            return self.getToken(jacParser.DBL_COLON, 0)

        def NAME(self):
            return self.getToken(jacParser.NAME, 0)

        def LBRACE(self):
            return self.getToken(jacParser.LBRACE, 0)

        def name_list(self):
            return self.getTypedRuleContext(jacParser.Name_listContext,0)


        def RBRACE(self):
            return self.getToken(jacParser.RBRACE, 0)

        def getRuleIndex(self):
            return jacParser.RULE_import_names

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterImport_names" ):
                listener.enterImport_names(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitImport_names" ):
                listener.exitImport_names(self)




    def import_names(self):

        localctx = jacParser.Import_namesContext(self, self._ctx, self.state)
        self.enterRule(localctx, 8, self.RULE_import_names)
        try:
            self.state = 287
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,14,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 280
                self.match(jacParser.DBL_COLON)
                self.state = 281
                self.match(jacParser.NAME)
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 282
                self.match(jacParser.DBL_COLON)
                self.state = 283
                self.match(jacParser.LBRACE)
                self.state = 284
                self.name_list()
                self.state = 285
                self.match(jacParser.RBRACE)
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ElementContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def architype(self):
            return self.getTypedRuleContext(jacParser.ArchitypeContext,0)


        def walker(self):
            return self.getTypedRuleContext(jacParser.WalkerContext,0)


        def test(self):
            return self.getTypedRuleContext(jacParser.TestContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_element

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterElement" ):
                listener.enterElement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitElement" ):
                listener.exitElement(self)




    def element(self):

        localctx = jacParser.ElementContext(self, self._ctx, self.state)
        self.enterRule(localctx, 10, self.RULE_element)
        try:
            self.state = 292
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [jacParser.KW_GRAPH, jacParser.KW_NODE, jacParser.KW_EDGE]:
                self.enterOuterAlt(localctx, 1)
                self.state = 289
                self.architype()
                pass
            elif token in [jacParser.KW_WALKER]:
                self.enterOuterAlt(localctx, 2)
                self.state = 290
                self.walker()
                pass
            elif token in [jacParser.KW_TEST]:
                self.enterOuterAlt(localctx, 3)
                self.state = 291
                self.test()
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ArchitypeContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def KW_NODE(self):
            return self.getToken(jacParser.KW_NODE, 0)

        def NAME(self):
            return self.getToken(jacParser.NAME, 0)

        def attr_block(self):
            return self.getTypedRuleContext(jacParser.Attr_blockContext,0)


        def COLON(self):
            return self.getToken(jacParser.COLON, 0)

        def INT(self):
            return self.getToken(jacParser.INT, 0)

        def KW_EDGE(self):
            return self.getToken(jacParser.KW_EDGE, 0)

        def KW_GRAPH(self):
            return self.getToken(jacParser.KW_GRAPH, 0)

        def graph_block(self):
            return self.getTypedRuleContext(jacParser.Graph_blockContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_architype

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterArchitype" ):
                listener.enterArchitype(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitArchitype" ):
                listener.exitArchitype(self)




    def architype(self):

        localctx = jacParser.ArchitypeContext(self, self._ctx, self.state)
        self.enterRule(localctx, 12, self.RULE_architype)
        try:
            self.state = 307
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [jacParser.KW_NODE]:
                self.enterOuterAlt(localctx, 1)
                self.state = 294
                self.match(jacParser.KW_NODE)
                self.state = 295
                self.match(jacParser.NAME)
                self.state = 298
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,16,self._ctx)
                if la_ == 1:
                    self.state = 296
                    self.match(jacParser.COLON)
                    self.state = 297
                    self.match(jacParser.INT)


                self.state = 300
                self.attr_block()
                pass
            elif token in [jacParser.KW_EDGE]:
                self.enterOuterAlt(localctx, 2)
                self.state = 301
                self.match(jacParser.KW_EDGE)
                self.state = 302
                self.match(jacParser.NAME)
                self.state = 303
                self.attr_block()
                pass
            elif token in [jacParser.KW_GRAPH]:
                self.enterOuterAlt(localctx, 3)
                self.state = 304
                self.match(jacParser.KW_GRAPH)
                self.state = 305
                self.match(jacParser.NAME)
                self.state = 306
                self.graph_block()
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class WalkerContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def KW_WALKER(self):
            return self.getToken(jacParser.KW_WALKER, 0)

        def NAME(self):
            return self.getToken(jacParser.NAME, 0)

        def walker_block(self):
            return self.getTypedRuleContext(jacParser.Walker_blockContext,0)


        def namespaces(self):
            return self.getTypedRuleContext(jacParser.NamespacesContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_walker

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterWalker" ):
                listener.enterWalker(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitWalker" ):
                listener.exitWalker(self)




    def walker(self):

        localctx = jacParser.WalkerContext(self, self._ctx, self.state)
        self.enterRule(localctx, 14, self.RULE_walker)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 309
            self.match(jacParser.KW_WALKER)
            self.state = 310
            self.match(jacParser.NAME)
            self.state = 312
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==jacParser.COLON:
                self.state = 311
                self.namespaces()


            self.state = 314
            self.walker_block()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Walker_blockContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LBRACE(self):
            return self.getToken(jacParser.LBRACE, 0)

        def RBRACE(self):
            return self.getToken(jacParser.RBRACE, 0)

        def attr_stmt(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(jacParser.Attr_stmtContext)
            else:
                return self.getTypedRuleContext(jacParser.Attr_stmtContext,i)


        def walk_entry_block(self):
            return self.getTypedRuleContext(jacParser.Walk_entry_blockContext,0)


        def statement(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(jacParser.StatementContext)
            else:
                return self.getTypedRuleContext(jacParser.StatementContext,i)


        def walk_activity_block(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(jacParser.Walk_activity_blockContext)
            else:
                return self.getTypedRuleContext(jacParser.Walk_activity_blockContext,i)


        def walk_exit_block(self):
            return self.getTypedRuleContext(jacParser.Walk_exit_blockContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_walker_block

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterWalker_block" ):
                listener.enterWalker_block(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitWalker_block" ):
                listener.exitWalker_block(self)




    def walker_block(self):

        localctx = jacParser.Walker_blockContext(self, self._ctx, self.state)
        self.enterRule(localctx, 16, self.RULE_walker_block)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 316
            self.match(jacParser.LBRACE)
            self.state = 320
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==jacParser.KW_HAS or _la==jacParser.KW_CAN:
                self.state = 317
                self.attr_stmt()
                self.state = 322
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 324
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,20,self._ctx)
            if la_ == 1:
                self.state = 323
                self.walk_entry_block()


            self.state = 330
            self._errHandler.sync(self)
            _alt = self._interp.adaptivePredict(self._input,22,self._ctx)
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt==1:
                    self.state = 328
                    self._errHandler.sync(self)
                    token = self._input.LA(1)
                    if token in [jacParser.T__1, jacParser.T__2, jacParser.T__4, jacParser.T__5, jacParser.T__6, jacParser.TYP_STRING, jacParser.TYP_INT, jacParser.TYP_FLOAT, jacParser.TYP_LIST, jacParser.TYP_DICT, jacParser.TYP_BOOL, jacParser.KW_TYPE, jacParser.KW_NODE, jacParser.KW_IGNORE, jacParser.KW_TAKE, jacParser.KW_SPAWN, jacParser.COLON, jacParser.DBL_COLON, jacParser.LBRACE, jacParser.KW_EDGE, jacParser.KW_ASSERT, jacParser.KW_IF, jacParser.KW_FOR, jacParser.KW_WHILE, jacParser.KW_CONTINUE, jacParser.KW_BREAK, jacParser.KW_DISENGAGE, jacParser.KW_SKIP, jacParser.KW_REPORT, jacParser.KW_DESTROY, jacParser.KW_TRY, jacParser.NOT, jacParser.PLUS, jacParser.MINUS, jacParser.STAR_MUL, jacParser.LPAREN, jacParser.LSQUARE, jacParser.FLOAT, jacParser.STRING, jacParser.BOOL, jacParser.INT, jacParser.NULL, jacParser.NAME]:
                        self.state = 326
                        self.statement()
                        pass
                    elif token in [jacParser.KW_WITH]:
                        self.state = 327
                        self.walk_activity_block()
                        pass
                    else:
                        raise NoViableAltException(self)
             
                self.state = 332
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,22,self._ctx)

            self.state = 334
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==jacParser.KW_WITH:
                self.state = 333
                self.walk_exit_block()


            self.state = 336
            self.match(jacParser.RBRACE)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class TestContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def KW_TEST(self):
            return self.getToken(jacParser.KW_TEST, 0)

        def STRING(self):
            return self.getToken(jacParser.STRING, 0)

        def KW_WITH(self):
            return self.getToken(jacParser.KW_WITH, 0)

        def KW_BY(self):
            return self.getToken(jacParser.KW_BY, 0)

        def graph_ref(self):
            return self.getTypedRuleContext(jacParser.Graph_refContext,0)


        def KW_GRAPH(self):
            return self.getToken(jacParser.KW_GRAPH, 0)

        def graph_block(self):
            return self.getTypedRuleContext(jacParser.Graph_blockContext,0)


        def KW_WALKER(self):
            return self.getToken(jacParser.KW_WALKER, 0)

        def walker_block(self):
            return self.getTypedRuleContext(jacParser.Walker_blockContext,0)


        def walker_ref(self):
            return self.getTypedRuleContext(jacParser.Walker_refContext,0)


        def code_block(self):
            return self.getTypedRuleContext(jacParser.Code_blockContext,0)


        def SEMI(self):
            return self.getToken(jacParser.SEMI, 0)

        def spawn_ctx(self):
            return self.getTypedRuleContext(jacParser.Spawn_ctxContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_test

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTest" ):
                listener.enterTest(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTest" ):
                listener.exitTest(self)




    def test(self):

        localctx = jacParser.TestContext(self, self._ctx, self.state)
        self.enterRule(localctx, 18, self.RULE_test)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 338
            self.match(jacParser.KW_TEST)
            self.state = 339
            self.match(jacParser.STRING)
            self.state = 340
            self.match(jacParser.KW_WITH)
            self.state = 344
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,24,self._ctx)
            if la_ == 1:
                self.state = 341
                self.graph_ref()
                pass

            elif la_ == 2:
                self.state = 342
                self.match(jacParser.KW_GRAPH)
                self.state = 343
                self.graph_block()
                pass


            self.state = 346
            self.match(jacParser.KW_BY)
            self.state = 357
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,27,self._ctx)
            if la_ == 1:
                self.state = 347
                self.walker_ref()
                self.state = 349
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==jacParser.LPAREN:
                    self.state = 348
                    self.spawn_ctx()


                self.state = 353
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [jacParser.COLON, jacParser.LBRACE]:
                    self.state = 351
                    self.code_block()
                    pass
                elif token in [jacParser.SEMI]:
                    self.state = 352
                    self.match(jacParser.SEMI)
                    pass
                else:
                    raise NoViableAltException(self)

                pass

            elif la_ == 2:
                self.state = 355
                self.match(jacParser.KW_WALKER)
                self.state = 356
                self.walker_block()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class NamespacesContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def COLON(self):
            return self.getToken(jacParser.COLON, 0)

        def name_list(self):
            return self.getTypedRuleContext(jacParser.Name_listContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_namespaces

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterNamespaces" ):
                listener.enterNamespaces(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitNamespaces" ):
                listener.exitNamespaces(self)




    def namespaces(self):

        localctx = jacParser.NamespacesContext(self, self._ctx, self.state)
        self.enterRule(localctx, 20, self.RULE_namespaces)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 359
            self.match(jacParser.COLON)
            self.state = 360
            self.name_list()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Walk_entry_blockContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def KW_WITH(self):
            return self.getToken(jacParser.KW_WITH, 0)

        def KW_ENTRY(self):
            return self.getToken(jacParser.KW_ENTRY, 0)

        def code_block(self):
            return self.getTypedRuleContext(jacParser.Code_blockContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_walk_entry_block

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterWalk_entry_block" ):
                listener.enterWalk_entry_block(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitWalk_entry_block" ):
                listener.exitWalk_entry_block(self)




    def walk_entry_block(self):

        localctx = jacParser.Walk_entry_blockContext(self, self._ctx, self.state)
        self.enterRule(localctx, 22, self.RULE_walk_entry_block)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 362
            self.match(jacParser.KW_WITH)
            self.state = 363
            self.match(jacParser.KW_ENTRY)
            self.state = 364
            self.code_block()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Walk_exit_blockContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def KW_WITH(self):
            return self.getToken(jacParser.KW_WITH, 0)

        def KW_EXIT(self):
            return self.getToken(jacParser.KW_EXIT, 0)

        def code_block(self):
            return self.getTypedRuleContext(jacParser.Code_blockContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_walk_exit_block

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterWalk_exit_block" ):
                listener.enterWalk_exit_block(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitWalk_exit_block" ):
                listener.exitWalk_exit_block(self)




    def walk_exit_block(self):

        localctx = jacParser.Walk_exit_blockContext(self, self._ctx, self.state)
        self.enterRule(localctx, 24, self.RULE_walk_exit_block)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 366
            self.match(jacParser.KW_WITH)
            self.state = 367
            self.match(jacParser.KW_EXIT)
            self.state = 368
            self.code_block()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Walk_activity_blockContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def KW_WITH(self):
            return self.getToken(jacParser.KW_WITH, 0)

        def KW_ACTIVITY(self):
            return self.getToken(jacParser.KW_ACTIVITY, 0)

        def code_block(self):
            return self.getTypedRuleContext(jacParser.Code_blockContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_walk_activity_block

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterWalk_activity_block" ):
                listener.enterWalk_activity_block(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitWalk_activity_block" ):
                listener.exitWalk_activity_block(self)




    def walk_activity_block(self):

        localctx = jacParser.Walk_activity_blockContext(self, self._ctx, self.state)
        self.enterRule(localctx, 26, self.RULE_walk_activity_block)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 370
            self.match(jacParser.KW_WITH)
            self.state = 371
            self.match(jacParser.KW_ACTIVITY)
            self.state = 372
            self.code_block()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Attr_blockContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LBRACE(self):
            return self.getToken(jacParser.LBRACE, 0)

        def RBRACE(self):
            return self.getToken(jacParser.RBRACE, 0)

        def attr_stmt(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(jacParser.Attr_stmtContext)
            else:
                return self.getTypedRuleContext(jacParser.Attr_stmtContext,i)


        def COLON(self):
            return self.getToken(jacParser.COLON, 0)

        def SEMI(self):
            return self.getToken(jacParser.SEMI, 0)

        def getRuleIndex(self):
            return jacParser.RULE_attr_block

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAttr_block" ):
                listener.enterAttr_block(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAttr_block" ):
                listener.exitAttr_block(self)




    def attr_block(self):

        localctx = jacParser.Attr_blockContext(self, self._ctx, self.state)
        self.enterRule(localctx, 28, self.RULE_attr_block)
        self._la = 0 # Token type
        try:
            self.state = 385
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [jacParser.LBRACE]:
                self.enterOuterAlt(localctx, 1)
                self.state = 374
                self.match(jacParser.LBRACE)
                self.state = 378
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while _la==jacParser.KW_HAS or _la==jacParser.KW_CAN:
                    self.state = 375
                    self.attr_stmt()
                    self.state = 380
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)

                self.state = 381
                self.match(jacParser.RBRACE)
                pass
            elif token in [jacParser.COLON]:
                self.enterOuterAlt(localctx, 2)
                self.state = 382
                self.match(jacParser.COLON)
                self.state = 383
                self.attr_stmt()
                pass
            elif token in [jacParser.SEMI]:
                self.enterOuterAlt(localctx, 3)
                self.state = 384
                self.match(jacParser.SEMI)
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Attr_stmtContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def has_stmt(self):
            return self.getTypedRuleContext(jacParser.Has_stmtContext,0)


        def can_stmt(self):
            return self.getTypedRuleContext(jacParser.Can_stmtContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_attr_stmt

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAttr_stmt" ):
                listener.enterAttr_stmt(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAttr_stmt" ):
                listener.exitAttr_stmt(self)




    def attr_stmt(self):

        localctx = jacParser.Attr_stmtContext(self, self._ctx, self.state)
        self.enterRule(localctx, 30, self.RULE_attr_stmt)
        try:
            self.state = 389
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [jacParser.KW_HAS]:
                self.enterOuterAlt(localctx, 1)
                self.state = 387
                self.has_stmt()
                pass
            elif token in [jacParser.KW_CAN]:
                self.enterOuterAlt(localctx, 2)
                self.state = 388
                self.can_stmt()
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Graph_blockContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def graph_block_spawn(self):
            return self.getTypedRuleContext(jacParser.Graph_block_spawnContext,0)


        def graph_block_dot(self):
            return self.getTypedRuleContext(jacParser.Graph_block_dotContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_graph_block

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterGraph_block" ):
                listener.enterGraph_block(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitGraph_block" ):
                listener.exitGraph_block(self)




    def graph_block(self):

        localctx = jacParser.Graph_blockContext(self, self._ctx, self.state)
        self.enterRule(localctx, 32, self.RULE_graph_block)
        try:
            self.state = 393
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,31,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 391
                self.graph_block_spawn()
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 392
                self.graph_block_dot()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Graph_block_spawnContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LBRACE(self):
            return self.getToken(jacParser.LBRACE, 0)

        def has_root(self):
            return self.getTypedRuleContext(jacParser.Has_rootContext,0)


        def KW_SPAWN(self):
            return self.getToken(jacParser.KW_SPAWN, 0)

        def code_block(self):
            return self.getTypedRuleContext(jacParser.Code_blockContext,0)


        def RBRACE(self):
            return self.getToken(jacParser.RBRACE, 0)

        def COLON(self):
            return self.getToken(jacParser.COLON, 0)

        def SEMI(self):
            return self.getToken(jacParser.SEMI, 0)

        def getRuleIndex(self):
            return jacParser.RULE_graph_block_spawn

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterGraph_block_spawn" ):
                listener.enterGraph_block_spawn(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitGraph_block_spawn" ):
                listener.exitGraph_block_spawn(self)




    def graph_block_spawn(self):

        localctx = jacParser.Graph_block_spawnContext(self, self._ctx, self.state)
        self.enterRule(localctx, 34, self.RULE_graph_block_spawn)
        try:
            self.state = 407
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [jacParser.LBRACE]:
                self.enterOuterAlt(localctx, 1)
                self.state = 395
                self.match(jacParser.LBRACE)
                self.state = 396
                self.has_root()
                self.state = 397
                self.match(jacParser.KW_SPAWN)
                self.state = 398
                self.code_block()
                self.state = 399
                self.match(jacParser.RBRACE)
                pass
            elif token in [jacParser.COLON]:
                self.enterOuterAlt(localctx, 2)
                self.state = 401
                self.match(jacParser.COLON)
                self.state = 402
                self.has_root()
                self.state = 403
                self.match(jacParser.KW_SPAWN)
                self.state = 404
                self.code_block()
                self.state = 405
                self.match(jacParser.SEMI)
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Graph_block_dotContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LBRACE(self):
            return self.getToken(jacParser.LBRACE, 0)

        def has_root(self):
            return self.getTypedRuleContext(jacParser.Has_rootContext,0)


        def dot_graph(self):
            return self.getTypedRuleContext(jacParser.Dot_graphContext,0)


        def RBRACE(self):
            return self.getToken(jacParser.RBRACE, 0)

        def COLON(self):
            return self.getToken(jacParser.COLON, 0)

        def SEMI(self):
            return self.getToken(jacParser.SEMI, 0)

        def getRuleIndex(self):
            return jacParser.RULE_graph_block_dot

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterGraph_block_dot" ):
                listener.enterGraph_block_dot(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitGraph_block_dot" ):
                listener.exitGraph_block_dot(self)




    def graph_block_dot(self):

        localctx = jacParser.Graph_block_dotContext(self, self._ctx, self.state)
        self.enterRule(localctx, 36, self.RULE_graph_block_dot)
        try:
            self.state = 419
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [jacParser.LBRACE]:
                self.enterOuterAlt(localctx, 1)
                self.state = 409
                self.match(jacParser.LBRACE)
                self.state = 410
                self.has_root()
                self.state = 411
                self.dot_graph()
                self.state = 412
                self.match(jacParser.RBRACE)
                pass
            elif token in [jacParser.COLON]:
                self.enterOuterAlt(localctx, 2)
                self.state = 414
                self.match(jacParser.COLON)
                self.state = 415
                self.has_root()
                self.state = 416
                self.dot_graph()
                self.state = 417
                self.match(jacParser.SEMI)
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Has_rootContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def KW_HAS(self):
            return self.getToken(jacParser.KW_HAS, 0)

        def KW_ANCHOR(self):
            return self.getToken(jacParser.KW_ANCHOR, 0)

        def NAME(self):
            return self.getToken(jacParser.NAME, 0)

        def SEMI(self):
            return self.getToken(jacParser.SEMI, 0)

        def getRuleIndex(self):
            return jacParser.RULE_has_root

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterHas_root" ):
                listener.enterHas_root(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitHas_root" ):
                listener.exitHas_root(self)




    def has_root(self):

        localctx = jacParser.Has_rootContext(self, self._ctx, self.state)
        self.enterRule(localctx, 38, self.RULE_has_root)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 421
            self.match(jacParser.KW_HAS)
            self.state = 422
            self.match(jacParser.KW_ANCHOR)
            self.state = 423
            self.match(jacParser.NAME)
            self.state = 424
            self.match(jacParser.SEMI)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Has_stmtContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def KW_HAS(self):
            return self.getToken(jacParser.KW_HAS, 0)

        def has_assign(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(jacParser.Has_assignContext)
            else:
                return self.getTypedRuleContext(jacParser.Has_assignContext,i)


        def SEMI(self):
            return self.getToken(jacParser.SEMI, 0)

        def KW_PRIVATE(self):
            return self.getToken(jacParser.KW_PRIVATE, 0)

        def KW_ANCHOR(self):
            return self.getToken(jacParser.KW_ANCHOR, 0)

        def COMMA(self, i:int=None):
            if i is None:
                return self.getTokens(jacParser.COMMA)
            else:
                return self.getToken(jacParser.COMMA, i)

        def getRuleIndex(self):
            return jacParser.RULE_has_stmt

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterHas_stmt" ):
                listener.enterHas_stmt(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitHas_stmt" ):
                listener.exitHas_stmt(self)




    def has_stmt(self):

        localctx = jacParser.Has_stmtContext(self, self._ctx, self.state)
        self.enterRule(localctx, 40, self.RULE_has_stmt)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 426
            self.match(jacParser.KW_HAS)
            self.state = 428
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==jacParser.KW_PRIVATE:
                self.state = 427
                self.match(jacParser.KW_PRIVATE)


            self.state = 431
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==jacParser.KW_ANCHOR:
                self.state = 430
                self.match(jacParser.KW_ANCHOR)


            self.state = 433
            self.has_assign()
            self.state = 438
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==jacParser.COMMA:
                self.state = 434
                self.match(jacParser.COMMA)
                self.state = 435
                self.has_assign()
                self.state = 440
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 441
            self.match(jacParser.SEMI)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Has_assignContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def NAME(self):
            return self.getToken(jacParser.NAME, 0)

        def EQ(self):
            return self.getToken(jacParser.EQ, 0)

        def expression(self):
            return self.getTypedRuleContext(jacParser.ExpressionContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_has_assign

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterHas_assign" ):
                listener.enterHas_assign(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitHas_assign" ):
                listener.exitHas_assign(self)




    def has_assign(self):

        localctx = jacParser.Has_assignContext(self, self._ctx, self.state)
        self.enterRule(localctx, 42, self.RULE_has_assign)
        try:
            self.state = 447
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,37,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 443
                self.match(jacParser.NAME)
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 444
                self.match(jacParser.NAME)
                self.state = 445
                self.match(jacParser.EQ)
                self.state = 446
                self.expression()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Can_stmtContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def KW_CAN(self):
            return self.getToken(jacParser.KW_CAN, 0)

        def dotted_name(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(jacParser.Dotted_nameContext)
            else:
                return self.getTypedRuleContext(jacParser.Dotted_nameContext,i)


        def SEMI(self):
            return self.getToken(jacParser.SEMI, 0)

        def preset_in_out(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(jacParser.Preset_in_outContext)
            else:
                return self.getTypedRuleContext(jacParser.Preset_in_outContext,i)


        def event_clause(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(jacParser.Event_clauseContext)
            else:
                return self.getTypedRuleContext(jacParser.Event_clauseContext,i)


        def COMMA(self, i:int=None):
            if i is None:
                return self.getTokens(jacParser.COMMA)
            else:
                return self.getToken(jacParser.COMMA, i)

        def NAME(self):
            return self.getToken(jacParser.NAME, 0)

        def code_block(self):
            return self.getTypedRuleContext(jacParser.Code_blockContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_can_stmt

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterCan_stmt" ):
                listener.enterCan_stmt(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitCan_stmt" ):
                listener.exitCan_stmt(self)




    def can_stmt(self):

        localctx = jacParser.Can_stmtContext(self, self._ctx, self.state)
        self.enterRule(localctx, 44, self.RULE_can_stmt)
        self._la = 0 # Token type
        try:
            self.state = 476
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,42,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 449
                self.match(jacParser.KW_CAN)
                self.state = 450
                self.dotted_name()
                self.state = 454
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==jacParser.DBL_COLON:
                    self.state = 451
                    self.preset_in_out()
                    self.state = 452
                    self.event_clause()


                self.state = 465
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while _la==jacParser.COMMA:
                    self.state = 456
                    self.match(jacParser.COMMA)
                    self.state = 457
                    self.dotted_name()
                    self.state = 461
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)
                    if _la==jacParser.DBL_COLON:
                        self.state = 458
                        self.preset_in_out()
                        self.state = 459
                        self.event_clause()


                    self.state = 467
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)

                self.state = 468
                self.match(jacParser.SEMI)
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 470
                self.match(jacParser.KW_CAN)
                self.state = 471
                self.match(jacParser.NAME)
                self.state = 473
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==jacParser.KW_WITH:
                    self.state = 472
                    self.event_clause()


                self.state = 475
                self.code_block()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Event_clauseContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def KW_WITH(self):
            return self.getToken(jacParser.KW_WITH, 0)

        def KW_ENTRY(self):
            return self.getToken(jacParser.KW_ENTRY, 0)

        def KW_EXIT(self):
            return self.getToken(jacParser.KW_EXIT, 0)

        def KW_ACTIVITY(self):
            return self.getToken(jacParser.KW_ACTIVITY, 0)

        def name_list(self):
            return self.getTypedRuleContext(jacParser.Name_listContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_event_clause

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterEvent_clause" ):
                listener.enterEvent_clause(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitEvent_clause" ):
                listener.exitEvent_clause(self)




    def event_clause(self):

        localctx = jacParser.Event_clauseContext(self, self._ctx, self.state)
        self.enterRule(localctx, 46, self.RULE_event_clause)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 478
            self.match(jacParser.KW_WITH)
            self.state = 480
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==jacParser.NAME:
                self.state = 479
                self.name_list()


            self.state = 482
            _la = self._input.LA(1)
            if not((((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << jacParser.KW_ENTRY) | (1 << jacParser.KW_EXIT) | (1 << jacParser.KW_ACTIVITY))) != 0)):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Preset_in_outContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def DBL_COLON(self, i:int=None):
            if i is None:
                return self.getTokens(jacParser.DBL_COLON)
            else:
                return self.getToken(jacParser.DBL_COLON, i)

        def COLON_OUT(self):
            return self.getToken(jacParser.COLON_OUT, 0)

        def expression(self):
            return self.getTypedRuleContext(jacParser.ExpressionContext,0)


        def expr_list(self):
            return self.getTypedRuleContext(jacParser.Expr_listContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_preset_in_out

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPreset_in_out" ):
                listener.enterPreset_in_out(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPreset_in_out" ):
                listener.exitPreset_in_out(self)




    def preset_in_out(self):

        localctx = jacParser.Preset_in_outContext(self, self._ctx, self.state)
        self.enterRule(localctx, 48, self.RULE_preset_in_out)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 484
            self.match(jacParser.DBL_COLON)
            self.state = 486
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,44,self._ctx)
            if la_ == 1:
                self.state = 485
                self.expr_list()


            self.state = 491
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [jacParser.DBL_COLON]:
                self.state = 488
                self.match(jacParser.DBL_COLON)
                pass
            elif token in [jacParser.COLON_OUT]:
                self.state = 489
                self.match(jacParser.COLON_OUT)
                self.state = 490
                self.expression()
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Dotted_nameContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def NAME(self, i:int=None):
            if i is None:
                return self.getTokens(jacParser.NAME)
            else:
                return self.getToken(jacParser.NAME, i)

        def DOT(self):
            return self.getToken(jacParser.DOT, 0)

        def getRuleIndex(self):
            return jacParser.RULE_dotted_name

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDotted_name" ):
                listener.enterDotted_name(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDotted_name" ):
                listener.exitDotted_name(self)




    def dotted_name(self):

        localctx = jacParser.Dotted_nameContext(self, self._ctx, self.state)
        self.enterRule(localctx, 50, self.RULE_dotted_name)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 493
            self.match(jacParser.NAME)
            self.state = 494
            self.match(jacParser.DOT)
            self.state = 495
            self.match(jacParser.NAME)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Name_listContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def NAME(self, i:int=None):
            if i is None:
                return self.getTokens(jacParser.NAME)
            else:
                return self.getToken(jacParser.NAME, i)

        def COMMA(self, i:int=None):
            if i is None:
                return self.getTokens(jacParser.COMMA)
            else:
                return self.getToken(jacParser.COMMA, i)

        def getRuleIndex(self):
            return jacParser.RULE_name_list

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterName_list" ):
                listener.enterName_list(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitName_list" ):
                listener.exitName_list(self)




    def name_list(self):

        localctx = jacParser.Name_listContext(self, self._ctx, self.state)
        self.enterRule(localctx, 52, self.RULE_name_list)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 497
            self.match(jacParser.NAME)
            self.state = 502
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==jacParser.COMMA:
                self.state = 498
                self.match(jacParser.COMMA)
                self.state = 499
                self.match(jacParser.NAME)
                self.state = 504
                self._errHandler.sync(self)
                _la = self._input.LA(1)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Expr_listContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def expression(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(jacParser.ExpressionContext)
            else:
                return self.getTypedRuleContext(jacParser.ExpressionContext,i)


        def COMMA(self, i:int=None):
            if i is None:
                return self.getTokens(jacParser.COMMA)
            else:
                return self.getToken(jacParser.COMMA, i)

        def getRuleIndex(self):
            return jacParser.RULE_expr_list

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterExpr_list" ):
                listener.enterExpr_list(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitExpr_list" ):
                listener.exitExpr_list(self)




    def expr_list(self):

        localctx = jacParser.Expr_listContext(self, self._ctx, self.state)
        self.enterRule(localctx, 54, self.RULE_expr_list)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 505
            self.expression()
            self.state = 510
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==jacParser.COMMA:
                self.state = 506
                self.match(jacParser.COMMA)
                self.state = 507
                self.expression()
                self.state = 512
                self._errHandler.sync(self)
                _la = self._input.LA(1)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Code_blockContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LBRACE(self):
            return self.getToken(jacParser.LBRACE, 0)

        def RBRACE(self):
            return self.getToken(jacParser.RBRACE, 0)

        def statement(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(jacParser.StatementContext)
            else:
                return self.getTypedRuleContext(jacParser.StatementContext,i)


        def COLON(self):
            return self.getToken(jacParser.COLON, 0)

        def getRuleIndex(self):
            return jacParser.RULE_code_block

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterCode_block" ):
                listener.enterCode_block(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitCode_block" ):
                listener.exitCode_block(self)




    def code_block(self):

        localctx = jacParser.Code_blockContext(self, self._ctx, self.state)
        self.enterRule(localctx, 56, self.RULE_code_block)
        self._la = 0 # Token type
        try:
            self.state = 523
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [jacParser.LBRACE]:
                self.enterOuterAlt(localctx, 1)
                self.state = 513
                self.match(jacParser.LBRACE)
                self.state = 517
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while (((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << jacParser.T__1) | (1 << jacParser.T__2) | (1 << jacParser.T__4) | (1 << jacParser.T__5) | (1 << jacParser.T__6) | (1 << jacParser.TYP_STRING) | (1 << jacParser.TYP_INT) | (1 << jacParser.TYP_FLOAT) | (1 << jacParser.TYP_LIST) | (1 << jacParser.TYP_DICT) | (1 << jacParser.TYP_BOOL) | (1 << jacParser.KW_TYPE) | (1 << jacParser.KW_NODE) | (1 << jacParser.KW_IGNORE) | (1 << jacParser.KW_TAKE) | (1 << jacParser.KW_SPAWN) | (1 << jacParser.COLON) | (1 << jacParser.DBL_COLON) | (1 << jacParser.LBRACE) | (1 << jacParser.KW_EDGE) | (1 << jacParser.KW_ASSERT) | (1 << jacParser.KW_IF) | (1 << jacParser.KW_FOR) | (1 << jacParser.KW_WHILE) | (1 << jacParser.KW_CONTINUE) | (1 << jacParser.KW_BREAK))) != 0) or ((((_la - 64)) & ~0x3f) == 0 and ((1 << (_la - 64)) & ((1 << (jacParser.KW_DISENGAGE - 64)) | (1 << (jacParser.KW_SKIP - 64)) | (1 << (jacParser.KW_REPORT - 64)) | (1 << (jacParser.KW_DESTROY - 64)) | (1 << (jacParser.KW_TRY - 64)) | (1 << (jacParser.NOT - 64)) | (1 << (jacParser.PLUS - 64)) | (1 << (jacParser.MINUS - 64)) | (1 << (jacParser.STAR_MUL - 64)) | (1 << (jacParser.LPAREN - 64)) | (1 << (jacParser.LSQUARE - 64)) | (1 << (jacParser.FLOAT - 64)) | (1 << (jacParser.STRING - 64)) | (1 << (jacParser.BOOL - 64)) | (1 << (jacParser.INT - 64)) | (1 << (jacParser.NULL - 64)) | (1 << (jacParser.NAME - 64)))) != 0):
                    self.state = 514
                    self.statement()
                    self.state = 519
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)

                self.state = 520
                self.match(jacParser.RBRACE)
                pass
            elif token in [jacParser.COLON]:
                self.enterOuterAlt(localctx, 2)
                self.state = 521
                self.match(jacParser.COLON)
                self.state = 522
                self.statement()
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Node_ctx_blockContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def name_list(self):
            return self.getTypedRuleContext(jacParser.Name_listContext,0)


        def code_block(self):
            return self.getTypedRuleContext(jacParser.Code_blockContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_node_ctx_block

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterNode_ctx_block" ):
                listener.enterNode_ctx_block(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitNode_ctx_block" ):
                listener.exitNode_ctx_block(self)




    def node_ctx_block(self):

        localctx = jacParser.Node_ctx_blockContext(self, self._ctx, self.state)
        self.enterRule(localctx, 58, self.RULE_node_ctx_block)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 525
            self.name_list()
            self.state = 526
            self.code_block()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class StatementContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def code_block(self):
            return self.getTypedRuleContext(jacParser.Code_blockContext,0)


        def node_ctx_block(self):
            return self.getTypedRuleContext(jacParser.Node_ctx_blockContext,0)


        def expression(self):
            return self.getTypedRuleContext(jacParser.ExpressionContext,0)


        def SEMI(self):
            return self.getToken(jacParser.SEMI, 0)

        def if_stmt(self):
            return self.getTypedRuleContext(jacParser.If_stmtContext,0)


        def try_stmt(self):
            return self.getTypedRuleContext(jacParser.Try_stmtContext,0)


        def for_stmt(self):
            return self.getTypedRuleContext(jacParser.For_stmtContext,0)


        def while_stmt(self):
            return self.getTypedRuleContext(jacParser.While_stmtContext,0)


        def assert_stmt(self):
            return self.getTypedRuleContext(jacParser.Assert_stmtContext,0)


        def ctrl_stmt(self):
            return self.getTypedRuleContext(jacParser.Ctrl_stmtContext,0)


        def destroy_action(self):
            return self.getTypedRuleContext(jacParser.Destroy_actionContext,0)


        def report_action(self):
            return self.getTypedRuleContext(jacParser.Report_actionContext,0)


        def walker_action(self):
            return self.getTypedRuleContext(jacParser.Walker_actionContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_statement

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterStatement" ):
                listener.enterStatement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitStatement" ):
                listener.exitStatement(self)




    def statement(self):

        localctx = jacParser.StatementContext(self, self._ctx, self.state)
        self.enterRule(localctx, 60, self.RULE_statement)
        try:
            self.state = 546
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,50,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 528
                self.code_block()
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 529
                self.node_ctx_block()
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 530
                self.expression()
                self.state = 531
                self.match(jacParser.SEMI)
                pass

            elif la_ == 4:
                self.enterOuterAlt(localctx, 4)
                self.state = 533
                self.if_stmt()
                pass

            elif la_ == 5:
                self.enterOuterAlt(localctx, 5)
                self.state = 534
                self.try_stmt()
                pass

            elif la_ == 6:
                self.enterOuterAlt(localctx, 6)
                self.state = 535
                self.for_stmt()
                pass

            elif la_ == 7:
                self.enterOuterAlt(localctx, 7)
                self.state = 536
                self.while_stmt()
                pass

            elif la_ == 8:
                self.enterOuterAlt(localctx, 8)
                self.state = 537
                self.assert_stmt()
                self.state = 538
                self.match(jacParser.SEMI)
                pass

            elif la_ == 9:
                self.enterOuterAlt(localctx, 9)
                self.state = 540
                self.ctrl_stmt()
                self.state = 541
                self.match(jacParser.SEMI)
                pass

            elif la_ == 10:
                self.enterOuterAlt(localctx, 10)
                self.state = 543
                self.destroy_action()
                pass

            elif la_ == 11:
                self.enterOuterAlt(localctx, 11)
                self.state = 544
                self.report_action()
                pass

            elif la_ == 12:
                self.enterOuterAlt(localctx, 12)
                self.state = 545
                self.walker_action()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class If_stmtContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def KW_IF(self):
            return self.getToken(jacParser.KW_IF, 0)

        def expression(self):
            return self.getTypedRuleContext(jacParser.ExpressionContext,0)


        def code_block(self):
            return self.getTypedRuleContext(jacParser.Code_blockContext,0)


        def elif_stmt(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(jacParser.Elif_stmtContext)
            else:
                return self.getTypedRuleContext(jacParser.Elif_stmtContext,i)


        def else_stmt(self):
            return self.getTypedRuleContext(jacParser.Else_stmtContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_if_stmt

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterIf_stmt" ):
                listener.enterIf_stmt(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitIf_stmt" ):
                listener.exitIf_stmt(self)




    def if_stmt(self):

        localctx = jacParser.If_stmtContext(self, self._ctx, self.state)
        self.enterRule(localctx, 62, self.RULE_if_stmt)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 548
            self.match(jacParser.KW_IF)
            self.state = 549
            self.expression()
            self.state = 550
            self.code_block()
            self.state = 554
            self._errHandler.sync(self)
            _alt = self._interp.adaptivePredict(self._input,51,self._ctx)
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt==1:
                    self.state = 551
                    self.elif_stmt() 
                self.state = 556
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,51,self._ctx)

            self.state = 558
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,52,self._ctx)
            if la_ == 1:
                self.state = 557
                self.else_stmt()


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Try_stmtContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def KW_TRY(self):
            return self.getToken(jacParser.KW_TRY, 0)

        def code_block(self):
            return self.getTypedRuleContext(jacParser.Code_blockContext,0)


        def else_from_try(self):
            return self.getTypedRuleContext(jacParser.Else_from_tryContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_try_stmt

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTry_stmt" ):
                listener.enterTry_stmt(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTry_stmt" ):
                listener.exitTry_stmt(self)




    def try_stmt(self):

        localctx = jacParser.Try_stmtContext(self, self._ctx, self.state)
        self.enterRule(localctx, 64, self.RULE_try_stmt)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 560
            self.match(jacParser.KW_TRY)
            self.state = 561
            self.code_block()
            self.state = 563
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,53,self._ctx)
            if la_ == 1:
                self.state = 562
                self.else_from_try()


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Else_from_tryContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def KW_ELSE(self):
            return self.getToken(jacParser.KW_ELSE, 0)

        def code_block(self):
            return self.getTypedRuleContext(jacParser.Code_blockContext,0)


        def LPAREN(self):
            return self.getToken(jacParser.LPAREN, 0)

        def NAME(self):
            return self.getToken(jacParser.NAME, 0)

        def RPAREN(self):
            return self.getToken(jacParser.RPAREN, 0)

        def KW_WITH(self):
            return self.getToken(jacParser.KW_WITH, 0)

        def getRuleIndex(self):
            return jacParser.RULE_else_from_try

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterElse_from_try" ):
                listener.enterElse_from_try(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitElse_from_try" ):
                listener.exitElse_from_try(self)




    def else_from_try(self):

        localctx = jacParser.Else_from_tryContext(self, self._ctx, self.state)
        self.enterRule(localctx, 66, self.RULE_else_from_try)
        self._la = 0 # Token type
        try:
            self.state = 578
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,56,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 565
                self.match(jacParser.KW_ELSE)
                self.state = 569
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==jacParser.LPAREN:
                    self.state = 566
                    self.match(jacParser.LPAREN)
                    self.state = 567
                    self.match(jacParser.NAME)
                    self.state = 568
                    self.match(jacParser.RPAREN)


                self.state = 571
                self.code_block()
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 572
                self.match(jacParser.KW_ELSE)
                self.state = 575
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==jacParser.KW_WITH:
                    self.state = 573
                    self.match(jacParser.KW_WITH)
                    self.state = 574
                    self.match(jacParser.NAME)


                self.state = 577
                self.code_block()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Elif_stmtContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def KW_ELIF(self):
            return self.getToken(jacParser.KW_ELIF, 0)

        def expression(self):
            return self.getTypedRuleContext(jacParser.ExpressionContext,0)


        def code_block(self):
            return self.getTypedRuleContext(jacParser.Code_blockContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_elif_stmt

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterElif_stmt" ):
                listener.enterElif_stmt(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitElif_stmt" ):
                listener.exitElif_stmt(self)




    def elif_stmt(self):

        localctx = jacParser.Elif_stmtContext(self, self._ctx, self.state)
        self.enterRule(localctx, 68, self.RULE_elif_stmt)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 580
            self.match(jacParser.KW_ELIF)
            self.state = 581
            self.expression()
            self.state = 582
            self.code_block()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Else_stmtContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def KW_ELSE(self):
            return self.getToken(jacParser.KW_ELSE, 0)

        def code_block(self):
            return self.getTypedRuleContext(jacParser.Code_blockContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_else_stmt

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterElse_stmt" ):
                listener.enterElse_stmt(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitElse_stmt" ):
                listener.exitElse_stmt(self)




    def else_stmt(self):

        localctx = jacParser.Else_stmtContext(self, self._ctx, self.state)
        self.enterRule(localctx, 70, self.RULE_else_stmt)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 584
            self.match(jacParser.KW_ELSE)
            self.state = 585
            self.code_block()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class For_stmtContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def KW_FOR(self):
            return self.getToken(jacParser.KW_FOR, 0)

        def expression(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(jacParser.ExpressionContext)
            else:
                return self.getTypedRuleContext(jacParser.ExpressionContext,i)


        def KW_TO(self):
            return self.getToken(jacParser.KW_TO, 0)

        def KW_BY(self):
            return self.getToken(jacParser.KW_BY, 0)

        def code_block(self):
            return self.getTypedRuleContext(jacParser.Code_blockContext,0)


        def NAME(self):
            return self.getToken(jacParser.NAME, 0)

        def KW_IN(self):
            return self.getToken(jacParser.KW_IN, 0)

        def getRuleIndex(self):
            return jacParser.RULE_for_stmt

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterFor_stmt" ):
                listener.enterFor_stmt(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitFor_stmt" ):
                listener.exitFor_stmt(self)




    def for_stmt(self):

        localctx = jacParser.For_stmtContext(self, self._ctx, self.state)
        self.enterRule(localctx, 72, self.RULE_for_stmt)
        try:
            self.state = 601
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,57,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 587
                self.match(jacParser.KW_FOR)
                self.state = 588
                self.expression()
                self.state = 589
                self.match(jacParser.KW_TO)
                self.state = 590
                self.expression()
                self.state = 591
                self.match(jacParser.KW_BY)
                self.state = 592
                self.expression()
                self.state = 593
                self.code_block()
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 595
                self.match(jacParser.KW_FOR)
                self.state = 596
                self.match(jacParser.NAME)
                self.state = 597
                self.match(jacParser.KW_IN)
                self.state = 598
                self.expression()
                self.state = 599
                self.code_block()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class While_stmtContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def KW_WHILE(self):
            return self.getToken(jacParser.KW_WHILE, 0)

        def expression(self):
            return self.getTypedRuleContext(jacParser.ExpressionContext,0)


        def code_block(self):
            return self.getTypedRuleContext(jacParser.Code_blockContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_while_stmt

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterWhile_stmt" ):
                listener.enterWhile_stmt(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitWhile_stmt" ):
                listener.exitWhile_stmt(self)




    def while_stmt(self):

        localctx = jacParser.While_stmtContext(self, self._ctx, self.state)
        self.enterRule(localctx, 74, self.RULE_while_stmt)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 603
            self.match(jacParser.KW_WHILE)
            self.state = 604
            self.expression()
            self.state = 605
            self.code_block()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Ctrl_stmtContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def KW_CONTINUE(self):
            return self.getToken(jacParser.KW_CONTINUE, 0)

        def KW_BREAK(self):
            return self.getToken(jacParser.KW_BREAK, 0)

        def KW_SKIP(self):
            return self.getToken(jacParser.KW_SKIP, 0)

        def getRuleIndex(self):
            return jacParser.RULE_ctrl_stmt

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterCtrl_stmt" ):
                listener.enterCtrl_stmt(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitCtrl_stmt" ):
                listener.exitCtrl_stmt(self)




    def ctrl_stmt(self):

        localctx = jacParser.Ctrl_stmtContext(self, self._ctx, self.state)
        self.enterRule(localctx, 76, self.RULE_ctrl_stmt)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 607
            _la = self._input.LA(1)
            if not(((((_la - 62)) & ~0x3f) == 0 and ((1 << (_la - 62)) & ((1 << (jacParser.KW_CONTINUE - 62)) | (1 << (jacParser.KW_BREAK - 62)) | (1 << (jacParser.KW_SKIP - 62)))) != 0)):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Assert_stmtContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def KW_ASSERT(self):
            return self.getToken(jacParser.KW_ASSERT, 0)

        def expression(self):
            return self.getTypedRuleContext(jacParser.ExpressionContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_assert_stmt

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAssert_stmt" ):
                listener.enterAssert_stmt(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAssert_stmt" ):
                listener.exitAssert_stmt(self)




    def assert_stmt(self):

        localctx = jacParser.Assert_stmtContext(self, self._ctx, self.state)
        self.enterRule(localctx, 78, self.RULE_assert_stmt)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 609
            self.match(jacParser.KW_ASSERT)
            self.state = 610
            self.expression()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Destroy_actionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def KW_DESTROY(self):
            return self.getToken(jacParser.KW_DESTROY, 0)

        def expression(self):
            return self.getTypedRuleContext(jacParser.ExpressionContext,0)


        def SEMI(self):
            return self.getToken(jacParser.SEMI, 0)

        def getRuleIndex(self):
            return jacParser.RULE_destroy_action

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDestroy_action" ):
                listener.enterDestroy_action(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDestroy_action" ):
                listener.exitDestroy_action(self)




    def destroy_action(self):

        localctx = jacParser.Destroy_actionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 80, self.RULE_destroy_action)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 612
            self.match(jacParser.KW_DESTROY)
            self.state = 613
            self.expression()
            self.state = 614
            self.match(jacParser.SEMI)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Report_actionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def KW_REPORT(self):
            return self.getToken(jacParser.KW_REPORT, 0)

        def expression(self):
            return self.getTypedRuleContext(jacParser.ExpressionContext,0)


        def SEMI(self):
            return self.getToken(jacParser.SEMI, 0)

        def DOT(self):
            return self.getToken(jacParser.DOT, 0)

        def NAME(self):
            return self.getToken(jacParser.NAME, 0)

        def EQ(self):
            return self.getToken(jacParser.EQ, 0)

        def INT(self):
            return self.getToken(jacParser.INT, 0)

        def getRuleIndex(self):
            return jacParser.RULE_report_action

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterReport_action" ):
                listener.enterReport_action(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitReport_action" ):
                listener.exitReport_action(self)




    def report_action(self):

        localctx = jacParser.Report_actionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 82, self.RULE_report_action)
        try:
            self.state = 626
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,58,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 616
                self.match(jacParser.KW_REPORT)
                self.state = 617
                self.expression()
                self.state = 618
                self.match(jacParser.SEMI)
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 620
                self.match(jacParser.KW_REPORT)
                self.state = 621
                self.match(jacParser.DOT)
                self.state = 622
                self.match(jacParser.NAME)
                self.state = 623
                self.match(jacParser.EQ)
                self.state = 624
                self.match(jacParser.INT)
                self.state = 625
                self.match(jacParser.SEMI)
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Walker_actionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ignore_action(self):
            return self.getTypedRuleContext(jacParser.Ignore_actionContext,0)


        def take_action(self):
            return self.getTypedRuleContext(jacParser.Take_actionContext,0)


        def KW_DISENGAGE(self):
            return self.getToken(jacParser.KW_DISENGAGE, 0)

        def SEMI(self):
            return self.getToken(jacParser.SEMI, 0)

        def getRuleIndex(self):
            return jacParser.RULE_walker_action

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterWalker_action" ):
                listener.enterWalker_action(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitWalker_action" ):
                listener.exitWalker_action(self)




    def walker_action(self):

        localctx = jacParser.Walker_actionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 84, self.RULE_walker_action)
        try:
            self.state = 632
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [jacParser.KW_IGNORE]:
                self.enterOuterAlt(localctx, 1)
                self.state = 628
                self.ignore_action()
                pass
            elif token in [jacParser.KW_TAKE]:
                self.enterOuterAlt(localctx, 2)
                self.state = 629
                self.take_action()
                pass
            elif token in [jacParser.KW_DISENGAGE]:
                self.enterOuterAlt(localctx, 3)
                self.state = 630
                self.match(jacParser.KW_DISENGAGE)
                self.state = 631
                self.match(jacParser.SEMI)
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Ignore_actionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def KW_IGNORE(self):
            return self.getToken(jacParser.KW_IGNORE, 0)

        def expression(self):
            return self.getTypedRuleContext(jacParser.ExpressionContext,0)


        def SEMI(self):
            return self.getToken(jacParser.SEMI, 0)

        def getRuleIndex(self):
            return jacParser.RULE_ignore_action

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterIgnore_action" ):
                listener.enterIgnore_action(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitIgnore_action" ):
                listener.exitIgnore_action(self)




    def ignore_action(self):

        localctx = jacParser.Ignore_actionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 86, self.RULE_ignore_action)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 634
            self.match(jacParser.KW_IGNORE)
            self.state = 635
            self.expression()
            self.state = 636
            self.match(jacParser.SEMI)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Take_actionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def KW_TAKE(self):
            return self.getToken(jacParser.KW_TAKE, 0)

        def expression(self):
            return self.getTypedRuleContext(jacParser.ExpressionContext,0)


        def SEMI(self):
            return self.getToken(jacParser.SEMI, 0)

        def else_stmt(self):
            return self.getTypedRuleContext(jacParser.Else_stmtContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_take_action

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTake_action" ):
                listener.enterTake_action(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTake_action" ):
                listener.exitTake_action(self)




    def take_action(self):

        localctx = jacParser.Take_actionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 88, self.RULE_take_action)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 638
            self.match(jacParser.KW_TAKE)
            self.state = 639
            self.expression()
            self.state = 642
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [jacParser.SEMI]:
                self.state = 640
                self.match(jacParser.SEMI)
                pass
            elif token in [jacParser.KW_ELSE]:
                self.state = 641
                self.else_stmt()
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ExpressionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def connect(self):
            return self.getTypedRuleContext(jacParser.ConnectContext,0)


        def assignment(self):
            return self.getTypedRuleContext(jacParser.AssignmentContext,0)


        def copy_assign(self):
            return self.getTypedRuleContext(jacParser.Copy_assignContext,0)


        def inc_assign(self):
            return self.getTypedRuleContext(jacParser.Inc_assignContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_expression

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterExpression" ):
                listener.enterExpression(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitExpression" ):
                listener.exitExpression(self)




    def expression(self):

        localctx = jacParser.ExpressionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 90, self.RULE_expression)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 644
            self.connect()
            self.state = 648
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,61,self._ctx)
            if la_ == 1:
                self.state = 645
                self.assignment()

            elif la_ == 2:
                self.state = 646
                self.copy_assign()

            elif la_ == 3:
                self.state = 647
                self.inc_assign()


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class AssignmentContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def EQ(self):
            return self.getToken(jacParser.EQ, 0)

        def expression(self):
            return self.getTypedRuleContext(jacParser.ExpressionContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_assignment

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAssignment" ):
                listener.enterAssignment(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAssignment" ):
                listener.exitAssignment(self)




    def assignment(self):

        localctx = jacParser.AssignmentContext(self, self._ctx, self.state)
        self.enterRule(localctx, 92, self.RULE_assignment)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 650
            self.match(jacParser.EQ)
            self.state = 651
            self.expression()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Copy_assignContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def CPY_EQ(self):
            return self.getToken(jacParser.CPY_EQ, 0)

        def expression(self):
            return self.getTypedRuleContext(jacParser.ExpressionContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_copy_assign

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterCopy_assign" ):
                listener.enterCopy_assign(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitCopy_assign" ):
                listener.exitCopy_assign(self)




    def copy_assign(self):

        localctx = jacParser.Copy_assignContext(self, self._ctx, self.state)
        self.enterRule(localctx, 94, self.RULE_copy_assign)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 653
            self.match(jacParser.CPY_EQ)
            self.state = 654
            self.expression()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Inc_assignContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def expression(self):
            return self.getTypedRuleContext(jacParser.ExpressionContext,0)


        def PEQ(self):
            return self.getToken(jacParser.PEQ, 0)

        def MEQ(self):
            return self.getToken(jacParser.MEQ, 0)

        def TEQ(self):
            return self.getToken(jacParser.TEQ, 0)

        def DEQ(self):
            return self.getToken(jacParser.DEQ, 0)

        def getRuleIndex(self):
            return jacParser.RULE_inc_assign

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterInc_assign" ):
                listener.enterInc_assign(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitInc_assign" ):
                listener.exitInc_assign(self)




    def inc_assign(self):

        localctx = jacParser.Inc_assignContext(self, self._ctx, self.state)
        self.enterRule(localctx, 96, self.RULE_inc_assign)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 656
            _la = self._input.LA(1)
            if not((((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << jacParser.PEQ) | (1 << jacParser.MEQ) | (1 << jacParser.TEQ) | (1 << jacParser.DEQ))) != 0)):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
            self.state = 657
            self.expression()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ConnectContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def logical(self):
            return self.getTypedRuleContext(jacParser.LogicalContext,0)


        def edge_ref(self):
            return self.getTypedRuleContext(jacParser.Edge_refContext,0)


        def expression(self):
            return self.getTypedRuleContext(jacParser.ExpressionContext,0)


        def NOT(self):
            return self.getToken(jacParser.NOT, 0)

        def getRuleIndex(self):
            return jacParser.RULE_connect

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterConnect" ):
                listener.enterConnect(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitConnect" ):
                listener.exitConnect(self)




    def connect(self):

        localctx = jacParser.ConnectContext(self, self._ctx, self.state)
        self.enterRule(localctx, 98, self.RULE_connect)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 659
            self.logical()
            self.state = 666
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,63,self._ctx)
            if la_ == 1:
                self.state = 661
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==jacParser.NOT:
                    self.state = 660
                    self.match(jacParser.NOT)


                self.state = 663
                self.edge_ref()
                self.state = 664
                self.expression()


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class LogicalContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def compare(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(jacParser.CompareContext)
            else:
                return self.getTypedRuleContext(jacParser.CompareContext,i)


        def KW_AND(self, i:int=None):
            if i is None:
                return self.getTokens(jacParser.KW_AND)
            else:
                return self.getToken(jacParser.KW_AND, i)

        def KW_OR(self, i:int=None):
            if i is None:
                return self.getTokens(jacParser.KW_OR)
            else:
                return self.getToken(jacParser.KW_OR, i)

        def getRuleIndex(self):
            return jacParser.RULE_logical

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterLogical" ):
                listener.enterLogical(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitLogical" ):
                listener.exitLogical(self)




    def logical(self):

        localctx = jacParser.LogicalContext(self, self._ctx, self.state)
        self.enterRule(localctx, 100, self.RULE_logical)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 668
            self.compare()
            self.state = 673
            self._errHandler.sync(self)
            _alt = self._interp.adaptivePredict(self._input,64,self._ctx)
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt==1:
                    self.state = 669
                    _la = self._input.LA(1)
                    if not(_la==jacParser.KW_AND or _la==jacParser.KW_OR):
                        self._errHandler.recoverInline(self)
                    else:
                        self._errHandler.reportMatch(self)
                        self.consume()
                    self.state = 670
                    self.compare() 
                self.state = 675
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,64,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class CompareContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def NOT(self):
            return self.getToken(jacParser.NOT, 0)

        def compare(self):
            return self.getTypedRuleContext(jacParser.CompareContext,0)


        def arithmetic(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(jacParser.ArithmeticContext)
            else:
                return self.getTypedRuleContext(jacParser.ArithmeticContext,i)


        def cmp_op(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(jacParser.Cmp_opContext)
            else:
                return self.getTypedRuleContext(jacParser.Cmp_opContext,i)


        def getRuleIndex(self):
            return jacParser.RULE_compare

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterCompare" ):
                listener.enterCompare(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitCompare" ):
                listener.exitCompare(self)




    def compare(self):

        localctx = jacParser.CompareContext(self, self._ctx, self.state)
        self.enterRule(localctx, 102, self.RULE_compare)
        try:
            self.state = 687
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [jacParser.NOT]:
                self.enterOuterAlt(localctx, 1)
                self.state = 676
                self.match(jacParser.NOT)
                self.state = 677
                self.compare()
                pass
            elif token in [jacParser.T__1, jacParser.T__2, jacParser.T__4, jacParser.T__5, jacParser.T__6, jacParser.TYP_STRING, jacParser.TYP_INT, jacParser.TYP_FLOAT, jacParser.TYP_LIST, jacParser.TYP_DICT, jacParser.TYP_BOOL, jacParser.KW_TYPE, jacParser.KW_NODE, jacParser.KW_SPAWN, jacParser.DBL_COLON, jacParser.LBRACE, jacParser.KW_EDGE, jacParser.PLUS, jacParser.MINUS, jacParser.STAR_MUL, jacParser.LPAREN, jacParser.LSQUARE, jacParser.FLOAT, jacParser.STRING, jacParser.BOOL, jacParser.INT, jacParser.NULL, jacParser.NAME]:
                self.enterOuterAlt(localctx, 2)
                self.state = 678
                self.arithmetic()
                self.state = 684
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,65,self._ctx)
                while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                    if _alt==1:
                        self.state = 679
                        self.cmp_op()
                        self.state = 680
                        self.arithmetic() 
                    self.state = 686
                    self._errHandler.sync(self)
                    _alt = self._interp.adaptivePredict(self._input,65,self._ctx)

                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Cmp_opContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def EE(self):
            return self.getToken(jacParser.EE, 0)

        def LT(self):
            return self.getToken(jacParser.LT, 0)

        def GT(self):
            return self.getToken(jacParser.GT, 0)

        def LTE(self):
            return self.getToken(jacParser.LTE, 0)

        def GTE(self):
            return self.getToken(jacParser.GTE, 0)

        def NE(self):
            return self.getToken(jacParser.NE, 0)

        def KW_IN(self):
            return self.getToken(jacParser.KW_IN, 0)

        def nin(self):
            return self.getTypedRuleContext(jacParser.NinContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_cmp_op

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterCmp_op" ):
                listener.enterCmp_op(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitCmp_op" ):
                listener.exitCmp_op(self)




    def cmp_op(self):

        localctx = jacParser.Cmp_opContext(self, self._ctx, self.state)
        self.enterRule(localctx, 104, self.RULE_cmp_op)
        try:
            self.state = 697
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [jacParser.EE]:
                self.enterOuterAlt(localctx, 1)
                self.state = 689
                self.match(jacParser.EE)
                pass
            elif token in [jacParser.LT]:
                self.enterOuterAlt(localctx, 2)
                self.state = 690
                self.match(jacParser.LT)
                pass
            elif token in [jacParser.GT]:
                self.enterOuterAlt(localctx, 3)
                self.state = 691
                self.match(jacParser.GT)
                pass
            elif token in [jacParser.LTE]:
                self.enterOuterAlt(localctx, 4)
                self.state = 692
                self.match(jacParser.LTE)
                pass
            elif token in [jacParser.GTE]:
                self.enterOuterAlt(localctx, 5)
                self.state = 693
                self.match(jacParser.GTE)
                pass
            elif token in [jacParser.NE]:
                self.enterOuterAlt(localctx, 6)
                self.state = 694
                self.match(jacParser.NE)
                pass
            elif token in [jacParser.KW_IN]:
                self.enterOuterAlt(localctx, 7)
                self.state = 695
                self.match(jacParser.KW_IN)
                pass
            elif token in [jacParser.NOT]:
                self.enterOuterAlt(localctx, 8)
                self.state = 696
                self.nin()
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class NinContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def NOT(self):
            return self.getToken(jacParser.NOT, 0)

        def KW_IN(self):
            return self.getToken(jacParser.KW_IN, 0)

        def getRuleIndex(self):
            return jacParser.RULE_nin

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterNin" ):
                listener.enterNin(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitNin" ):
                listener.exitNin(self)




    def nin(self):

        localctx = jacParser.NinContext(self, self._ctx, self.state)
        self.enterRule(localctx, 106, self.RULE_nin)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 699
            self.match(jacParser.NOT)
            self.state = 700
            self.match(jacParser.KW_IN)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ArithmeticContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def term(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(jacParser.TermContext)
            else:
                return self.getTypedRuleContext(jacParser.TermContext,i)


        def PLUS(self, i:int=None):
            if i is None:
                return self.getTokens(jacParser.PLUS)
            else:
                return self.getToken(jacParser.PLUS, i)

        def MINUS(self, i:int=None):
            if i is None:
                return self.getTokens(jacParser.MINUS)
            else:
                return self.getToken(jacParser.MINUS, i)

        def getRuleIndex(self):
            return jacParser.RULE_arithmetic

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterArithmetic" ):
                listener.enterArithmetic(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitArithmetic" ):
                listener.exitArithmetic(self)




    def arithmetic(self):

        localctx = jacParser.ArithmeticContext(self, self._ctx, self.state)
        self.enterRule(localctx, 108, self.RULE_arithmetic)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 702
            self.term()
            self.state = 707
            self._errHandler.sync(self)
            _alt = self._interp.adaptivePredict(self._input,68,self._ctx)
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt==1:
                    self.state = 703
                    _la = self._input.LA(1)
                    if not(_la==jacParser.PLUS or _la==jacParser.MINUS):
                        self._errHandler.recoverInline(self)
                    else:
                        self._errHandler.reportMatch(self)
                        self.consume()
                    self.state = 704
                    self.term() 
                self.state = 709
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,68,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class TermContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def factor(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(jacParser.FactorContext)
            else:
                return self.getTypedRuleContext(jacParser.FactorContext,i)


        def STAR_MUL(self, i:int=None):
            if i is None:
                return self.getTokens(jacParser.STAR_MUL)
            else:
                return self.getToken(jacParser.STAR_MUL, i)

        def DIV(self, i:int=None):
            if i is None:
                return self.getTokens(jacParser.DIV)
            else:
                return self.getToken(jacParser.DIV, i)

        def MOD(self, i:int=None):
            if i is None:
                return self.getTokens(jacParser.MOD)
            else:
                return self.getToken(jacParser.MOD, i)

        def getRuleIndex(self):
            return jacParser.RULE_term

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTerm" ):
                listener.enterTerm(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTerm" ):
                listener.exitTerm(self)




    def term(self):

        localctx = jacParser.TermContext(self, self._ctx, self.state)
        self.enterRule(localctx, 110, self.RULE_term)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 710
            self.factor()
            self.state = 715
            self._errHandler.sync(self)
            _alt = self._interp.adaptivePredict(self._input,69,self._ctx)
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt==1:
                    self.state = 711
                    _la = self._input.LA(1)
                    if not(((((_la - 85)) & ~0x3f) == 0 and ((1 << (_la - 85)) & ((1 << (jacParser.STAR_MUL - 85)) | (1 << (jacParser.DIV - 85)) | (1 << (jacParser.MOD - 85)))) != 0)):
                        self._errHandler.recoverInline(self)
                    else:
                        self._errHandler.reportMatch(self)
                        self.consume()
                    self.state = 712
                    self.factor() 
                self.state = 717
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,69,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class FactorContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def factor(self):
            return self.getTypedRuleContext(jacParser.FactorContext,0)


        def PLUS(self):
            return self.getToken(jacParser.PLUS, 0)

        def MINUS(self):
            return self.getToken(jacParser.MINUS, 0)

        def power(self):
            return self.getTypedRuleContext(jacParser.PowerContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_factor

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterFactor" ):
                listener.enterFactor(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitFactor" ):
                listener.exitFactor(self)




    def factor(self):

        localctx = jacParser.FactorContext(self, self._ctx, self.state)
        self.enterRule(localctx, 112, self.RULE_factor)
        self._la = 0 # Token type
        try:
            self.state = 721
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,70,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 718
                _la = self._input.LA(1)
                if not(_la==jacParser.PLUS or _la==jacParser.MINUS):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                self.state = 719
                self.factor()
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 720
                self.power()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class PowerContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def atom(self):
            return self.getTypedRuleContext(jacParser.AtomContext,0)


        def POW(self, i:int=None):
            if i is None:
                return self.getTokens(jacParser.POW)
            else:
                return self.getToken(jacParser.POW, i)

        def factor(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(jacParser.FactorContext)
            else:
                return self.getTypedRuleContext(jacParser.FactorContext,i)


        def getRuleIndex(self):
            return jacParser.RULE_power

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPower" ):
                listener.enterPower(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPower" ):
                listener.exitPower(self)




    def power(self):

        localctx = jacParser.PowerContext(self, self._ctx, self.state)
        self.enterRule(localctx, 114, self.RULE_power)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 723
            self.atom(0)
            self.state = 728
            self._errHandler.sync(self)
            _alt = self._interp.adaptivePredict(self._input,71,self._ctx)
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt==1:
                    self.state = 724
                    self.match(jacParser.POW)
                    self.state = 725
                    self.factor() 
                self.state = 730
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,71,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class AtomContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def INT(self):
            return self.getToken(jacParser.INT, 0)

        def FLOAT(self):
            return self.getToken(jacParser.FLOAT, 0)

        def STRING(self):
            return self.getToken(jacParser.STRING, 0)

        def BOOL(self):
            return self.getToken(jacParser.BOOL, 0)

        def NULL(self):
            return self.getToken(jacParser.NULL, 0)

        def NAME(self):
            return self.getToken(jacParser.NAME, 0)

        def node_edge_ref(self):
            return self.getTypedRuleContext(jacParser.Node_edge_refContext,0)


        def list_val(self):
            return self.getTypedRuleContext(jacParser.List_valContext,0)


        def dict_val(self):
            return self.getTypedRuleContext(jacParser.Dict_valContext,0)


        def LPAREN(self):
            return self.getToken(jacParser.LPAREN, 0)

        def expression(self):
            return self.getTypedRuleContext(jacParser.ExpressionContext,0)


        def RPAREN(self):
            return self.getToken(jacParser.RPAREN, 0)

        def DBL_COLON(self):
            return self.getToken(jacParser.DBL_COLON, 0)

        def spawn_ctx(self):
            return self.getTypedRuleContext(jacParser.Spawn_ctxContext,0)


        def spawn(self):
            return self.getTypedRuleContext(jacParser.SpawnContext,0)


        def ref(self):
            return self.getTypedRuleContext(jacParser.RefContext,0)


        def deref(self):
            return self.getTypedRuleContext(jacParser.DerefContext,0)


        def any_type(self):
            return self.getTypedRuleContext(jacParser.Any_typeContext,0)


        def atom(self):
            return self.getTypedRuleContext(jacParser.AtomContext,0)


        def atom_trailer(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(jacParser.Atom_trailerContext)
            else:
                return self.getTypedRuleContext(jacParser.Atom_trailerContext,i)


        def getRuleIndex(self):
            return jacParser.RULE_atom

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAtom" ):
                listener.enterAtom(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAtom" ):
                listener.exitAtom(self)



    def atom(self, _p:int=0):
        _parentctx = self._ctx
        _parentState = self.state
        localctx = jacParser.AtomContext(self, self._ctx, _parentState)
        _prevctx = localctx
        _startState = 116
        self.enterRecursionRule(localctx, 116, self.RULE_atom, _p)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 754
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,73,self._ctx)
            if la_ == 1:
                self.state = 732
                self.match(jacParser.INT)
                pass

            elif la_ == 2:
                self.state = 733
                self.match(jacParser.FLOAT)
                pass

            elif la_ == 3:
                self.state = 734
                self.match(jacParser.STRING)
                pass

            elif la_ == 4:
                self.state = 735
                self.match(jacParser.BOOL)
                pass

            elif la_ == 5:
                self.state = 736
                self.match(jacParser.NULL)
                pass

            elif la_ == 6:
                self.state = 737
                self.match(jacParser.NAME)
                pass

            elif la_ == 7:
                self.state = 738
                self.node_edge_ref()
                pass

            elif la_ == 8:
                self.state = 739
                self.list_val()
                pass

            elif la_ == 9:
                self.state = 740
                self.dict_val()
                pass

            elif la_ == 10:
                self.state = 741
                self.match(jacParser.LPAREN)
                self.state = 742
                self.expression()
                self.state = 743
                self.match(jacParser.RPAREN)
                pass

            elif la_ == 11:
                self.state = 745
                self.match(jacParser.DBL_COLON)
                self.state = 746
                self.match(jacParser.NAME)
                self.state = 748
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,72,self._ctx)
                if la_ == 1:
                    self.state = 747
                    self.spawn_ctx()


                pass

            elif la_ == 12:
                self.state = 750
                self.spawn()
                pass

            elif la_ == 13:
                self.state = 751
                self.ref()
                pass

            elif la_ == 14:
                self.state = 752
                self.deref()
                pass

            elif la_ == 15:
                self.state = 753
                self.any_type()
                pass


            self._ctx.stop = self._input.LT(-1)
            self.state = 764
            self._errHandler.sync(self)
            _alt = self._interp.adaptivePredict(self._input,75,self._ctx)
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt==1:
                    if self._parseListeners is not None:
                        self.triggerExitRuleEvent()
                    _prevctx = localctx
                    localctx = jacParser.AtomContext(self, _parentctx, _parentState)
                    self.pushNewRecursionContext(localctx, _startState, self.RULE_atom)
                    self.state = 756
                    if not self.precpred(self._ctx, 5):
                        from antlr4.error.Errors import FailedPredicateException
                        raise FailedPredicateException(self, "self.precpred(self._ctx, 5)")
                    self.state = 758 
                    self._errHandler.sync(self)
                    _alt = 1
                    while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                        if _alt == 1:
                            self.state = 757
                            self.atom_trailer()

                        else:
                            raise NoViableAltException(self)
                        self.state = 760 
                        self._errHandler.sync(self)
                        _alt = self._interp.adaptivePredict(self._input,74,self._ctx)
             
                self.state = 766
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,75,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.unrollRecursionContexts(_parentctx)
        return localctx


    class Atom_trailerContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def DOT(self):
            return self.getToken(jacParser.DOT, 0)

        def built_in(self):
            return self.getTypedRuleContext(jacParser.Built_inContext,0)


        def NAME(self):
            return self.getToken(jacParser.NAME, 0)

        def index_slice(self):
            return self.getTypedRuleContext(jacParser.Index_sliceContext,0)


        def LPAREN(self):
            return self.getToken(jacParser.LPAREN, 0)

        def RPAREN(self):
            return self.getToken(jacParser.RPAREN, 0)

        def expr_list(self):
            return self.getTypedRuleContext(jacParser.Expr_listContext,0)


        def DBL_COLON(self):
            return self.getToken(jacParser.DBL_COLON, 0)

        def spawn_ctx(self):
            return self.getTypedRuleContext(jacParser.Spawn_ctxContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_atom_trailer

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAtom_trailer" ):
                listener.enterAtom_trailer(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAtom_trailer" ):
                listener.exitAtom_trailer(self)




    def atom_trailer(self):

        localctx = jacParser.Atom_trailerContext(self, self._ctx, self.state)
        self.enterRule(localctx, 118, self.RULE_atom_trailer)
        self._la = 0 # Token type
        try:
            self.state = 782
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,78,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 767
                self.match(jacParser.DOT)
                self.state = 768
                self.built_in()
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 769
                self.match(jacParser.DOT)
                self.state = 770
                self.match(jacParser.NAME)
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 771
                self.index_slice()
                pass

            elif la_ == 4:
                self.enterOuterAlt(localctx, 4)
                self.state = 772
                self.match(jacParser.LPAREN)
                self.state = 774
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if (((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << jacParser.T__1) | (1 << jacParser.T__2) | (1 << jacParser.T__4) | (1 << jacParser.T__5) | (1 << jacParser.T__6) | (1 << jacParser.TYP_STRING) | (1 << jacParser.TYP_INT) | (1 << jacParser.TYP_FLOAT) | (1 << jacParser.TYP_LIST) | (1 << jacParser.TYP_DICT) | (1 << jacParser.TYP_BOOL) | (1 << jacParser.KW_TYPE) | (1 << jacParser.KW_NODE) | (1 << jacParser.KW_SPAWN) | (1 << jacParser.DBL_COLON) | (1 << jacParser.LBRACE) | (1 << jacParser.KW_EDGE))) != 0) or ((((_la - 70)) & ~0x3f) == 0 and ((1 << (_la - 70)) & ((1 << (jacParser.NOT - 70)) | (1 << (jacParser.PLUS - 70)) | (1 << (jacParser.MINUS - 70)) | (1 << (jacParser.STAR_MUL - 70)) | (1 << (jacParser.LPAREN - 70)) | (1 << (jacParser.LSQUARE - 70)) | (1 << (jacParser.FLOAT - 70)) | (1 << (jacParser.STRING - 70)) | (1 << (jacParser.BOOL - 70)) | (1 << (jacParser.INT - 70)) | (1 << (jacParser.NULL - 70)) | (1 << (jacParser.NAME - 70)))) != 0):
                    self.state = 773
                    self.expr_list()


                self.state = 776
                self.match(jacParser.RPAREN)
                pass

            elif la_ == 5:
                self.enterOuterAlt(localctx, 5)
                self.state = 777
                self.match(jacParser.DBL_COLON)
                self.state = 778
                self.match(jacParser.NAME)
                self.state = 780
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,77,self._ctx)
                if la_ == 1:
                    self.state = 779
                    self.spawn_ctx()


                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class RefContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def expression(self):
            return self.getTypedRuleContext(jacParser.ExpressionContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_ref

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterRef" ):
                listener.enterRef(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitRef" ):
                listener.exitRef(self)




    def ref(self):

        localctx = jacParser.RefContext(self, self._ctx, self.state)
        self.enterRule(localctx, 120, self.RULE_ref)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 784
            self.match(jacParser.T__1)
            self.state = 785
            self.expression()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class DerefContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def STAR_MUL(self):
            return self.getToken(jacParser.STAR_MUL, 0)

        def expression(self):
            return self.getTypedRuleContext(jacParser.ExpressionContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_deref

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDeref" ):
                listener.enterDeref(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDeref" ):
                listener.exitDeref(self)




    def deref(self):

        localctx = jacParser.DerefContext(self, self._ctx, self.state)
        self.enterRule(localctx, 122, self.RULE_deref)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 787
            self.match(jacParser.STAR_MUL)
            self.state = 788
            self.expression()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Built_inContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def string_built_in(self):
            return self.getTypedRuleContext(jacParser.String_built_inContext,0)


        def dict_built_in(self):
            return self.getTypedRuleContext(jacParser.Dict_built_inContext,0)


        def list_built_in(self):
            return self.getTypedRuleContext(jacParser.List_built_inContext,0)


        def obj_built_in(self):
            return self.getTypedRuleContext(jacParser.Obj_built_inContext,0)


        def cast_built_in(self):
            return self.getTypedRuleContext(jacParser.Cast_built_inContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_built_in

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterBuilt_in" ):
                listener.enterBuilt_in(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitBuilt_in" ):
                listener.exitBuilt_in(self)




    def built_in(self):

        localctx = jacParser.Built_inContext(self, self._ctx, self.state)
        self.enterRule(localctx, 124, self.RULE_built_in)
        try:
            self.state = 796
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,79,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)

                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 791
                self.string_built_in()
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 792
                self.dict_built_in()
                pass

            elif la_ == 4:
                self.enterOuterAlt(localctx, 4)
                self.state = 793
                self.list_built_in()
                pass

            elif la_ == 5:
                self.enterOuterAlt(localctx, 5)
                self.state = 794
                self.obj_built_in()
                pass

            elif la_ == 6:
                self.enterOuterAlt(localctx, 6)
                self.state = 795
                self.cast_built_in()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Cast_built_inContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def any_type(self):
            return self.getTypedRuleContext(jacParser.Any_typeContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_cast_built_in

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterCast_built_in" ):
                listener.enterCast_built_in(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitCast_built_in" ):
                listener.exitCast_built_in(self)




    def cast_built_in(self):

        localctx = jacParser.Cast_built_inContext(self, self._ctx, self.state)
        self.enterRule(localctx, 126, self.RULE_cast_built_in)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 798
            self.any_type()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Obj_built_inContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def KW_CONTEXT(self):
            return self.getToken(jacParser.KW_CONTEXT, 0)

        def KW_INFO(self):
            return self.getToken(jacParser.KW_INFO, 0)

        def KW_DETAILS(self):
            return self.getToken(jacParser.KW_DETAILS, 0)

        def getRuleIndex(self):
            return jacParser.RULE_obj_built_in

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterObj_built_in" ):
                listener.enterObj_built_in(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitObj_built_in" ):
                listener.exitObj_built_in(self)




    def obj_built_in(self):

        localctx = jacParser.Obj_built_inContext(self, self._ctx, self.state)
        self.enterRule(localctx, 128, self.RULE_obj_built_in)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 800
            _la = self._input.LA(1)
            if not((((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << jacParser.KW_CONTEXT) | (1 << jacParser.KW_INFO) | (1 << jacParser.KW_DETAILS))) != 0)):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Dict_built_inContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def KW_KEYS(self):
            return self.getToken(jacParser.KW_KEYS, 0)

        def LBRACE(self):
            return self.getToken(jacParser.LBRACE, 0)

        def name_list(self):
            return self.getTypedRuleContext(jacParser.Name_listContext,0)


        def RBRACE(self):
            return self.getToken(jacParser.RBRACE, 0)

        def NAME(self):
            return self.getToken(jacParser.NAME, 0)

        def TYP_DICT(self):
            return self.getToken(jacParser.TYP_DICT, 0)

        def DBL_COLON(self):
            return self.getToken(jacParser.DBL_COLON, 0)

        def DICT_DBL_COLON(self):
            return self.getToken(jacParser.DICT_DBL_COLON, 0)

        def LPAREN(self):
            return self.getToken(jacParser.LPAREN, 0)

        def expr_list(self):
            return self.getTypedRuleContext(jacParser.Expr_listContext,0)


        def RPAREN(self):
            return self.getToken(jacParser.RPAREN, 0)

        def getRuleIndex(self):
            return jacParser.RULE_dict_built_in

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDict_built_in" ):
                listener.enterDict_built_in(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDict_built_in" ):
                listener.exitDict_built_in(self)




    def dict_built_in(self):

        localctx = jacParser.Dict_built_inContext(self, self._ctx, self.state)
        self.enterRule(localctx, 130, self.RULE_dict_built_in)
        self._la = 0 # Token type
        try:
            self.state = 819
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [jacParser.KW_KEYS]:
                self.enterOuterAlt(localctx, 1)
                self.state = 802
                self.match(jacParser.KW_KEYS)
                pass
            elif token in [jacParser.LBRACE]:
                self.enterOuterAlt(localctx, 2)
                self.state = 803
                self.match(jacParser.LBRACE)
                self.state = 804
                self.name_list()
                self.state = 805
                self.match(jacParser.RBRACE)
                pass
            elif token in [jacParser.TYP_DICT, jacParser.DICT_DBL_COLON]:
                self.enterOuterAlt(localctx, 3)
                self.state = 810
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [jacParser.TYP_DICT]:
                    self.state = 807
                    self.match(jacParser.TYP_DICT)
                    self.state = 808
                    self.match(jacParser.DBL_COLON)
                    pass
                elif token in [jacParser.DICT_DBL_COLON]:
                    self.state = 809
                    self.match(jacParser.DICT_DBL_COLON)
                    pass
                else:
                    raise NoViableAltException(self)

                self.state = 812
                _la = self._input.LA(1)
                if not(_la==jacParser.KW_KEYS or _la==jacParser.NAME):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                self.state = 817
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,81,self._ctx)
                if la_ == 1:
                    self.state = 813
                    self.match(jacParser.LPAREN)
                    self.state = 814
                    self.expr_list()
                    self.state = 815
                    self.match(jacParser.RPAREN)


                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class List_built_inContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def KW_LENGTH(self):
            return self.getToken(jacParser.KW_LENGTH, 0)

        def NAME(self):
            return self.getToken(jacParser.NAME, 0)

        def TYP_LIST(self):
            return self.getToken(jacParser.TYP_LIST, 0)

        def DBL_COLON(self):
            return self.getToken(jacParser.DBL_COLON, 0)

        def LIST_DBL_COLON(self):
            return self.getToken(jacParser.LIST_DBL_COLON, 0)

        def LPAREN(self):
            return self.getToken(jacParser.LPAREN, 0)

        def expr_list(self):
            return self.getTypedRuleContext(jacParser.Expr_listContext,0)


        def RPAREN(self):
            return self.getToken(jacParser.RPAREN, 0)

        def getRuleIndex(self):
            return jacParser.RULE_list_built_in

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterList_built_in" ):
                listener.enterList_built_in(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitList_built_in" ):
                listener.exitList_built_in(self)




    def list_built_in(self):

        localctx = jacParser.List_built_inContext(self, self._ctx, self.state)
        self.enterRule(localctx, 132, self.RULE_list_built_in)
        try:
            self.state = 834
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [jacParser.KW_LENGTH]:
                self.enterOuterAlt(localctx, 1)
                self.state = 821
                self.match(jacParser.KW_LENGTH)
                pass
            elif token in [jacParser.TYP_LIST, jacParser.LIST_DBL_COLON]:
                self.enterOuterAlt(localctx, 2)
                self.state = 825
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [jacParser.TYP_LIST]:
                    self.state = 822
                    self.match(jacParser.TYP_LIST)
                    self.state = 823
                    self.match(jacParser.DBL_COLON)
                    pass
                elif token in [jacParser.LIST_DBL_COLON]:
                    self.state = 824
                    self.match(jacParser.LIST_DBL_COLON)
                    pass
                else:
                    raise NoViableAltException(self)

                self.state = 827
                self.match(jacParser.NAME)
                self.state = 832
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,84,self._ctx)
                if la_ == 1:
                    self.state = 828
                    self.match(jacParser.LPAREN)
                    self.state = 829
                    self.expr_list()
                    self.state = 830
                    self.match(jacParser.RPAREN)


                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class String_built_inContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def NAME(self):
            return self.getToken(jacParser.NAME, 0)

        def TYP_STRING(self):
            return self.getToken(jacParser.TYP_STRING, 0)

        def DBL_COLON(self):
            return self.getToken(jacParser.DBL_COLON, 0)

        def STR_DBL_COLON(self):
            return self.getToken(jacParser.STR_DBL_COLON, 0)

        def LPAREN(self):
            return self.getToken(jacParser.LPAREN, 0)

        def expr_list(self):
            return self.getTypedRuleContext(jacParser.Expr_listContext,0)


        def RPAREN(self):
            return self.getToken(jacParser.RPAREN, 0)

        def getRuleIndex(self):
            return jacParser.RULE_string_built_in

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterString_built_in" ):
                listener.enterString_built_in(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitString_built_in" ):
                listener.exitString_built_in(self)




    def string_built_in(self):

        localctx = jacParser.String_built_inContext(self, self._ctx, self.state)
        self.enterRule(localctx, 134, self.RULE_string_built_in)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 839
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [jacParser.TYP_STRING]:
                self.state = 836
                self.match(jacParser.TYP_STRING)
                self.state = 837
                self.match(jacParser.DBL_COLON)
                pass
            elif token in [jacParser.STR_DBL_COLON]:
                self.state = 838
                self.match(jacParser.STR_DBL_COLON)
                pass
            else:
                raise NoViableAltException(self)

            self.state = 841
            self.match(jacParser.NAME)
            self.state = 846
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,87,self._ctx)
            if la_ == 1:
                self.state = 842
                self.match(jacParser.LPAREN)
                self.state = 843
                self.expr_list()
                self.state = 844
                self.match(jacParser.RPAREN)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Node_edge_refContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def node_ref(self):
            return self.getTypedRuleContext(jacParser.Node_refContext,0)


        def filter_ctx(self):
            return self.getTypedRuleContext(jacParser.Filter_ctxContext,0)


        def edge_ref(self):
            return self.getTypedRuleContext(jacParser.Edge_refContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_node_edge_ref

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterNode_edge_ref" ):
                listener.enterNode_edge_ref(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitNode_edge_ref" ):
                listener.exitNode_edge_ref(self)




    def node_edge_ref(self):

        localctx = jacParser.Node_edge_refContext(self, self._ctx, self.state)
        self.enterRule(localctx, 136, self.RULE_node_edge_ref)
        try:
            self.state = 859
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [jacParser.KW_NODE]:
                self.enterOuterAlt(localctx, 1)
                self.state = 848
                self.node_ref()
                self.state = 850
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,88,self._ctx)
                if la_ == 1:
                    self.state = 849
                    self.filter_ctx()


                pass
            elif token in [jacParser.T__2, jacParser.T__4, jacParser.T__5, jacParser.T__6, jacParser.MINUS]:
                self.enterOuterAlt(localctx, 2)
                self.state = 852
                self.edge_ref()
                self.state = 857
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,90,self._ctx)
                if la_ == 1:
                    self.state = 853
                    self.node_ref()
                    self.state = 855
                    self._errHandler.sync(self)
                    la_ = self._interp.adaptivePredict(self._input,89,self._ctx)
                    if la_ == 1:
                        self.state = 854
                        self.filter_ctx()




                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Node_refContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def KW_NODE(self):
            return self.getToken(jacParser.KW_NODE, 0)

        def DBL_COLON(self):
            return self.getToken(jacParser.DBL_COLON, 0)

        def NAME(self):
            return self.getToken(jacParser.NAME, 0)

        def getRuleIndex(self):
            return jacParser.RULE_node_ref

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterNode_ref" ):
                listener.enterNode_ref(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitNode_ref" ):
                listener.exitNode_ref(self)




    def node_ref(self):

        localctx = jacParser.Node_refContext(self, self._ctx, self.state)
        self.enterRule(localctx, 138, self.RULE_node_ref)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 861
            self.match(jacParser.KW_NODE)
            self.state = 862
            self.match(jacParser.DBL_COLON)
            self.state = 863
            self.match(jacParser.NAME)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Walker_refContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def KW_WALKER(self):
            return self.getToken(jacParser.KW_WALKER, 0)

        def DBL_COLON(self):
            return self.getToken(jacParser.DBL_COLON, 0)

        def NAME(self):
            return self.getToken(jacParser.NAME, 0)

        def getRuleIndex(self):
            return jacParser.RULE_walker_ref

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterWalker_ref" ):
                listener.enterWalker_ref(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitWalker_ref" ):
                listener.exitWalker_ref(self)




    def walker_ref(self):

        localctx = jacParser.Walker_refContext(self, self._ctx, self.state)
        self.enterRule(localctx, 140, self.RULE_walker_ref)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 865
            self.match(jacParser.KW_WALKER)
            self.state = 866
            self.match(jacParser.DBL_COLON)
            self.state = 867
            self.match(jacParser.NAME)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Graph_refContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def KW_GRAPH(self):
            return self.getToken(jacParser.KW_GRAPH, 0)

        def DBL_COLON(self):
            return self.getToken(jacParser.DBL_COLON, 0)

        def NAME(self):
            return self.getToken(jacParser.NAME, 0)

        def getRuleIndex(self):
            return jacParser.RULE_graph_ref

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterGraph_ref" ):
                listener.enterGraph_ref(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitGraph_ref" ):
                listener.exitGraph_ref(self)




    def graph_ref(self):

        localctx = jacParser.Graph_refContext(self, self._ctx, self.state)
        self.enterRule(localctx, 142, self.RULE_graph_ref)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 869
            self.match(jacParser.KW_GRAPH)
            self.state = 870
            self.match(jacParser.DBL_COLON)
            self.state = 871
            self.match(jacParser.NAME)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Edge_refContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def edge_to(self):
            return self.getTypedRuleContext(jacParser.Edge_toContext,0)


        def edge_from(self):
            return self.getTypedRuleContext(jacParser.Edge_fromContext,0)


        def edge_any(self):
            return self.getTypedRuleContext(jacParser.Edge_anyContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_edge_ref

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterEdge_ref" ):
                listener.enterEdge_ref(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitEdge_ref" ):
                listener.exitEdge_ref(self)




    def edge_ref(self):

        localctx = jacParser.Edge_refContext(self, self._ctx, self.state)
        self.enterRule(localctx, 144, self.RULE_edge_ref)
        try:
            self.state = 876
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,92,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 873
                self.edge_to()
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 874
                self.edge_from()
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 875
                self.edge_any()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Edge_toContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def MINUS(self):
            return self.getToken(jacParser.MINUS, 0)

        def LSQUARE(self):
            return self.getToken(jacParser.LSQUARE, 0)

        def NAME(self):
            return self.getToken(jacParser.NAME, 0)

        def RSQUARE(self):
            return self.getToken(jacParser.RSQUARE, 0)

        def spawn_ctx(self):
            return self.getTypedRuleContext(jacParser.Spawn_ctxContext,0)


        def filter_ctx(self):
            return self.getTypedRuleContext(jacParser.Filter_ctxContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_edge_to

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterEdge_to" ):
                listener.enterEdge_to(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitEdge_to" ):
                listener.exitEdge_to(self)




    def edge_to(self):

        localctx = jacParser.Edge_toContext(self, self._ctx, self.state)
        self.enterRule(localctx, 146, self.RULE_edge_to)
        self._la = 0 # Token type
        try:
            self.state = 890
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [jacParser.T__2]:
                self.enterOuterAlt(localctx, 1)
                self.state = 878
                self.match(jacParser.T__2)
                pass
            elif token in [jacParser.MINUS]:
                self.enterOuterAlt(localctx, 2)
                self.state = 879
                self.match(jacParser.MINUS)
                self.state = 887
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==jacParser.LSQUARE:
                    self.state = 880
                    self.match(jacParser.LSQUARE)
                    self.state = 881
                    self.match(jacParser.NAME)
                    self.state = 884
                    self._errHandler.sync(self)
                    la_ = self._interp.adaptivePredict(self._input,93,self._ctx)
                    if la_ == 1:
                        self.state = 882
                        self.spawn_ctx()

                    elif la_ == 2:
                        self.state = 883
                        self.filter_ctx()


                    self.state = 886
                    self.match(jacParser.RSQUARE)


                self.state = 889
                self.match(jacParser.T__3)
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Edge_fromContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def MINUS(self):
            return self.getToken(jacParser.MINUS, 0)

        def LSQUARE(self):
            return self.getToken(jacParser.LSQUARE, 0)

        def NAME(self):
            return self.getToken(jacParser.NAME, 0)

        def RSQUARE(self):
            return self.getToken(jacParser.RSQUARE, 0)

        def spawn_ctx(self):
            return self.getTypedRuleContext(jacParser.Spawn_ctxContext,0)


        def filter_ctx(self):
            return self.getTypedRuleContext(jacParser.Filter_ctxContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_edge_from

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterEdge_from" ):
                listener.enterEdge_from(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitEdge_from" ):
                listener.exitEdge_from(self)




    def edge_from(self):

        localctx = jacParser.Edge_fromContext(self, self._ctx, self.state)
        self.enterRule(localctx, 148, self.RULE_edge_from)
        self._la = 0 # Token type
        try:
            self.state = 904
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [jacParser.T__4]:
                self.enterOuterAlt(localctx, 1)
                self.state = 892
                self.match(jacParser.T__4)
                pass
            elif token in [jacParser.T__5]:
                self.enterOuterAlt(localctx, 2)
                self.state = 893
                self.match(jacParser.T__5)
                self.state = 901
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==jacParser.LSQUARE:
                    self.state = 894
                    self.match(jacParser.LSQUARE)
                    self.state = 895
                    self.match(jacParser.NAME)
                    self.state = 898
                    self._errHandler.sync(self)
                    la_ = self._interp.adaptivePredict(self._input,96,self._ctx)
                    if la_ == 1:
                        self.state = 896
                        self.spawn_ctx()

                    elif la_ == 2:
                        self.state = 897
                        self.filter_ctx()


                    self.state = 900
                    self.match(jacParser.RSQUARE)


                self.state = 903
                self.match(jacParser.MINUS)
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Edge_anyContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LSQUARE(self):
            return self.getToken(jacParser.LSQUARE, 0)

        def NAME(self):
            return self.getToken(jacParser.NAME, 0)

        def RSQUARE(self):
            return self.getToken(jacParser.RSQUARE, 0)

        def spawn_ctx(self):
            return self.getTypedRuleContext(jacParser.Spawn_ctxContext,0)


        def filter_ctx(self):
            return self.getTypedRuleContext(jacParser.Filter_ctxContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_edge_any

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterEdge_any" ):
                listener.enterEdge_any(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitEdge_any" ):
                listener.exitEdge_any(self)




    def edge_any(self):

        localctx = jacParser.Edge_anyContext(self, self._ctx, self.state)
        self.enterRule(localctx, 150, self.RULE_edge_any)
        self._la = 0 # Token type
        try:
            self.state = 918
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [jacParser.T__6]:
                self.enterOuterAlt(localctx, 1)
                self.state = 906
                self.match(jacParser.T__6)
                pass
            elif token in [jacParser.T__5]:
                self.enterOuterAlt(localctx, 2)
                self.state = 907
                self.match(jacParser.T__5)
                self.state = 915
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==jacParser.LSQUARE:
                    self.state = 908
                    self.match(jacParser.LSQUARE)
                    self.state = 909
                    self.match(jacParser.NAME)
                    self.state = 912
                    self._errHandler.sync(self)
                    la_ = self._interp.adaptivePredict(self._input,99,self._ctx)
                    if la_ == 1:
                        self.state = 910
                        self.spawn_ctx()

                    elif la_ == 2:
                        self.state = 911
                        self.filter_ctx()


                    self.state = 914
                    self.match(jacParser.RSQUARE)


                self.state = 917
                self.match(jacParser.T__3)
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class List_valContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LSQUARE(self):
            return self.getToken(jacParser.LSQUARE, 0)

        def RSQUARE(self):
            return self.getToken(jacParser.RSQUARE, 0)

        def expr_list(self):
            return self.getTypedRuleContext(jacParser.Expr_listContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_list_val

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterList_val" ):
                listener.enterList_val(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitList_val" ):
                listener.exitList_val(self)




    def list_val(self):

        localctx = jacParser.List_valContext(self, self._ctx, self.state)
        self.enterRule(localctx, 152, self.RULE_list_val)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 920
            self.match(jacParser.LSQUARE)
            self.state = 922
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if (((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << jacParser.T__1) | (1 << jacParser.T__2) | (1 << jacParser.T__4) | (1 << jacParser.T__5) | (1 << jacParser.T__6) | (1 << jacParser.TYP_STRING) | (1 << jacParser.TYP_INT) | (1 << jacParser.TYP_FLOAT) | (1 << jacParser.TYP_LIST) | (1 << jacParser.TYP_DICT) | (1 << jacParser.TYP_BOOL) | (1 << jacParser.KW_TYPE) | (1 << jacParser.KW_NODE) | (1 << jacParser.KW_SPAWN) | (1 << jacParser.DBL_COLON) | (1 << jacParser.LBRACE) | (1 << jacParser.KW_EDGE))) != 0) or ((((_la - 70)) & ~0x3f) == 0 and ((1 << (_la - 70)) & ((1 << (jacParser.NOT - 70)) | (1 << (jacParser.PLUS - 70)) | (1 << (jacParser.MINUS - 70)) | (1 << (jacParser.STAR_MUL - 70)) | (1 << (jacParser.LPAREN - 70)) | (1 << (jacParser.LSQUARE - 70)) | (1 << (jacParser.FLOAT - 70)) | (1 << (jacParser.STRING - 70)) | (1 << (jacParser.BOOL - 70)) | (1 << (jacParser.INT - 70)) | (1 << (jacParser.NULL - 70)) | (1 << (jacParser.NAME - 70)))) != 0):
                self.state = 921
                self.expr_list()


            self.state = 924
            self.match(jacParser.RSQUARE)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Index_sliceContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LSQUARE(self):
            return self.getToken(jacParser.LSQUARE, 0)

        def expression(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(jacParser.ExpressionContext)
            else:
                return self.getTypedRuleContext(jacParser.ExpressionContext,i)


        def RSQUARE(self):
            return self.getToken(jacParser.RSQUARE, 0)

        def COLON(self):
            return self.getToken(jacParser.COLON, 0)

        def getRuleIndex(self):
            return jacParser.RULE_index_slice

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterIndex_slice" ):
                listener.enterIndex_slice(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitIndex_slice" ):
                listener.exitIndex_slice(self)




    def index_slice(self):

        localctx = jacParser.Index_sliceContext(self, self._ctx, self.state)
        self.enterRule(localctx, 154, self.RULE_index_slice)
        try:
            self.state = 936
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,103,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 926
                self.match(jacParser.LSQUARE)
                self.state = 927
                self.expression()
                self.state = 928
                self.match(jacParser.RSQUARE)
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 930
                self.match(jacParser.LSQUARE)
                self.state = 931
                self.expression()
                self.state = 932
                self.match(jacParser.COLON)
                self.state = 933
                self.expression()
                self.state = 934
                self.match(jacParser.RSQUARE)
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Dict_valContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LBRACE(self):
            return self.getToken(jacParser.LBRACE, 0)

        def RBRACE(self):
            return self.getToken(jacParser.RBRACE, 0)

        def kv_pair(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(jacParser.Kv_pairContext)
            else:
                return self.getTypedRuleContext(jacParser.Kv_pairContext,i)


        def COMMA(self, i:int=None):
            if i is None:
                return self.getTokens(jacParser.COMMA)
            else:
                return self.getToken(jacParser.COMMA, i)

        def getRuleIndex(self):
            return jacParser.RULE_dict_val

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDict_val" ):
                listener.enterDict_val(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDict_val" ):
                listener.exitDict_val(self)




    def dict_val(self):

        localctx = jacParser.Dict_valContext(self, self._ctx, self.state)
        self.enterRule(localctx, 156, self.RULE_dict_val)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 938
            self.match(jacParser.LBRACE)
            self.state = 947
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==jacParser.STRING:
                self.state = 939
                self.kv_pair()
                self.state = 944
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while _la==jacParser.COMMA:
                    self.state = 940
                    self.match(jacParser.COMMA)
                    self.state = 941
                    self.kv_pair()
                    self.state = 946
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)



            self.state = 949
            self.match(jacParser.RBRACE)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Kv_pairContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def STRING(self):
            return self.getToken(jacParser.STRING, 0)

        def COLON(self):
            return self.getToken(jacParser.COLON, 0)

        def expression(self):
            return self.getTypedRuleContext(jacParser.ExpressionContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_kv_pair

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterKv_pair" ):
                listener.enterKv_pair(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitKv_pair" ):
                listener.exitKv_pair(self)




    def kv_pair(self):

        localctx = jacParser.Kv_pairContext(self, self._ctx, self.state)
        self.enterRule(localctx, 158, self.RULE_kv_pair)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 951
            self.match(jacParser.STRING)
            self.state = 952
            self.match(jacParser.COLON)
            self.state = 953
            self.expression()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class SpawnContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def KW_SPAWN(self):
            return self.getToken(jacParser.KW_SPAWN, 0)

        def spawn_object(self):
            return self.getTypedRuleContext(jacParser.Spawn_objectContext,0)


        def expression(self):
            return self.getTypedRuleContext(jacParser.ExpressionContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_spawn

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSpawn" ):
                listener.enterSpawn(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSpawn" ):
                listener.exitSpawn(self)




    def spawn(self):

        localctx = jacParser.SpawnContext(self, self._ctx, self.state)
        self.enterRule(localctx, 160, self.RULE_spawn)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 955
            self.match(jacParser.KW_SPAWN)
            self.state = 957
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,106,self._ctx)
            if la_ == 1:
                self.state = 956
                self.expression()


            self.state = 959
            self.spawn_object()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Spawn_objectContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def node_spawn(self):
            return self.getTypedRuleContext(jacParser.Node_spawnContext,0)


        def walker_spawn(self):
            return self.getTypedRuleContext(jacParser.Walker_spawnContext,0)


        def graph_spawn(self):
            return self.getTypedRuleContext(jacParser.Graph_spawnContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_spawn_object

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSpawn_object" ):
                listener.enterSpawn_object(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSpawn_object" ):
                listener.exitSpawn_object(self)




    def spawn_object(self):

        localctx = jacParser.Spawn_objectContext(self, self._ctx, self.state)
        self.enterRule(localctx, 162, self.RULE_spawn_object)
        try:
            self.state = 964
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,107,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 961
                self.node_spawn()
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 962
                self.walker_spawn()
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 963
                self.graph_spawn()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Node_spawnContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def node_ref(self):
            return self.getTypedRuleContext(jacParser.Node_refContext,0)


        def edge_ref(self):
            return self.getTypedRuleContext(jacParser.Edge_refContext,0)


        def spawn_ctx(self):
            return self.getTypedRuleContext(jacParser.Spawn_ctxContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_node_spawn

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterNode_spawn" ):
                listener.enterNode_spawn(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitNode_spawn" ):
                listener.exitNode_spawn(self)




    def node_spawn(self):

        localctx = jacParser.Node_spawnContext(self, self._ctx, self.state)
        self.enterRule(localctx, 164, self.RULE_node_spawn)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 967
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if (((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << jacParser.T__2) | (1 << jacParser.T__4) | (1 << jacParser.T__5) | (1 << jacParser.T__6))) != 0) or _la==jacParser.MINUS:
                self.state = 966
                self.edge_ref()


            self.state = 969
            self.node_ref()
            self.state = 971
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,109,self._ctx)
            if la_ == 1:
                self.state = 970
                self.spawn_ctx()


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Graph_spawnContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def graph_ref(self):
            return self.getTypedRuleContext(jacParser.Graph_refContext,0)


        def edge_ref(self):
            return self.getTypedRuleContext(jacParser.Edge_refContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_graph_spawn

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterGraph_spawn" ):
                listener.enterGraph_spawn(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitGraph_spawn" ):
                listener.exitGraph_spawn(self)




    def graph_spawn(self):

        localctx = jacParser.Graph_spawnContext(self, self._ctx, self.state)
        self.enterRule(localctx, 166, self.RULE_graph_spawn)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 974
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if (((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << jacParser.T__2) | (1 << jacParser.T__4) | (1 << jacParser.T__5) | (1 << jacParser.T__6))) != 0) or _la==jacParser.MINUS:
                self.state = 973
                self.edge_ref()


            self.state = 976
            self.graph_ref()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Walker_spawnContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def walker_ref(self):
            return self.getTypedRuleContext(jacParser.Walker_refContext,0)


        def spawn_ctx(self):
            return self.getTypedRuleContext(jacParser.Spawn_ctxContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_walker_spawn

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterWalker_spawn" ):
                listener.enterWalker_spawn(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitWalker_spawn" ):
                listener.exitWalker_spawn(self)




    def walker_spawn(self):

        localctx = jacParser.Walker_spawnContext(self, self._ctx, self.state)
        self.enterRule(localctx, 168, self.RULE_walker_spawn)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 978
            self.walker_ref()
            self.state = 980
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,111,self._ctx)
            if la_ == 1:
                self.state = 979
                self.spawn_ctx()


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Spawn_ctxContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LPAREN(self):
            return self.getToken(jacParser.LPAREN, 0)

        def RPAREN(self):
            return self.getToken(jacParser.RPAREN, 0)

        def spawn_assign(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(jacParser.Spawn_assignContext)
            else:
                return self.getTypedRuleContext(jacParser.Spawn_assignContext,i)


        def COMMA(self, i:int=None):
            if i is None:
                return self.getTokens(jacParser.COMMA)
            else:
                return self.getToken(jacParser.COMMA, i)

        def getRuleIndex(self):
            return jacParser.RULE_spawn_ctx

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSpawn_ctx" ):
                listener.enterSpawn_ctx(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSpawn_ctx" ):
                listener.exitSpawn_ctx(self)




    def spawn_ctx(self):

        localctx = jacParser.Spawn_ctxContext(self, self._ctx, self.state)
        self.enterRule(localctx, 170, self.RULE_spawn_ctx)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 982
            self.match(jacParser.LPAREN)
            self.state = 991
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==jacParser.NAME:
                self.state = 983
                self.spawn_assign()
                self.state = 988
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while _la==jacParser.COMMA:
                    self.state = 984
                    self.match(jacParser.COMMA)
                    self.state = 985
                    self.spawn_assign()
                    self.state = 990
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)



            self.state = 993
            self.match(jacParser.RPAREN)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Filter_ctxContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LPAREN(self):
            return self.getToken(jacParser.LPAREN, 0)

        def RPAREN(self):
            return self.getToken(jacParser.RPAREN, 0)

        def filter_compare(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(jacParser.Filter_compareContext)
            else:
                return self.getTypedRuleContext(jacParser.Filter_compareContext,i)


        def COMMA(self, i:int=None):
            if i is None:
                return self.getTokens(jacParser.COMMA)
            else:
                return self.getToken(jacParser.COMMA, i)

        def getRuleIndex(self):
            return jacParser.RULE_filter_ctx

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterFilter_ctx" ):
                listener.enterFilter_ctx(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitFilter_ctx" ):
                listener.exitFilter_ctx(self)




    def filter_ctx(self):

        localctx = jacParser.Filter_ctxContext(self, self._ctx, self.state)
        self.enterRule(localctx, 172, self.RULE_filter_ctx)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 995
            self.match(jacParser.LPAREN)
            self.state = 1004
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==jacParser.NAME:
                self.state = 996
                self.filter_compare()
                self.state = 1001
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while _la==jacParser.COMMA:
                    self.state = 997
                    self.match(jacParser.COMMA)
                    self.state = 998
                    self.filter_compare()
                    self.state = 1003
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)



            self.state = 1006
            self.match(jacParser.RPAREN)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Spawn_assignContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def NAME(self):
            return self.getToken(jacParser.NAME, 0)

        def EQ(self):
            return self.getToken(jacParser.EQ, 0)

        def expression(self):
            return self.getTypedRuleContext(jacParser.ExpressionContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_spawn_assign

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSpawn_assign" ):
                listener.enterSpawn_assign(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSpawn_assign" ):
                listener.exitSpawn_assign(self)




    def spawn_assign(self):

        localctx = jacParser.Spawn_assignContext(self, self._ctx, self.state)
        self.enterRule(localctx, 174, self.RULE_spawn_assign)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1008
            self.match(jacParser.NAME)
            self.state = 1009
            self.match(jacParser.EQ)
            self.state = 1010
            self.expression()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Filter_compareContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def NAME(self):
            return self.getToken(jacParser.NAME, 0)

        def cmp_op(self):
            return self.getTypedRuleContext(jacParser.Cmp_opContext,0)


        def expression(self):
            return self.getTypedRuleContext(jacParser.ExpressionContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_filter_compare

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterFilter_compare" ):
                listener.enterFilter_compare(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitFilter_compare" ):
                listener.exitFilter_compare(self)




    def filter_compare(self):

        localctx = jacParser.Filter_compareContext(self, self._ctx, self.state)
        self.enterRule(localctx, 176, self.RULE_filter_compare)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1012
            self.match(jacParser.NAME)
            self.state = 1013
            self.cmp_op()
            self.state = 1014
            self.expression()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Any_typeContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def TYP_STRING(self):
            return self.getToken(jacParser.TYP_STRING, 0)

        def TYP_INT(self):
            return self.getToken(jacParser.TYP_INT, 0)

        def TYP_FLOAT(self):
            return self.getToken(jacParser.TYP_FLOAT, 0)

        def TYP_LIST(self):
            return self.getToken(jacParser.TYP_LIST, 0)

        def TYP_DICT(self):
            return self.getToken(jacParser.TYP_DICT, 0)

        def TYP_BOOL(self):
            return self.getToken(jacParser.TYP_BOOL, 0)

        def KW_NODE(self):
            return self.getToken(jacParser.KW_NODE, 0)

        def KW_EDGE(self):
            return self.getToken(jacParser.KW_EDGE, 0)

        def KW_TYPE(self):
            return self.getToken(jacParser.KW_TYPE, 0)

        def getRuleIndex(self):
            return jacParser.RULE_any_type

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAny_type" ):
                listener.enterAny_type(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAny_type" ):
                listener.exitAny_type(self)




    def any_type(self):

        localctx = jacParser.Any_typeContext(self, self._ctx, self.state)
        self.enterRule(localctx, 178, self.RULE_any_type)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1016
            _la = self._input.LA(1)
            if not((((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << jacParser.TYP_STRING) | (1 << jacParser.TYP_INT) | (1 << jacParser.TYP_FLOAT) | (1 << jacParser.TYP_LIST) | (1 << jacParser.TYP_DICT) | (1 << jacParser.TYP_BOOL) | (1 << jacParser.KW_TYPE) | (1 << jacParser.KW_NODE) | (1 << jacParser.KW_EDGE))) != 0)):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Dot_graphContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LBRACE(self):
            return self.getToken(jacParser.LBRACE, 0)

        def dot_stmt_list(self):
            return self.getTypedRuleContext(jacParser.Dot_stmt_listContext,0)


        def RBRACE(self):
            return self.getToken(jacParser.RBRACE, 0)

        def KW_GRAPH(self):
            return self.getToken(jacParser.KW_GRAPH, 0)

        def KW_DIGRAPH(self):
            return self.getToken(jacParser.KW_DIGRAPH, 0)

        def KW_STRICT(self):
            return self.getToken(jacParser.KW_STRICT, 0)

        def dot_id(self):
            return self.getTypedRuleContext(jacParser.Dot_idContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_dot_graph

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDot_graph" ):
                listener.enterDot_graph(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDot_graph" ):
                listener.exitDot_graph(self)




    def dot_graph(self):

        localctx = jacParser.Dot_graphContext(self, self._ctx, self.state)
        self.enterRule(localctx, 180, self.RULE_dot_graph)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1019
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==jacParser.KW_STRICT:
                self.state = 1018
                self.match(jacParser.KW_STRICT)


            self.state = 1021
            _la = self._input.LA(1)
            if not(_la==jacParser.KW_GRAPH or _la==jacParser.KW_DIGRAPH):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
            self.state = 1023
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if (((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << jacParser.KW_GRAPH) | (1 << jacParser.KW_NODE) | (1 << jacParser.KW_EDGE))) != 0) or ((((_la - 93)) & ~0x3f) == 0 and ((1 << (_la - 93)) & ((1 << (jacParser.FLOAT - 93)) | (1 << (jacParser.STRING - 93)) | (1 << (jacParser.INT - 93)) | (1 << (jacParser.NAME - 93)))) != 0):
                self.state = 1022
                self.dot_id()


            self.state = 1025
            self.match(jacParser.LBRACE)
            self.state = 1026
            self.dot_stmt_list()
            self.state = 1027
            self.match(jacParser.RBRACE)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Dot_stmt_listContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def dot_stmt(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(jacParser.Dot_stmtContext)
            else:
                return self.getTypedRuleContext(jacParser.Dot_stmtContext,i)


        def SEMI(self, i:int=None):
            if i is None:
                return self.getTokens(jacParser.SEMI)
            else:
                return self.getToken(jacParser.SEMI, i)

        def getRuleIndex(self):
            return jacParser.RULE_dot_stmt_list

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDot_stmt_list" ):
                listener.enterDot_stmt_list(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDot_stmt_list" ):
                listener.exitDot_stmt_list(self)




    def dot_stmt_list(self):

        localctx = jacParser.Dot_stmt_listContext(self, self._ctx, self.state)
        self.enterRule(localctx, 182, self.RULE_dot_stmt_list)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1035
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while (((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << jacParser.KW_GRAPH) | (1 << jacParser.KW_SUBGRAPH) | (1 << jacParser.KW_NODE) | (1 << jacParser.LBRACE) | (1 << jacParser.KW_EDGE))) != 0) or ((((_la - 93)) & ~0x3f) == 0 and ((1 << (_la - 93)) & ((1 << (jacParser.FLOAT - 93)) | (1 << (jacParser.STRING - 93)) | (1 << (jacParser.INT - 93)) | (1 << (jacParser.NAME - 93)))) != 0):
                self.state = 1029
                self.dot_stmt()
                self.state = 1031
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==jacParser.SEMI:
                    self.state = 1030
                    self.match(jacParser.SEMI)


                self.state = 1037
                self._errHandler.sync(self)
                _la = self._input.LA(1)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Dot_stmtContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def dot_node_stmt(self):
            return self.getTypedRuleContext(jacParser.Dot_node_stmtContext,0)


        def dot_edge_stmt(self):
            return self.getTypedRuleContext(jacParser.Dot_edge_stmtContext,0)


        def dot_attr_stmt(self):
            return self.getTypedRuleContext(jacParser.Dot_attr_stmtContext,0)


        def dot_id(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(jacParser.Dot_idContext)
            else:
                return self.getTypedRuleContext(jacParser.Dot_idContext,i)


        def EQ(self):
            return self.getToken(jacParser.EQ, 0)

        def dot_subgraph(self):
            return self.getTypedRuleContext(jacParser.Dot_subgraphContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_dot_stmt

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDot_stmt" ):
                listener.enterDot_stmt(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDot_stmt" ):
                listener.exitDot_stmt(self)




    def dot_stmt(self):

        localctx = jacParser.Dot_stmtContext(self, self._ctx, self.state)
        self.enterRule(localctx, 184, self.RULE_dot_stmt)
        try:
            self.state = 1046
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,120,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 1038
                self.dot_node_stmt()
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 1039
                self.dot_edge_stmt()
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 1040
                self.dot_attr_stmt()
                pass

            elif la_ == 4:
                self.enterOuterAlt(localctx, 4)
                self.state = 1041
                self.dot_id()
                self.state = 1042
                self.match(jacParser.EQ)
                self.state = 1043
                self.dot_id()
                pass

            elif la_ == 5:
                self.enterOuterAlt(localctx, 5)
                self.state = 1045
                self.dot_subgraph()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Dot_attr_stmtContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def dot_attr_list(self):
            return self.getTypedRuleContext(jacParser.Dot_attr_listContext,0)


        def KW_GRAPH(self):
            return self.getToken(jacParser.KW_GRAPH, 0)

        def KW_NODE(self):
            return self.getToken(jacParser.KW_NODE, 0)

        def KW_EDGE(self):
            return self.getToken(jacParser.KW_EDGE, 0)

        def getRuleIndex(self):
            return jacParser.RULE_dot_attr_stmt

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDot_attr_stmt" ):
                listener.enterDot_attr_stmt(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDot_attr_stmt" ):
                listener.exitDot_attr_stmt(self)




    def dot_attr_stmt(self):

        localctx = jacParser.Dot_attr_stmtContext(self, self._ctx, self.state)
        self.enterRule(localctx, 186, self.RULE_dot_attr_stmt)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1048
            _la = self._input.LA(1)
            if not((((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << jacParser.KW_GRAPH) | (1 << jacParser.KW_NODE) | (1 << jacParser.KW_EDGE))) != 0)):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
            self.state = 1049
            self.dot_attr_list()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Dot_attr_listContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LSQUARE(self, i:int=None):
            if i is None:
                return self.getTokens(jacParser.LSQUARE)
            else:
                return self.getToken(jacParser.LSQUARE, i)

        def RSQUARE(self, i:int=None):
            if i is None:
                return self.getTokens(jacParser.RSQUARE)
            else:
                return self.getToken(jacParser.RSQUARE, i)

        def dot_a_list(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(jacParser.Dot_a_listContext)
            else:
                return self.getTypedRuleContext(jacParser.Dot_a_listContext,i)


        def getRuleIndex(self):
            return jacParser.RULE_dot_attr_list

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDot_attr_list" ):
                listener.enterDot_attr_list(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDot_attr_list" ):
                listener.exitDot_attr_list(self)




    def dot_attr_list(self):

        localctx = jacParser.Dot_attr_listContext(self, self._ctx, self.state)
        self.enterRule(localctx, 188, self.RULE_dot_attr_list)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1056 
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while True:
                self.state = 1051
                self.match(jacParser.LSQUARE)
                self.state = 1053
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if (((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << jacParser.KW_GRAPH) | (1 << jacParser.KW_NODE) | (1 << jacParser.KW_EDGE))) != 0) or ((((_la - 93)) & ~0x3f) == 0 and ((1 << (_la - 93)) & ((1 << (jacParser.FLOAT - 93)) | (1 << (jacParser.STRING - 93)) | (1 << (jacParser.INT - 93)) | (1 << (jacParser.NAME - 93)))) != 0):
                    self.state = 1052
                    self.dot_a_list()


                self.state = 1055
                self.match(jacParser.RSQUARE)
                self.state = 1058 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if not (_la==jacParser.LSQUARE):
                    break

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Dot_a_listContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def dot_id(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(jacParser.Dot_idContext)
            else:
                return self.getTypedRuleContext(jacParser.Dot_idContext,i)


        def EQ(self, i:int=None):
            if i is None:
                return self.getTokens(jacParser.EQ)
            else:
                return self.getToken(jacParser.EQ, i)

        def COMMA(self, i:int=None):
            if i is None:
                return self.getTokens(jacParser.COMMA)
            else:
                return self.getToken(jacParser.COMMA, i)

        def getRuleIndex(self):
            return jacParser.RULE_dot_a_list

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDot_a_list" ):
                listener.enterDot_a_list(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDot_a_list" ):
                listener.exitDot_a_list(self)




    def dot_a_list(self):

        localctx = jacParser.Dot_a_listContext(self, self._ctx, self.state)
        self.enterRule(localctx, 190, self.RULE_dot_a_list)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1068 
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while True:
                self.state = 1060
                self.dot_id()
                self.state = 1063
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==jacParser.EQ:
                    self.state = 1061
                    self.match(jacParser.EQ)
                    self.state = 1062
                    self.dot_id()


                self.state = 1066
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==jacParser.COMMA:
                    self.state = 1065
                    self.match(jacParser.COMMA)


                self.state = 1070 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if not ((((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << jacParser.KW_GRAPH) | (1 << jacParser.KW_NODE) | (1 << jacParser.KW_EDGE))) != 0) or ((((_la - 93)) & ~0x3f) == 0 and ((1 << (_la - 93)) & ((1 << (jacParser.FLOAT - 93)) | (1 << (jacParser.STRING - 93)) | (1 << (jacParser.INT - 93)) | (1 << (jacParser.NAME - 93)))) != 0)):
                    break

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Dot_edge_stmtContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def dot_edgeRHS(self):
            return self.getTypedRuleContext(jacParser.Dot_edgeRHSContext,0)


        def dot_node_id(self):
            return self.getTypedRuleContext(jacParser.Dot_node_idContext,0)


        def dot_subgraph(self):
            return self.getTypedRuleContext(jacParser.Dot_subgraphContext,0)


        def dot_attr_list(self):
            return self.getTypedRuleContext(jacParser.Dot_attr_listContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_dot_edge_stmt

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDot_edge_stmt" ):
                listener.enterDot_edge_stmt(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDot_edge_stmt" ):
                listener.exitDot_edge_stmt(self)




    def dot_edge_stmt(self):

        localctx = jacParser.Dot_edge_stmtContext(self, self._ctx, self.state)
        self.enterRule(localctx, 192, self.RULE_dot_edge_stmt)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1074
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [jacParser.KW_GRAPH, jacParser.KW_NODE, jacParser.KW_EDGE, jacParser.FLOAT, jacParser.STRING, jacParser.INT, jacParser.NAME]:
                self.state = 1072
                self.dot_node_id()
                pass
            elif token in [jacParser.KW_SUBGRAPH, jacParser.LBRACE]:
                self.state = 1073
                self.dot_subgraph()
                pass
            else:
                raise NoViableAltException(self)

            self.state = 1076
            self.dot_edgeRHS()
            self.state = 1078
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==jacParser.LSQUARE:
                self.state = 1077
                self.dot_attr_list()


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Dot_edgeRHSContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def dot_edgeop(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(jacParser.Dot_edgeopContext)
            else:
                return self.getTypedRuleContext(jacParser.Dot_edgeopContext,i)


        def dot_node_id(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(jacParser.Dot_node_idContext)
            else:
                return self.getTypedRuleContext(jacParser.Dot_node_idContext,i)


        def dot_subgraph(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(jacParser.Dot_subgraphContext)
            else:
                return self.getTypedRuleContext(jacParser.Dot_subgraphContext,i)


        def getRuleIndex(self):
            return jacParser.RULE_dot_edgeRHS

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDot_edgeRHS" ):
                listener.enterDot_edgeRHS(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDot_edgeRHS" ):
                listener.exitDot_edgeRHS(self)




    def dot_edgeRHS(self):

        localctx = jacParser.Dot_edgeRHSContext(self, self._ctx, self.state)
        self.enterRule(localctx, 194, self.RULE_dot_edgeRHS)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1085 
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while True:
                self.state = 1080
                self.dot_edgeop()
                self.state = 1083
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [jacParser.KW_GRAPH, jacParser.KW_NODE, jacParser.KW_EDGE, jacParser.FLOAT, jacParser.STRING, jacParser.INT, jacParser.NAME]:
                    self.state = 1081
                    self.dot_node_id()
                    pass
                elif token in [jacParser.KW_SUBGRAPH, jacParser.LBRACE]:
                    self.state = 1082
                    self.dot_subgraph()
                    pass
                else:
                    raise NoViableAltException(self)

                self.state = 1087 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if not (_la==jacParser.T__3 or _la==jacParser.T__7):
                    break

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Dot_edgeopContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser


        def getRuleIndex(self):
            return jacParser.RULE_dot_edgeop

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDot_edgeop" ):
                listener.enterDot_edgeop(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDot_edgeop" ):
                listener.exitDot_edgeop(self)




    def dot_edgeop(self):

        localctx = jacParser.Dot_edgeopContext(self, self._ctx, self.state)
        self.enterRule(localctx, 196, self.RULE_dot_edgeop)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1089
            _la = self._input.LA(1)
            if not(_la==jacParser.T__3 or _la==jacParser.T__7):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Dot_node_stmtContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def dot_node_id(self):
            return self.getTypedRuleContext(jacParser.Dot_node_idContext,0)


        def dot_attr_list(self):
            return self.getTypedRuleContext(jacParser.Dot_attr_listContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_dot_node_stmt

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDot_node_stmt" ):
                listener.enterDot_node_stmt(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDot_node_stmt" ):
                listener.exitDot_node_stmt(self)




    def dot_node_stmt(self):

        localctx = jacParser.Dot_node_stmtContext(self, self._ctx, self.state)
        self.enterRule(localctx, 198, self.RULE_dot_node_stmt)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1091
            self.dot_node_id()
            self.state = 1093
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==jacParser.LSQUARE:
                self.state = 1092
                self.dot_attr_list()


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Dot_node_idContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def dot_id(self):
            return self.getTypedRuleContext(jacParser.Dot_idContext,0)


        def dot_port(self):
            return self.getTypedRuleContext(jacParser.Dot_portContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_dot_node_id

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDot_node_id" ):
                listener.enterDot_node_id(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDot_node_id" ):
                listener.exitDot_node_id(self)




    def dot_node_id(self):

        localctx = jacParser.Dot_node_idContext(self, self._ctx, self.state)
        self.enterRule(localctx, 200, self.RULE_dot_node_id)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1095
            self.dot_id()
            self.state = 1097
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==jacParser.COLON:
                self.state = 1096
                self.dot_port()


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Dot_portContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def COLON(self, i:int=None):
            if i is None:
                return self.getTokens(jacParser.COLON)
            else:
                return self.getToken(jacParser.COLON, i)

        def dot_id(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(jacParser.Dot_idContext)
            else:
                return self.getTypedRuleContext(jacParser.Dot_idContext,i)


        def getRuleIndex(self):
            return jacParser.RULE_dot_port

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDot_port" ):
                listener.enterDot_port(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDot_port" ):
                listener.exitDot_port(self)




    def dot_port(self):

        localctx = jacParser.Dot_portContext(self, self._ctx, self.state)
        self.enterRule(localctx, 202, self.RULE_dot_port)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1099
            self.match(jacParser.COLON)
            self.state = 1100
            self.dot_id()
            self.state = 1103
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==jacParser.COLON:
                self.state = 1101
                self.match(jacParser.COLON)
                self.state = 1102
                self.dot_id()


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Dot_subgraphContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LBRACE(self):
            return self.getToken(jacParser.LBRACE, 0)

        def dot_stmt_list(self):
            return self.getTypedRuleContext(jacParser.Dot_stmt_listContext,0)


        def RBRACE(self):
            return self.getToken(jacParser.RBRACE, 0)

        def KW_SUBGRAPH(self):
            return self.getToken(jacParser.KW_SUBGRAPH, 0)

        def dot_id(self):
            return self.getTypedRuleContext(jacParser.Dot_idContext,0)


        def getRuleIndex(self):
            return jacParser.RULE_dot_subgraph

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDot_subgraph" ):
                listener.enterDot_subgraph(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDot_subgraph" ):
                listener.exitDot_subgraph(self)




    def dot_subgraph(self):

        localctx = jacParser.Dot_subgraphContext(self, self._ctx, self.state)
        self.enterRule(localctx, 204, self.RULE_dot_subgraph)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1109
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==jacParser.KW_SUBGRAPH:
                self.state = 1105
                self.match(jacParser.KW_SUBGRAPH)
                self.state = 1107
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if (((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << jacParser.KW_GRAPH) | (1 << jacParser.KW_NODE) | (1 << jacParser.KW_EDGE))) != 0) or ((((_la - 93)) & ~0x3f) == 0 and ((1 << (_la - 93)) & ((1 << (jacParser.FLOAT - 93)) | (1 << (jacParser.STRING - 93)) | (1 << (jacParser.INT - 93)) | (1 << (jacParser.NAME - 93)))) != 0):
                    self.state = 1106
                    self.dot_id()




            self.state = 1111
            self.match(jacParser.LBRACE)
            self.state = 1112
            self.dot_stmt_list()
            self.state = 1113
            self.match(jacParser.RBRACE)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Dot_idContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def NAME(self):
            return self.getToken(jacParser.NAME, 0)

        def STRING(self):
            return self.getToken(jacParser.STRING, 0)

        def INT(self):
            return self.getToken(jacParser.INT, 0)

        def FLOAT(self):
            return self.getToken(jacParser.FLOAT, 0)

        def KW_GRAPH(self):
            return self.getToken(jacParser.KW_GRAPH, 0)

        def KW_NODE(self):
            return self.getToken(jacParser.KW_NODE, 0)

        def KW_EDGE(self):
            return self.getToken(jacParser.KW_EDGE, 0)

        def getRuleIndex(self):
            return jacParser.RULE_dot_id

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDot_id" ):
                listener.enterDot_id(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDot_id" ):
                listener.exitDot_id(self)




    def dot_id(self):

        localctx = jacParser.Dot_idContext(self, self._ctx, self.state)
        self.enterRule(localctx, 206, self.RULE_dot_id)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1115
            _la = self._input.LA(1)
            if not((((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << jacParser.KW_GRAPH) | (1 << jacParser.KW_NODE) | (1 << jacParser.KW_EDGE))) != 0) or ((((_la - 93)) & ~0x3f) == 0 and ((1 << (_la - 93)) & ((1 << (jacParser.FLOAT - 93)) | (1 << (jacParser.STRING - 93)) | (1 << (jacParser.INT - 93)) | (1 << (jacParser.NAME - 93)))) != 0)):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx



    def sempred(self, localctx:RuleContext, ruleIndex:int, predIndex:int):
        if self._predicates == None:
            self._predicates = dict()
        self._predicates[58] = self.atom_sempred
        pred = self._predicates.get(ruleIndex, None)
        if pred is None:
            raise Exception("No predicate with index:" + str(ruleIndex))
        else:
            return pred(localctx, predIndex)

    def atom_sempred(self, localctx:AtomContext, predIndex:int):
            if predIndex == 0:
                return self.precpred(self._ctx, 5)
         




